\name{RV.rtest}
\alias{RV.rtest}
\title{Monte-Carlo Test on the sum of eigenvalues of a co-inertia analysis (in R).}
\description{
performs a Monte-Carlo Test on the sum of eigenvalues of a co-inertia analysis. 
}
\usage{
RV.rtest(df1, df2, nrepet = 999)
}
\arguments{
  \item{df1, df2}{two data frames with the same rows}
  \item{nrepet}{the number of permutations}
}
\value{
returns a list of class 'rtest'
}
\references{
Heo, M. & Gabriel, K.R. (1997) A permutation test of association between configurations by means of the RV coefficient. 
Communications in Statistics - Simulation and Computation, \bold{27}, 843-856.
}
\examples{
data(doubs)
pca1 <- dudi.pca(doubs$mil, scal = TRUE, scann = FALSE)
pca2 <- dudi.pca(doubs$poi, scal = FALSE, scann = FALSE)
rv1 <- RV.rtest(pca1$tab, pca2$tab, 99)
rv1
plot(rv1)
}
\keyword{multivariate}
\keyword{nonparametric}
\eof
\name{ade4toR}
\alias{ade4toR}
\alias{Rtoade4}
\title{Format Change Utility}
\description{
  Exchange objects between \R and ADE4 (classic version) \url{http://pbil.univ-lyon1.fr/ADE-4/} 
}
\usage{
ade4toR (fictab, ficcolnames = NULL, ficrownames = NULL)
Rtoade4 (x)
}
\arguments{
  \item{fictab}{a name of ADE4 text file.  A data frame with the same name is created in the \R environment.} 
  \item{ficcolnames}{the column names label file}
  \item{ficrownames}{the row names label file}
  \item{x}{a data frame}
}
\value{
 'ade4toR' gives data frames.\cr
  'Rtoade4' gives text files.
}
\details{
"xxx" is the name of object x (\code{(deparse(substitute(x)))})\cr
For any table :\cr
	creates a file "xxx.txt"\cr
	creates a file "xxx\_row\_lab.txt" with row names\cr
	creates a file "xxx\_col\_lab.txt" with column names\cr\cr

if x has the 'col.blocks' attribute\cr
creates a file "xxx\_col\_bloc\_lab.txt" with blocks names\cr
creates a file "xxx\_col\_bloc.txt" with blocks sizes\cr\cr

For a table which all columns are factors : \cr
creates a file "xxx.txt"\cr
creates a file "xxx\_var\_lab.txt" with row names\cr
creates a file "xxx\_moda\_lab.txt" with categories names\cr\cr

Files are created in the current working directory. \cr
}
\examples{
data(tarentaise)
traits <- tarentaise$traits
Rtoade4(traits)
# File creation traits.txt 
# File creation traits_col_lab.txt 
# File creation traits_row_lab.txt 
# File creation traits_col_bloc.txt 
# File creation traits_col_bloc_lab.txt  

mil <- tarentaise$envir
Rtoade4(mil)
#File creation mil.txt 
#File creation mil_var_lab.txt 
#File creation mil_moda_lab.txt 
}
\keyword{utilities}
\eof
\name{ardeche}
\alias{ardeche}
\docType{data}
\title{Fauna Table with double (row and column) partitioning}
\description{
  This data set gives informations about species in different sites and dates. 
}
\usage{data(ardeche)}
\format{
  'ardeche' is a list with 6 components. \cr
  \describe{
    \item{tab}{is a data frame containing fauna table with 43 species (rows) and 35 sites (columns).}\cr
    \item{col.blocks}{is a vector containing the number of columns in the 6 groups.}\cr
    \item{row.blocks}{is a vector containing the number of rows in the 4 groups.}\cr
    \item{dat.fac}{is a dates factor for samples (6 dates).}\cr
    \item{sta.fac}{is a sites factor for samples (6 sites).}\cr
    \item{esp.fac}{is a species order factor (Ephemeroptera, Plecoptera, Coleoptera, Trichoptera).}
  }
}
\source{
 Cazes, P., Chessel, D., and Doldec, S. (1988) L'analyse des correspondances internes d'un tableau partitionn :
 son usage en hydrobiologie. \emph{Revue de Statistique Applique} \bold{36}, 39--54.
}
\examples{
data(ardeche)
dudi1 <- dudi.coa(ardeche$tab, scan=FALSE)
s.class(dudi1$co, ardeche$dat.fac)
s.label(dudi1$co, clab=0.5, add.p=TRUE)
}
\keyword{datasets}
\eof
\name{area.plot}
\alias{area.plot}
\alias{poly2area}
\alias{area2poly}
\alias{area2link}
\alias{area.util.contour}
\alias{area.util.xy}
\title{Graphical Display of Areas}
\description{
'area' is a data frame with three variables.\cr
The first variable is a factor defining the polygons.\cr
The second and third variables are the xy coordinates of the
polygon vertices in the order where they are found.

area.plot : grey levels areas mapping

poly2area takes an object of class 'polylist' (spdep package, that contains the
older package 'spweights') and returns a data frame of type area.\cr
area2poly takes an object of type 'area' and returns a list of class 'polylist'\cr
area.util.contour and area.util.xy are two utility functions.
}
\usage{
area.plot(x, center = NULL, values = NULL, graph = NULL, lwdgraph = 2,
nclasslegend = 8, clegend = 0.75, sub = "", csub = 1, 
possub = "topleft", cpoint = 0, label = NULL, clabel = 0, ...)

area2poly(area)
poly2area (polys)
}
\arguments{
\item{x}{a data frame with three variables}
\item{center}{a matrix with the same row number as x and two columns, the coordinates
of polugone centers. If NULL, it is computed with \code{area.util.xy}}
\item{values}{if not NULL, a vector which values will be mapped to grey levels.
The values must be in the same order as the values in \code{unique(x.area[,1])}}
\item{graph}{if not NULL, \code{graph} is a neighbouring graph (object of class "neig") between polygons}
\item{lwdgraph}{a line width to draw the neighbouring graph}
\item{nclasslegend}{if \code{value} not NULL, a number of classes for the legend}
\item{clegend}{if not NULL, a character size for the legend, used with \code{par("cex")*clegend}}
\item{sub}{a string of characters to be inserted as sub-title}
\item{csub}{a character size for the sub-titles, used with \code{par("cex")*csub}}
\item{possub}{a string of characters indicating the sub-titles position 
("topleft", "topright", "bottomleft", "bottomright")}
\item{cpoint}{if positive, a character size for drawing the polygons vertices (check up),
used with \code{par("cex")*cpoint}}
\item{label}{if not NULL, by default the levels of the factor that define the polygons
are used as labels. To change this value, use label. These labels must be in the same order than
\code{unique(x.area[,1])}}
\item{clabel}{if not NULL, a character size for the polygon labels, used with \code{par("cex")*clabel}}
\item{polys}{a list belonging to the 'polylist' class in the spdep package}
\item{area}{a data frame of class 'area'}
\item{\dots}{further arguments passed to or from other methods}
}
\value{
poly2area returns a data frame 'factor,x,y'. \cr
area2poly returns a list of class \code{polylist}. \cr
}
\examples{
data(elec88)
par(mfrow = c(2,2))
area.plot(elec88$area, cpoint = 1)
area.plot(elec88$area, lab = elec88$lab, clab = 0.75)
area.plot(elec88$area, clab = 0.75)
# elec88$neig <- neig(area = elec88$area)
area.plot(elec88$area, graph = elec88$neig, 
sub = "Neighbourhood graph", possub = "topright")

par(mfrow = c(3,3))
for (i in 1:9) {
    x <- elec88$tab[,i]
    area.plot(elec88$area, val=x,
    sub = names(elec88$tab)[i], csub = 3, cleg = 1.5)
}

par(mfrow = c(3,3))
for (i in 1:9) {
    x <- elec88$tab[,i]
    s.value(elec88$xy, elec88$tab[,i], contour = elec88$contour,
    meth = "greylevel", sub = names(elec88$tab)[i], csub = 3, 
    cleg = 1.5, incl = FALSE)
}

data(irishdata)
par(mfrow = c(2,2))
w <- area.util.contour(irishdata$area)
xy <- area.util.xy(irishdata$area)
area.plot(irishdata$area, cpoint = 1)
apply(w, 1, function(x) segments(x[1],x[2],x[3],x[4], lwd = 3))
area.plot(irishdata$area, clabel = 1)
s.label(xy, area = irishdata$area, incl = FALSE, clab = 0, 
cpoi = 3, addax = FALSE, contour = w)
s.label(xy, area = irishdata$area, incl = FALSE, 
addax = FALSE, contour = w)
}
\keyword{hplot}
\eof
\name{atlas}
\alias{atlas}
\docType{data}
\title{Small Ecological Dataset}
\description{
\code{atlas} is a list containing three kinds of information about 23 regions : \cr
geographical coordinates, meteorology and bird presences. 
}
\usage{data(atlas)}
\format{
 This list contains the following objects:
  \describe{
    \item{area}{is a convex hull of 23 geographical regions. }
    \item{xy}{are the coordinates of the region centers and altitude (in meters). }
    \item{names.district}{is a vector of region names.}
    \item{meteo}{is a data frame with 7 variables: min and max temperature in january; min and max temperature in july; january, july and total rainfalls.}
    \item{birds}{is a data frame with 15 variables (species).}
    \item{alti}{is a data frame with 3 variables altitude in percentage [0,800], ]800,1500] and ]1500,5000].}
    }
}
\source{
Extract from \cr
Lebreton, Ph. (1977) Les oiseaux nicheurs rhonalpins. \emph{Atlas ornithologique Rhone-Alpes}.\cr
Centre Ornithologique Rhone-Alpes, Universit Lyon 1, 69621 Villeurbanne.\cr
Direction de la Protection de la Nature, Minist"re de la Qualit de la Vie. 1--354.
}
\examples{
data(atlas)
op <- par(no.readonly = TRUE) 
par(mfrow = c(2,2))
area.plot(atlas$area, cpoin = 1.5)
area.plot(atlas$area, lab = atlas$names.district, clab = 1)
x <- atlas$meteo$mini.jan

names(x) <- row.names(atlas$meteo)
area.plot(atlas$area, val = x, ncl = 12, sub = "Temp Mini January", 
    csub = 2, cleg = 1)
s.corcircle((dudi.pca(atlas$meteo, scann = FALSE)$co), 
    clab = 1)

area.plot(atlas$area, val = dudi.pca(atlas$meteo,scann=FALSE)$li[,1], 
    ncl = 12, sub = "Principal Component Analysis analysis", csub = 1.5, 
    cleg = 1)
birds.coa <- dudi.coa(atlas$birds, sca = FALSE, nf = 1)
x <- birds.coa$li$Axis1
area.plot(atlas$area, val = x, ncl = 12, 
    sub = "Correspondence analysis", csub = 1.5, cleg = 1)

s.value(atlas$xy, x, contour = atlas$contour, csi = 2, 
    incl = FALSE, addax = FALSE)
triangle.plot(atlas$alti)
par(op)
}
\keyword{datasets}
\eof
\name{avimedi}
\alias{avimedi}
\docType{data}
\title{Fauna Table for Constrained Ordinations}
\description{
\code{avimedi} is a list containing the informations about 302 sites : \cr
frequencies of 51 bird species ; two factors (habitats and Mediterranean origin). 
}
\usage{data(avimedi)}
\format{
  This list contains the following objects:
  \describe{
    \item{fau}{is a data frame 302 sites - 51 species. }
    \item{plan}{is a data frame 302 sites - 2 factors. }
    \item{nomesp}{is a vector 51 latin names. }
  }
}
\source{
Blondel, J., Chessel, D., & Frochot, B. (1988)\cr
Bird species impoverishment, niche expansion, and density inflation in mediterranean island habitats.\cr
\emph{Ecology}, \bold{69}, 1899--1917
}
\examples{
data(avimedi)
par(mfrow = c(2,2))
coa1 <- dudi.coa(avimedi$fau, scan = FALSE, nf = 3)
s.class(coa1$li,avimedi$plan$str:avimedi$plan$reg,
    sub = "Correspondences Analysis")
bet1 <- between(coa1, avimedi$plan$str, scan = FALSE)
s.class(bet1$ls, avimedi$plan$str,
    sub = "Between Analysis")
wit1 <- within(coa1, avimedi$plan$reg, scan=FALSE)
s.class(wit1$li, avimedi$plan$str,
    sub = "Within Analysis")
pcaiv1 <- pcaiv(coa1, avimedi$plan, scan = FALSE)
s.match(pcaiv1$li, pcaiv1$ls, clab = 0,
    sub = "Canonical Correspondences Analysis")
s.class(pcaiv1$li, avimedi$plan$str:avimedi$plan$reg, 
    add.plot = TRUE)
}
\keyword{datasets}
\eof
\name{aviurba}
\alias{aviurba}
\docType{data}
\title{Ecological Tables Triplet}
\description{
This data set is a list of informations about 51 sites : species and environmental variables. \cr
For each species, a data frame contains biological traits. 
}
\usage{data(aviurba)}
\format{
	This list contains the following objects:
	\describe{
		\item{fau}{is a data frame 51 sites 40 species. }
		\item{mil}{is a data frame 51 sites 11 environmental variables. }
		\item{traits}{is a data frame 40 species 4 biological traits.}
		\item{species.names.fr}{is a vector of the species names in french. }
		\item{species.names.la}{is a vector of the species names in latin. }
		\item{species.family}{is a factor : the species families. }
	}
}
\source{
Doldec, S., Chessel, D., Ter Braak,C. J. F.  and Champely S. (1996)\cr
Matching species traits to environmental variables: a new three-table ordination method.\cr
\emph{Environmental and Ecological Statistics}, \bold{3}, 143--166.
}
\examples{
data(aviurba)
a1 <- dudi.coa(aviurba$fau, scan = FALSE, nf=4)
a2 <- dudi.acm(aviurba$mil, row.w = a1$lw, scan = FALSE, nf = 4)
plot(coinertia(a1, a2, scan = FALSE))
}
\keyword{datasets}
\eof
\name{bacteria}
\alias{bacteria}
\docType{data}
\title{Genomes of 43 Bacteria}
\description{
    \code{bacteria} is a list containing 43 species and genomic informations : codons, amino acid and bases. 
}
\usage{data(bacteria)}
\format{
	This list contains the following objects:
	\describe{
		\item{code}{is a factor with the amino acid names for each codon. }
		\item{espcodon}{is a data frame 43 species 64 codons. }
		\item{espaa}{is a data frame 43 species 21 amino acid. }
		\item{espbase}{is a data frame 43 species 4 bases. }
	}
}
\source{
Data prepared by J. Lobry \email{lobry@biomserv.univ-lyon1.fr}
starting from \url{http://www.tigr.org/tdb/mdb/mdbcomplete.html}
}
\examples{
data(bacteria)
names(bacteria$espcodon)
names(bacteria$espaa)
names(bacteria$espbase)
sum(bacteria$espcodon) # 22,619,749 codons
scatter.coa(dudi.coa(bacteria$espcodon, scann = FALSE), 
    posi = "bottom")
}
\keyword{datasets}
\eof
\name{banque}
\alias{banque}
\docType{data}
\title{Table of Factors}
\description{
\code{banque} gives the results of a bank survey onto 810 customers. 
}
\usage{data(banque)}
\format{
  This data frame contains the following columns:
  \describe{
    \item{csp}{: "Socio-professional categories" a factor with levels 
        \code{agric} Farmers 
    	\code{artis} Craftsmen, Shopkeepers, Company directors 
    	\code{cadsu} Executives and higher intellectual professions 
    	\code{inter} Intermediate professions 
        \code{emplo} Other white-collar workers 
        \code{ouvri} Manual workers 
        \code{retra} Pensionners 
    	\code{inact} Non working population 
        \code{etudi} Students} 

    \item{duree}{: "Time relations with the customer" a factor with levels 
        \code{dm2} <2 years 
        \code{d24} [2 years, 4 years[ 
        \code{d48} [4 years, 8 years[ 
        \code{d812} [8 years, 12 years[ 
        \code{dp12} >= 12 years}
	
    \item{oppo}{: "Stopped a check ?" a factor with levels 
        \code{non} no 
        \code{oui} yes}
	
    \item{age}{: "Customer's age" a factor with levels 
        \code{ai25} [18 years, 25 years[ 
        \code{ai35} [25 years, 35 years[
        \code{ai45} [35 years, 45 years[ 
        \code{ai55} [45 years, 55 years[ 
        \code{ai75} [55 years, 75 years[}
	
    \item{sexe}{: "Customer's gender" a factor with levels 
        \code{hom} Male 
        \code{fem} Female}
	
    \item{interdit}{: "No checkbook allowed" a factor with levels
        \code{non} no 
        \code{oui} yes }
	
    \item{cableue}{: "Possess a bank card ?" a factor with levels 
        \code{non} no 
        \code{oui} yes }
	
    \item{assurvi}{: "Contrat of life insurance ?" a factor with levels 
        \code{non} no\cr
        \code{oui} yes}
	
    \item{soldevu}{: "Balance of the current accounts" a factor with levels 
        \code{p4} credit balance > 20000 
        \code{p3} credit balance 12000-20000 
        \code{p2} credit balance 4000-120000 
        \code{p1} credit balance >0-4000 
        \code{n1} debit balance  0-4000 
        \code{n2} debit balance >4000  }
	
    \item{eparlog}{: "Savings and loan association account amount" a factor with levels 
        \code{for} > 20000 
        \code{fai} >0 et <20000 
        \code{nul} nulle  }
	
    \item{eparliv}{: "Savings bank amount" a factor with levels 
        \code{for} > 20000 
        \code{fai} >0 et <20000 
        \code{nul} nulle  }
	
    \item{credhab}{: "Home loan owner" a factor with levels 
        \code{non} no 
        \code{oui} yes  }
	
    \item{credcon}{: "Consumer credit amount" a factor with levels 
        \code{nul} none 
        \code{fai} >0 and <20000 
        \code{for} > 20000  }
	
    \item{versesp}{: "Check deposits" a factor with levels 
        \code{oui} yes 
        \code{non} no  }
	
    \item{retresp}{: "Cash withdrawals" a factor with levels 
        \code{fai} < 2000 
        \code{moy} 2000-5000 
        \code{for} > 5000  }
	
    \item{remiche}{: "Endorsed checks amount" a factor with levels 
        \code{for} >10000 
        \code{moy} 10000-5000 
        \code{fai} 1-5000 
        \code{nul} none  }
	
    \item{preltre}{: "Treasury Department tax deductions" a factor with levels 
        \code{nul} none 
        \code{fai} <1000 
        \code{moy} >1000  }
	
    \item{prelfin}{: "Financial institution deductions" a factor with levels 
        \code{nul} none 
        \code{fai} <1000 
        \code{moy} >1000  }
	
    \item{viredeb}{: "Debit transfer amount" a factor with levels 
        \code{nul} none 
        \code{fai} <2500 
        \code{moy} 2500-5000 
        \code{for} >5000  }
	
    \item{virecre}{: "Credit transfer amount" a factor with levels 
        \code{for} >10000 
        \code{moy} 10000-5000 
        \code{fai} <5000 
        \code{nul} aucun  }
	
    \item{porttit}{: "Securities portfolio estimations" a factor with levels 
        \code{nul} none 
        \code{fai} < 20000 
        \code{moy} 20000-100000 
        \code{for} >100000  }
  }
}
\source{
 anonymous
}
\examples{
data(banque)
banque.acm <- dudi.acm(banque, scann = FALSE, nf = 3)
apply(banque.acm$cr, 2, mean)
banque.acm$eig[1:banque.acm$nf] # the same thing
s.arrow(banque.acm$c1, clab = 0.75)
}
\keyword{datasets}
\eof
\name{baran95}
\alias{baran95}
\docType{data}
\title{African Estuary Fishes}
\description{
This data set is a list containing relations between sites and species linked to dates
}
\usage{data(baran95)}
\format{
	This list contains the following objects:
	\describe{
		\item{fau}{is a data frame 95 sites 33 species. }
		\item{plan}{is a data frame 2 factors date and site. }
		\item{species.names}{is a vector of species latin names. }
	}
}
\source{
Baran, E. (1995) Dynamique spatio-temporelle des peuplements de Poissons estuariens en Guine (Afrique de l'Ouest).\cr
Thse de Doctorat, Universit de Bretagne Occidentale.\cr
Data collected by net fishing sampling in the Fatala river estuary
}
\examples{
data(baran95)
w <- dudi.pca(log(baran95$fau+1), scal = FALSE, scann = FALSE, 
    nf = 3)
w1 <- within(w, baran95$plan$date, scann = FALSE)
fatala <- ktab.within(w1)
stat1 <- statis(fatala, scan = FALSE, nf = 3)
w1 <- split(stat1$C.Co, baran95$plan$date)
w2 <- split(baran95$plan$site, baran95$plan$date)
par(mfrow = c(3,2))
for (j in 1:6) {
    s.label(stat1$C.Co[,1:2], clab = 0,
    sub = tab.names(fatala)[j], csub = 3)
    s.class(w1[[j]][,1:2], w2[[j]], clab = 2, axese = FALSE,
    add.plot = TRUE)
}
par(mfrow = c(1,1))

kplot(stat1, arrow = FALSE, traj = FALSE, clab = 2, uni = TRUE, 
    class = baran95$plan$site) #simpler

mfa1 <- mfa(fatala, scan = FALSE, nf = 3)
w1 <- split(mfa1$co, baran95$plan$date)
w2 <- split(baran95$plan$site, baran95$plan$date)
par(mfrow = c(3,2))
for (j in 1:6) {
    s.label(mfa1$co[,1:2], clab = 0,
    sub = tab.names(fatala)[j], csub = 3)
    s.class(w1[[j]][,1:2], w2[[j]], clab = 2, axese=FALSE,
    add.plot = TRUE)
}
par(mfrow = c(1,1))
}
\keyword{datasets}
\eof
\name{between}
\alias{between}
\alias{print.between}
\alias{plot.between}
\title{Between-Class Analysis}
\description{
Performs a particular case of a Principal Component Analysis with respect to Instrumental Variables,
in which there is only one instrumental variable, and it is a factor
}
\usage{
between(dudi, fac, scannf = TRUE, nf = 2)
plot.between(x, xax = 1, yax = 2, \dots) 
print.between(x, \dots) 
}
\arguments{
  \item{dudi}{a duality diagram, object of class \code{\link{dudi}} from one of the functions dudi.coa, dudi.pca, ...}
  \item{fac}{a factor partitioning the rows of \code{dudi$tab} in classes}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, a numeric value indicating the number of kept axes}
  \cr
  \item{x}{an object of class 'between'}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
Returns a list of subclass 'between' of class 'dudi' (see \code{\link{dudi}})
  \item{tab}{a data frame class-variables, array of variables means in each class}
  \item{cw}{a numeric vector of the column weigths}
  \item{lw}{a numeric vector of the group weigths}
  \item{eig}{a numeric vector with all the eigenvalues}
  \item{rank}{an integer}
  \item{nf}{an integer value indicating the number of kept axes}
  \item{c1}{a data frame with the column normed scores}
  \item{l1}{a data frame with the class normed scores}
  \item{co}{a data frame  with the column coordinates}
  \item{li}{a data frame with the class coordinates}
  \item{call}{the origin}
  \item{ratio}{the bewteen-class inertia percentage}
  \item{ls}{a data frame with the row coordinates}
  \item{as}{a data frame containing the projection of inertia axes onto between axes}
}
\references{
Doldec, S. and Chessel, D. (1987) Rythmes saisonniers et composantes stationnelles en milieu aquatique
I- Description d'un plan d'observations complet par projection de variables. \emph{Acta Oecologica, Oecologia Generalis}, \bold{8}, 3, 403--426.
}
\examples{
data(meaudret)
par(mfrow = c(2,2))
pca1 <- dudi.pca(meaudret$mil, scan = FALSE, nf = 4)
s.class(pca1$li, meaudret$plan$sta,
    sub = "Principal Component Analysis (mil)", csub = 1.75)
pca2 <- dudi.pca(meaudret$fau, scal = FALSE, scan = FALSE, nf = 4)
s.class(pca2$li, meaudret$pla$sta,
    sub = "Principal Component Analysis (fau)", csub = 1.75)
bet1 <- between(pca1, meaudret$plan$sta, scan = FALSE, nf = 2)
bet2 <- between(pca2, meaudret$plan$sta, scan = FALSE, nf = 2)
s.class(bet1$ls, meaudret$plan$sta,
    sub = "Between sites PCA (mil)", csub = 1.75)
s.class(bet2$ls, meaudret$plan$sta,
    sub = "Between sites PCA (fau)", csub = 1.75)

par(mfrow=c(1,1))
coib <- coinertia(bet1, bet2, scann = FALSE)
plot(coib)
}
\keyword{multivariate}
\eof
\name{bf88}
\alias{bf88}
\docType{data}
\title{Cubic Ecological Data}
\description{
\code{bf88} is a list of 6 data frames corresponding to 6 stages of vegetation. \cr
Each data frame gives some bird species informations for 4 counties. 
}
\usage{data(bf88)}
\format{
A list of six data frames with 79 rows (bird species) and 4 columns (counties).\cr
The 6 arrays (S1 to S6) are the 6 stages of vegetation.\cr
The attribut 'nomesp' of this list is a vector of species french names. 
}
\source{
Blondel, J. and Farre, H. (1988)\cr
The convergent trajectories of bird communities along ecological successions in european forests.\cr
\emph{Oecologia} (Berlin), \bold{75}, 83--93.
}
\examples{
data(bf88)
fou1 <- foucart(bf88, scann = FALSE, nf = 3)
fou1
par(mfrow = c(2,2))
scatter(fou1)
s.traject(fou1$Tco, fou1$TC[,1])
s.traject(fou1$Tco, fou1$TC[,2])
s.label(fou1$Tco)
s.label(fou1$co, add.p = TRUE, clab = 2)
par(mfrow = c(1,1))
kplot(fou1, clab.c = 2, clab.r = 0, csub = 3)
}
\keyword{datasets}
\eof
\name{bicenter.wt}
\alias{bicenter.wt}
\title{Double Weighted Centring}
\description{
This function creates a doubly centred matrix. 
}
\usage{
bicenter.wt(X, row.wt = rep(1, nrow(X)), col.wt = rep(1, ncol(X)))
}
\arguments{
  \item{X}{a matrix with n rows and p columns}
  \item{row.wt}{a vector of positive or null weights of length n}
  \item{col.wt}{a vector of positive or null weights of length p}
}
\value{
returns a doubly centred matrix
}
\examples{
w <- matrix(1:6, 3, 2)
bicenter.wt(w, c(0.2,0.6,0.2), c(0.3,0.7))

w <- matrix(1:20, 5, 4)
sum(bicenter.wt(w, runif(5), runif(4))^2)
}
\keyword{utilities}
\eof
\name{bordeaux}
\alias{bordeaux}
\docType{data}
\title{Wine Tasting}
\description{
The \code{bordeaux} data frame gives the opinions of 200 judges in a blind tasting of five different types of claret 
(red wine from the Bordeaux area in the south western parts of France).
}
\usage{data(bordeaux)}
\format{
  This data frame has 5 rows (the wines) and 4 columns (the judgements).
    \describe{
    \item{excellent}{a numeric vector}
    \item{good}{a numeric vector}
    \item{mediocre}{a numeric vector}
    \item{boring}{a numeric vector}
  }
}
\source{
 van Rijckevorsel, J. (1987)\cr
 The application of fuzzy coding and horseshoes in multiple correspondence analysis.\cr
 DSWO Press, Leiden (p. 32)
}
\examples{
data(bordeaux)
bordeaux
score(dudi.coa(bordeaux, scan = FALSE))
}
\keyword{datasets}
\eof
\name{bsetal97}
\alias{bsetal97}
\docType{data}
\title{Ecological and Biological Traits}
\description{
This data set gives ecological and biological characteristics of 131 species of aquatic insects. 
}
\usage{data(bsetal97)}
\format{
'bsetal97' is a list of 8 components.\cr
    \enumerate{
    \item{species.names}{is a vector of the species names.}
    \item{taxo}{is a data frame containing the taxonomy of species. }
    \item{biol}{is a data frame containing the biological traits. }
    \item{biol.blo}{is a vector of the numbers of items for each biological trait. }
    \item{biol.blo.names}{is a vector of the names of the biological traits. }
    \item{ecol}{is a data frame with the ecological traits. }
    \item{ecol.blo}{is a vector of the numbers of items for each ecological trait. }
    \item{ecol.blo.names}{is a vector of the names of the ecological traits. }
    }
}
\source{
 Statzner, B., Hoppenhaus, K., Arens, M.-F. and Richoux, P. (1997)\cr
 Reproductive traits, habitat use and templet theory: a synthesis of world-wide data on aquatic insects.\cr
 \emph{Freshwater Biology}, \bold{38}, 109--135.
}
\examples{
data(bsetal97)
X <- prep.fuzzy.var(bsetal97$biol, bsetal97$biol.blo)
Y <- prep.fuzzy.var(bsetal97$ecol, bsetal97$ecol.blo)
plot(coinertia(dudi.fca(X, scan = FALSE), 
    dudi.fca(Y, scan = FALSE), scan = FALSE))
}
\keyword{datasets}
\eof
\name{butterfly}
\alias{butterfly}
\docType{data}
\title{Genetics-Ecology-Environment Triple}
\description{
This data set contains environmental and genetics informations about 16 Euphydryas editha butterfly colonies studied in California and Oregon
}
\usage{data(butterfly)}
\format{
\code{butterfly} is a list with 4 components.\cr
    \enumerate{
    \item{xy}{is a data frame with the two coordinates of the 16 Euphydryas editha butterfly colonies. }
    \item{envir}{is a environmental data frame of  16 sites - 4 variables. }
    \item{genet}{is a genetics data frame of 16 sites - 6 allele frequencies. }
    \item{contour}{is a data frame for background map (California map). }
	}
}
\source{
McKechnie, S.W., Ehrlich, P.R. and White, R.R. (1975)\cr
Population genetics of Euphydryas butterflies.\cr
I. Genetic variation and the neutrality hypothesis.\cr
\emph{Genetics}, \bold{81}, 571--594.\cr\cr

Manly, B.F. (1994) \emph{Multivariate Statistical Methods. A primer.}\cr
Second edition. Chapman & Hall, London. 1--215.
}
\examples{
library(mva)
data(butterfly)
par(mfrow = c(2,2))
s.label(butterfly$xy, contour = butterfly$contour, inc = FALSE)
table.dist(dist(butterfly$xy), labels = row.names(butterfly$xy)) # depends of mva
s.value(butterfly$xy, dudi.pca(butterfly$envir, scan = FALSE)$li[,1], 
    contour = butterfly$contour, inc = FALSE, csi = 3)
plot(mantel.randtest(dist(butterfly$xy), dist(butterfly$gen), 99),
    main = "genetic/spatial")
}
\keyword{datasets}
\eof
\name{cailliez}
\alias{cailliez}
\title{Transformation to make Euclidean a distance matrix}
\description{
This function computes the smallest positive constant that makes Euclidean a distance matrix
and applies it. 
}
\usage{
cailliez(distmat, print = FALSE)
}
\arguments{
  \item{distmat}{an object of class \code{dist}}
  \item{print}{if TRUE, prints the eigenvalues of the matrix}
}
\value{
an object of class 'dist' containing an Euclidean distance matrix.
}
\references{
Cailliez, F. (1983) The analytical solution of the additive constant problem. \emph{Psychometrika}, \bold{48}, 305--310.\cr

Legendre, P. and Anderson, M.J. (1999) Distance-based redundancy analysis: testing multispecies responses in multifactorial ecological experiments. \emph{Ecological Monographs}, \bold{69}, 1--24.\cr

Legendre, P., and Legendre, L. (1998) \emph{Numerical ecology}, 2nd English edition edition. Elsevier Science BV, Amsterdam.\cr

From the DistPCoa program of P. Legendre et M.J. Anderson\cr
\url{http://www.fas.umontreal.ca/BIOL/Casgrain/en/labo/distpcoa.html}
}
\examples{
library(mva)
data(capitales)
d0 <- as.dist(capitales$df)
is.euclid(d0) # FALSE
d1 <- cailliez(d0, TRUE)
# Cailliez constant = 2429.87867 
is.euclid(d1) # TRUE
plot(d0, d1)
abline(lm(unclass(d1)~unclass(d0)))
print(coefficients(lm(unclass(d1)~unclass(d0))), dig = 8) # d1 = d + Cte
is.euclid(d0 + 2428) # FALSE
is.euclid(d0 + 2430) # TRUE the smallest constant
}
\keyword{array}
\eof
\name{capitales}
\alias{capitales}
\docType{data}
\title{Road Distances}
\description{
This data set gives the road distances between 15 european capitals and their coordinates. 
}
\usage{data(capitales)}
\format{
This list contains the following objects:
    \describe{
    \item{df}{is a data frame containing the road distances between 15 european capitals. }
    \item{xy}{is a data frame containing the coordinates of capitals. }
    }
}
\source{
 \url{http://www.euro.gouv.fr/jeunes/eurocollege/tableaucarte.htm}
}
\examples{
if (require(pixmap, quiet = TRUE)) {
    library(mva)
    data(capitales)
    names(capitales$df)
    # [1] "Madrid"     "Paris"      "Londres"    "Dublin"     "Rome"      
    # [6] "Bruxelles"  "Amsterdam"  "Berlin"     "Copenhague" "Stokholm"  
    #[11] "Luxembourg" "Helsinki"   "Vienne"     "Athenes"    "Lisbonne"

    #capitales.pnm <- read.pnm(system.file("pictures/capitales.pnm", package = "ade4"))
    #plot.pixmap(capitales.pnm) # depends of pixmap
    # xy <- locator(15) # funny
    data(capitales)
    par(mfrow = c(2,2))
    s.label(capitales$xy, lab = names(capitales$df)) 
    # depends of pixmap
    #s.label(capitales$xy, lab = names(capitales$df), pixmap = capitales.pnm, inc = FALSE)
    table.dist(as.dist(capitales$df), lab = names(capitales$df)) # depends of mva
    s.label(pcoscaled(lingoes(as.dist(capitales$df))))
    par(mfrow = c(1,1))
}
}
\keyword{datasets}
\eof
\name{cca}
\alias{cca}
\title{Canonical Correspondence Analysis}
\description{
Performs a Canonical Correspondence Analysis.  
}
\usage{
cca(sitspe, sitenv, scannf = TRUE, nf = 2)
}
\arguments{
  \item{sitspe}{a data frame for correspondence analysis, typically a sites x species table}
  \item{sitenv}{a data frame containing variables, typically a sites x environmental variables table}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
}
\value{
returns an object of class 'pcaiv'. See \code{pcaiv}
}
\references{
Ter Braak, C. J. F. (1986) Canonical correspondence analysis : a new eigenvector technique for multivariate direct gradient analysis. \emph{Ecology}, \bold{67}, 1167--1179.\cr

Ter Braak, C. J. F. (1987) The analysis of vegetation-environment relationships by canonical correspondence analysis. \emph{Vegetatio}, \bold{69}, 69--77.\cr

Chessel, D., Lebreton J. D. and Yoccoz N. (1987) Proprits de l'analyse canonique des correspondances. Une utilisation en hydrobiologie. \emph{Revue de Statistique Applique}, \bold{35}, 55--72.\cr
}
\seealso{\code{cca} in the package \code{vegan}
}
\examples{
data(rpjdl)
millog <- log(rpjdl$mil + 1)
iv1 <- cca(rpjdl$fau, millog, scan = FALSE)
plot(iv1)

# analysis with c1 - as - li -ls
# projections of inertia axes on PCAIV axes
s.corcircle(iv1$as)

# Species positions
s.label(iv1$c1, 2, 1, clab = 0.5, xlim = c(-4,4))
# Sites positions at the weighted mean of present species
s.label(iv1$ls, 2, 1, clab = 0, cpoi = 1, add.p = TRUE)

# Prediction of the positions by regression on environmental variables
s.match(iv1$ls, iv1$li, 2, 1, clab = 0.5)

# analysis with fa - l1 - co -cor
# canonical weights giving unit variance combinations
s.arrow(iv1$fa)

# sites position by environmental variables combinations
# position of species by averaging
s.label(iv1$l1, 2, 1, clab = 0, cpoi = 1.5)
s.label(iv1$co, 2, 1, add.plot = TRUE)

s.distri(iv1$l1, rpjdl$fau, 2, 1, cell = 0, csta = 0.33)
s.label(iv1$co, 2, 1, clab = 0.75, add.plot = TRUE)

# coherence between weights and correlations
par(mfrow = c(1,2))
s.corcircle(iv1$cor, 2, 1)
s.arrow(iv1$fa, 2, 1)
par(mfrow = c(1,1))
 }
\keyword{multivariate}
\eof
\name{chatcat}
\alias{chatcat}
\docType{data}
\title{Qualitative Weighted Variables}
\description{
  This data set gives the age, the fecundity and the number of litters for 26 groups of cats. 
}
\usage{data(chatcat)}
\format{
\code{chatcat} is a list of two components :
    \describe{
    \item{tab}{is a data frame with 3 factors (age, feco, nport). }
    \item{eff}{is a vector of numbers. }
    }
}
\details{
one row of \code{tab} corresponds to one group of cats.\cr
The value in \code{eff} is the number of cats in this group
}
\source{
Pontier, D. (1984)\cr
Contribution  la biologie et  la gntique des populations de chats domestiques (Felis catus).\cr
Thse de 3me cycle. Universit Lyon 1, p. 67.
}
\examples{
data(chatcat)
summary(chatcat$tab)
w <- acm.disjonctif(chatcat$tab) #  Disjonctive table
names(w) <- c(paste("A", 1:5, sep = ""), paste("B", 1:5, sep = ""), 
    paste("C", 1:2, sep = ""))
w <- t(w*chatcat$num)%*%as.matrix(w)
w <- data.frame(w)
w # BURT table
}
\keyword{datasets}
\eof
\name{chats}
\alias{chats}
\docType{data}
\title{Pair of Variables}
\description{
This data set is a contingency table of age classes and fecundity classes of cats felis catus. 
}
\usage{data(chats)}
\format{
    \code{chats} is a data frame with 8 rows and 8 columns.\cr
    The 8 rows are age classes (age1, \dots, age8)\cr
    The 8 columns are fecundity classes (f0, f12, f34, \dots, fcd)\cr
    The values are cats numbers (contingency table).
}
\source{
Legay, J.M. and Pontier, D. (1985)\cr
Relation ge-fcondit dans les populations de Chats domestiques, Felis catus.\cr
\emph{Mammalia}, \bold{49}, 395--402.
}
\examples{
data(chats)
chatsw <- data.frame(t(chats))
chatscoa <- dudi.coa(chatsw, scann = FALSE)
par(mfrow = c(2,2))
table.cont(chatsw, abmean.x = TRUE, csi = 2, abline.x = TRUE, 
    clabel.r = 1.5, clabel.c = 1.5)
table.cont(chatsw, abmean.y = TRUE, csi = 2, abline.y = TRUE, 
    clabel.r = 1.5, clabel.c = 1.5)
table.cont(chatsw, x = chatscoa$c1[,1], y = chatscoa$l1[,1],
    abmean.x = TRUE, csi = 2, abline.x = TRUE, clabel.r = 1.5, 
    clabel.c = 1.5)
table.cont(chatsw,, x = chatscoa$c1[,1], y = chatscoa$l1[,1],
    abmean.y = TRUE, csi = 2, abline.y = TRUE, clabel.r = 1.5, 
    clabel.c = 1.5)
}
\keyword{datasets}
\eof
\name{chazeb}
\alias{chazeb}
\docType{data}
\title{Charolais-Zebus}
\description{
This data set gives six different weights of 23 charolais and zebu oxen. 
}
\usage{data(chazeb)}
\format{
  \code{chazeb} is a list of 2 components.
  \describe{
	  \item{tab}{is a data frame with 23 rows and 6 columns.}
	  \item{cla}{is a factor with two levels "cha" et "zeb". }
  }
}
\source{
Tomassone, R., Danzard, M., Daudin, J. J. and Masson J. P.  (1988)\cr
\emph{Discrimination et classement}, Masson, Paris. p. 43
}
\examples{
data(chazeb)
plot(discrimin(dudi.pca(chazeb$tab, scan = FALSE), 
    chazeb$cla, scan = FALSE))
}
\keyword{datasets}
\eof
\name{clementines}
\alias{clementines}
\docType{data}
\title{Fruit Production}
\description{
The \code{clementines} is a data set containing the fruit production of 20 clementine trees during 15 years.
}
\usage{data(clementines)}
\format{
A data frame with 15 rows and 20 columns
}
\source{
Tisn-Agostini, D. (1988)\cr
Description par analyse en composantes principales de l'volution de la production du clmentinier en association avec 12 types de porte-greffe.\cr
Rapport technique, DEA Analyse et modlisation des systmes biologiques, Universit Lyon 1. 
}
\examples{
data(clementines)
op <- par(no.readonly = TRUE) 
par(mfrow = c(5,4)) ; par(mar = c(2,2,1,1))
for (i in 1:20) {
    w0 <- 1:15 ; plot(w0, clementines[,i], type = "b")
    abline(lm(clementines[,i] ~ w0))
}
par(op)

pca1 <- dudi.pca(clementines, scan = FALSE)
s.corcircle(pca1$co, clab = 0.75)

barplot(pca1$li[,1])

op <- par(no.readonly = TRUE) 
par(mfrow = c(5,4)) ; par(mar = c(2,2,1,1))
clem0 <- pca1$tab
croi <- 1:15
alter <- c(rep(c(1,-1),7),1)
for (i in 1:20) {
    y <- clem0[,i]
    plot(w0, y, type = "b", ylim = c(-2,2))
    z <- predict(lm(clem0[,i] ~ croi*alter))
    points(w0, z, pch = 20, cex = 2)
    for(j in 1:15) segments (j,y[j],j,z[j])
}
par(op)
}
\keyword{datasets}
\eof
\name{coinertia}
\alias{coinertia}
\alias{print.coinertia}
\alias{plot.coinertia}
\alias{summary.coinertia}
\title{Coinertia Analysis}
\description{
The coinertia analysis performs a double inertia analysis of two arrays. 
}
\usage{
coinertia(dudiX, dudiY, scannf = TRUE, nf = 2)
plot.coinertia (x, xax = 1, yax = 2, \dots) 
print.coinertia (x, \dots) 
summary.coinertia (object, \dots) 
}
\arguments{
  \item{dudiX}{a duality diagram providing from one of the functions dudi.coa, dudi.pca, \dots}
  \item{dudiY}{a duality diagram providing from one of the functions dudi.coa, dudi.pca, \dots}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  \cr
  \item{x, object}{an object of class 'coinertia'}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
Returns a list of class 'coinertia', sub-class 'dudi' containing:
  \item{call}{call}
  \item{rank}{rank}
  \item{nf}{a numeric value indicating the number of kept axes}
  \item{RV}{a numeric value, the RV coefficient}
  \item{eig}{a numeric vector with all the eigenvalues}
  \item{lw}{a numeric vector with the rows weigths (crossed array)}
  \item{cw}{a numeric vector with the columns weigths (crossed array)}
  \item{tab}{a crossed array (CA)} 
  \item{li}{Y col = CA row: coordinates}
  \item{l1}{Y col = CA row: normed scores}
  \item{co}{X col = CA column: coordinates}
  \item{c1}{X col = CA column: normed scores}
  \item{lX}{the row coordinates (X)}
  \item{mX}{the normed row scores (X)}
  \item{lY}{the row coordinates (Y)}
  \item{mY}{the normed row scores (Y)}
  \item{aX}{the axis onto co-inertia axis (X)}
  \item{aY}{the axis onto co-inertia axis (Y)}
}
\references{
Doldec, S. and Chessel, D. (1994) Co-inertia analysis: an alternative method for studying species-environment relationships. \emph{Freshwater Biology}, \bold{31}, 277--294.
}
\section{WARNING }{
IMPORTANT : \code{dudi1} and \code{dudi2} must have identical row weights.
}
\examples{
data(doubs)
dudi1 <- dudi.pca(doubs$mil, scale = TRUE, scan = FALSE, nf = 3)
dudi2 <- dudi.pca(doubs$poi, scale = FALSE, scan = FALSE, nf = 2)
coin1 <- coinertia(dudi1,dudi2, scan = FALSE, nf = 2)
s.arrow(coin1$l1, clab = 0.7)

s.arrow(coin1$c1, clab = 0.7)

par(mfrow = c(1,2))
s.corcircle(coin1$aX)
s.corcircle(coin1$aY)
par(mfrow = c(1,1))
 
coin1
summary(coin1)
plot(coin1)
}
\keyword{multivariate}
\eof
\name{coleo}
\alias{coleo}
\docType{data}
\title{Table of Fuzzy Biological Traits }
\description{
This data set coleo (coleoptera) is a a fuzzy biological traits table.  
}
\usage{data(coleo)}
\format{
\code{coleo} is a list of 5 components.
\describe{
    \item{tab}{is a data frame with 110 rows (species) and 32 columns (categories).}
    \item{species.names}{is a vector of species names.}
    \item{moda.names}{is a vector of fuzzy variables names.}
    \item{families}{is a factor species family.}
    \item{col.blocks}{is a vector containing the number of categories of each trait.}
    }
}
\source{
Bournaud, M., Richoux, P. and Usseglio-Polatera, P. (1992)\cr
An approach to the synthesis of qualitative ecological information from aquatic coleoptera communities.\cr
\emph{Regulated rivers: Research and Management}, \bold{7}, 165--180
}
\examples{
data(coleo)
op <- par(no.readonly = TRUE) 
coleo.fuzzy <- prep.fuzzy.var(coleo$tab, coleo$col.blocks)
fca1 <- dudi.fca(coleo.fuzzy, sca = FALSE, nf = 3)
par(mfrow = c(3,3))
indica <- factor(rep(names(coleo$col), coleo$col))
for (j in levels(indica)) s.distri (fca1$l1,
    coleo$tab[,which(indica==j)], clab = 1.5, sub = as.character(j), 
    cell = 0, csta = 0.5, csub = 3, 
    label = coleo$moda.names[which(indica==j)])
par(op)
}
\keyword{datasets}
\eof
\name{deug}
\alias{deug}
\docType{data}
\title{Exam marks for some students}
\description{
This data set gives the exam results of 118 students in the second year of a French University onto 8 subjects. 
}
\usage{data(deug)}
\format{
    \code{deug} is a list of three components.
    \enumerate{
    \item{tab}{is a data frame with 118 students and 8 subjects.}
    \item{result}{is a factor of 118 components giving the final exam levels (A+, A, B, B-, C-, D).}
    \item{cent}{is a vector of required marks by subject to get exactly 10/20 with a coefficient.}
    }
}
\source{
University of Lyon 1
}
\examples{
data(deug)
# decentred PCA
pca1 <- dudi.pca(deug$tab, scal = FALSE, center = deug$cent, 
    scan = FALSE)
s.class(pca1$li, deug$result)
s.arrow(40 * pca1$c1, add.plot = TRUE)
}
\keyword{datasets}
\eof
\name{discrimin}
\alias{discrimin}
\alias{plot.discrimin}
\alias{print.discrimin}
\title{Linear Discriminant Analysis (descriptive statistic)}
\description{
performs a linear discriminant analysis. 
}
\usage{
discrimin(dudi, fac, scannf = TRUE, nf = 2)
plot.discrimin (x, xax = 1, yax = 2, \dots) 
print.discrimin (x, \dots) 
}
\arguments{
  \item{dudi}{a duality diagram, object of class 'dudi'}
  \item{fac}{a factor defining the classes of discriminant analysis}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  \cr

  \item{x}{an object of class 'discrimin'}
  \item{xax}{the column number of the x-axis}
  \item{yax}{the column number of the y-axis}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
returns a list of class 'discrimin' containing :
  \item{nf}{a numeric value indicating the number of kept axes}
  \item{eig}{a numeric vector with all the eigenvalues}
  \item{fa}{a matrix with the loadings: the canonical weights}
  \item{li}{a data frame which gives the canonical scores}
  \item{va}{a matrix which gives the cosines between the variables and the canonical scores}
  \item{cp}{a matrix which gives the cosines between the components and the canonical scores}
  \item{gc}{a data frame which gives the class scores}
}
\seealso{\code{lda} in package \code{MASS}
}
\examples{
data(chazeb)
dis1 <- discrimin(dudi.pca(chazeb$tab, scan = FALSE), chazeb$cla, 
    scan = FALSE)
dis1
plot(dis1)

data(skulls)
plot(discrimin(dudi.pca(skulls, scan = FALSE), gl(5,30), 
    scan = FALSE))
}
\keyword{multivariate}
\eof
\name{discrimin.coa}
\alias{discrimin.coa}
\title{Discriminant Correspondence Analysis
}
\description{
performs a discriminant correspondence analysis. 
}
\usage{
discrimin.coa(df, fac, scannf = TRUE, nf = 2)
}
\arguments{
  \item{df}{a data frame containing positive or null values}
  \item{fac}{a factor defining the classes of discriminant analysis}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
}
\value{
a list of class 'discrimin'. See \code{\link{discrimin}}
}
\references{
Perriere, G.,Lobry,  J. R.  and Thioulouse J. (1996) Correspondence discriminant analysis: a multivariate method for comparing classes of protein and nucleic acid sequences. \emph{CABIOS}, \bold{12}, 519--524.\cr

Perriere, G. and Thioulouse, J. (2002) Use of Correspondence Discriminant Analysis to predict the subcellular location of bacterial proteins. \emph{Computer Methods and Programs in Biomedicine}, in press.
}
\examples{
data(perthi02)
plot(discrimin.coa(perthi02$tab, perthi02$cla, scan = FALSE))
}
\keyword{multivariate}
\eof
\name{dist.binary}
\alias{dist.binary}
\title{Computation of Distance Matrices for Binary Data}
\description{
computes for binary data some distance matrice. 
}
\usage{
dist.binary(df, method = NULL, diag = FALSE, upper = FALSE)
}
\arguments{
  \item{df}{a data frame with positive or zero values. Used with \code{as.matrix(1 * (df > 0))}}
  \item{method}{an integer between 1 and 10 . If NULL the choice is made with a console message. See details}
  \item{diag}{a logical value indicating whether the diagonal of the distance matrix should be printed by `print.dist'}
  \item{upper}{a logical value indicating whether the upper triangle of the distance matrix should be printed by `print.dist'}
}
\details{
All these distances are of type \eqn{d=\sqrt{1-s}}{d = sqrt(1 - s)} with s a similarity coefficient. 
\item{1 = Jaccard index (1901)}{S3 coefficient of Gower & Legendre \eqn{s_1 = \frac{a}{a+b+c}}{s1 = a / (a+b+c)}}
\item{2 = Sockal & Michener index (1958)}{S4 coefficient of Gower & Legendre \eqn{s_2 =\frac{a+d}{a+b+c+d}}{s2 = (a+d) / (a+b+c+d)}}
\item{3 = Sockal & Sneath(1963)}{S5 coefficient of Gower & Legendre \eqn{s_3 =\frac{a}{a+2(b+c)}}{s3 = a / (a + 2(b + c))}}
\item{4 = Rogers & Tanimoto (1960)}{S6 coefficient of Gower & Legendre \eqn{s_4 =\frac{a+d}{(a+2(b+c)+d)}}{s4 = (a + d) / (a + 2(b + c) +d)}}
\item{5 = Czekanowski (1913) or Sorensen (1948)}{S7 coefficient of Gower & Legendre \eqn{s_5 =\frac{2*a}{2*a+b+c}}{s5 = 2a / (2a + b + c)}}
\item{6 = S9 index of Gower & Legendre (1986)}{\eqn{s_6 =\frac{a-(b+c)+d}{a+b+c+d}}{s6 = (a - (b + c) + d) / (a + b + c + d)}}
\item{7 = Ochiai (1957)}{S12 coefficient of Gower & Legendre \eqn{s_7 =\frac{a}{\sqrt{(a+b)(a+c)}}}{s7 = a / sqrt((a + b)(a + c))}}
\item{8 = Sockal & Sneath (1963)}{S13 coefficient of Gower & Legendre \eqn{s_8 =\frac{ad}{sqrt{(a+b)(a+c)(d+b)(d+c)}}}{s8 = ad / sqrt((a + b)(a + c)(d + b)(d + c))}}
\item{9 = Phi of Pearson}{S14 coefficient of Gower & Legendre \eqn{s_9 =\frac{ad-bc}{\sqrt{(a+b)(a+c)(b+d)(d+c)}}}{s9 = (ad - bc) / sqrt((a + b)(a + c)(d + b)(d + c))}}
\item{10 = S2 coefficient of Gower & Legendre}{\eqn{s_1 = \frac{a}{a+b+c+d}}{s10 = a / (a + b + c + d)}}
}
\value{
returns a distance matrix of class \code{dist} between the rows of the data frame
}
\references{Gower, J.C. and Legendre, P. (1986) Metric and Euclidean properties of dissimilarity coefficients. 
\emph{Journal of Classification}, \bold{3}, 5--48.
}
\examples{
data(aviurba)
for (i in 1:10) {
	d <- dist.binary(aviurba$fau, method = i)
	cat(attr(d, "method"), is.euclid(d), "\n")}
}
\keyword{array}
\keyword{multivariate}
\eof
\name{dist.dudi}
\alias{dist.dudi}
\title{Computation of the Distance Matrix of a Statistical Triplet
}
\description{
computes for a statistical triplet a distance matrix. 
}
\usage{
dist.dudi(dudi, amongrow = TRUE)
}
\arguments{
  \item{dudi}{a duality diagram, object of class 'dudi'}
  \item{amongrow}{a logical value computing the distance if TRUE, between rows, if FALSE between columns.}
}
\value{
an object of class 'dist'
}
\examples{
data (meaudret)
pca1 <- dudi.pca(meaudret$mil, scan = FALSE)
sum((dist(scalewt(meaudret$mil)) - dist.dudi(pca1))^2)
#[1] 4.045e-29 the same thing
}
\keyword{array}
\keyword{multivariate}
\eof
\name{dist.neig}
\alias{dist.neig}
\title{Computation of the Distance Matrix associated to a Neighbouring Graph
}
\description{
  This distance matrix  between two points is the length of the shortest path between
these points. 
}
\usage{
dist.neig(neig)
}
\arguments{
  \item{neig}{a neighbouring graph, object of class 'neig'}
}
\value{
returns a distance matrix, object of class 'dist'
}
\examples{
if (require(mva, quiet = TRUE)) {
	data(elec88)
	d0 <- dist.neig(elec88$neig)
	plot(dist(elec88$xy),d0)
}
}
\keyword{array}
\keyword{multivariate}
\eof
\name{dist.prop}
\alias{dist.prop}
\title{Computation of Distance Matrices of Percentage Data
}
\description{
computes for percentage data some distance matrices. 
}
\usage{
dist.prop(df, method = NULL, diag = FALSE, upper = FALSE)
}
\arguments{
  \item{df}{a data frame containing only positive or null values, used as row percentages}
  \item{method}{an integer between 1 and 5. If NULL the choice is made with a console message. See details}
  \item{diag}{a logical value indicating whether the diagonal of the distance matrix should be printed by `print.dist'}
  \item{upper}{a logical value indicating whether the upper triangle of the distance matrix should be printed by `print.dist'}
}
\details{
\item{1 = Manly}{\eqn{d_1=\frac{1}{2} \sum_{i=1}^{K}{|{p_i-q_i}|}}{d1 = sum|p(i) - q(i)|/2}}
\item{2 = Overlap index Manly}{\eqn{d_2=1-\frac{\sum_{i=1}^{K}{p_i}}{\sqrt{\sum_{i=1}^{K}{p_i^2}}{\sqrt{\sum_{i=1}^{K}{q_i^2}}}}}{d2 = 1 - Sum(p(i)q(i))/sqrt(Sum(p(i)^2)/sqrt(Sum(q(i)^2)}}
\item{3 = Rogers 1972 (one locus)}{\eqn{d_3=\frac{1}{n} \sqrt{\frac{1}{2} \sum_{i=1}^{K}{({p_i-q_i})^2}}}{d3 = sqrt(0.5*Sum(p(i)-q(i)^2))}}
\item{4 = Nei 1972 (one locus)}{\eqn{d_4=\frac{1}{n} \ln{\frac{\sum_{i=1}^{K}{p_i q_i}}{\sqrt{\sum_{i=1}^{K}{p_i^2}}{\sqrt{\sum_{i=1}^{K}{q_i^2}}}}}}{d4 = -ln(Sum(p(i)q(i)/sqrt(Sum(p(i)^2)/sqrt(Sum(q(i)^2))}}
\item{5 = Edwards 1971 (one locus)}{\eqn{d_5=\sqrt{1-\sum_{i=1}^{K}{\sqrt{p_1 q_i}}}}{d5= sqrt (1 - (Sum(sqrt(p(i)q(i))))}}
}
\value{
returns a distance matrix, object of class 'dist'
}
\references{
Edwards, A. W. F. (1971) Distance between populations on the basis of gene frequencies. \emph{Biometrics}, \bold{27}, 
873--881. 

Manly, B. F. (1994) \emph{Multivariate Statistical Methods. A primer.}, Second edition. Chapman & Hall, London.\cr

Nei, M. (1972) Genetic distances between populations. \emph{The American Naturalist}, \bold{106}, 283--292. 
}
\examples{
data(microsatt)
w <- microsatt$tab[1:microsatt$loci.eff[1]]
par(mfrow = c(2,2))
scatter(dudi.pco(lingoes(dist.prop(w,1)), scann = FALSE))
scatter(dudi.pco(lingoes(dist.prop(w,2)), scann = FALSE))
scatter(dudi.pco(dist.prop(w,3), scann = FALSE))
scatter(dudi.pco(lingoes(dist.prop(w,4)), scann = FALSE))
}
\keyword{array}
\keyword{multivariate}
\eof
\name{dist.quant}
\alias{dist.quant}
\title{Computation of Distance Matrices on Quantitative Variables}
\description{
computes on quantitative variables, some distance matrices as canonical, Joreskog and Mahalanobis. 
}
\usage{
dist.quant(df, method = NULL, diag = FALSE, upper = FALSE, 
    tol = 1e-07)
}
\arguments{
  \item{df}{a data frame containing only quantitative variables}
  \item{method}{an integer between 1 and 3. If NULL the choice is made with a console message. See details}
  \item{diag}{a logical value indicating whether the diagonal of the distance matrix should be printed by `print.dist'}
  \item{upper}{a logical value indicating whether the upper triangle of the distance matrix should be printed by `print.dist'}
  \item{tol}{used in case 3 of \code{method} as a tolerance threshold for null eigenvalues}
}
\details{
All the distances are of type \eqn{d=\|x-y\|}{d = ||x - y||}
  \item{1 = Canonical}{A = Identity}
  \item{2 = Joreskog}{\eqn{A=\frac{1}{diag(cov)}}{A = 1 / diag(cov)}}
  \item{3 = Mahalanobis}{A = inv(cov)} 
}
\value{
an object of class 'dist'
}
\examples{
library(mva)
data(ecomor)
par(mfrow = c(2,2))
scatter(dudi.pco(dist.quant(ecomor$morpho,3), scan = FALSE))
scatter(dudi.pco(dist.quant(ecomor$morpho,2), scan = FALSE))
scatter(dudi.pco(dist(scalewt(ecomor$morpho)), scan = FALSE))
scatter(dudi.pco(dist.quant(ecomor$morpho,1), scan = FALSE))
}
\keyword{array}
\keyword{multivariate}
\eof
\name{doubs}
\alias{doubs}
\docType{data}
\title{Pair of Ecological Tables}
\description{
This data set gives environmental variables, fish species and spatial coordinates for 30 sites. 
}
\usage{data(doubs)}
\format{
	\code{doubs} is a list with 3 components.
	\enumerate{
		\item{mil}{is a data frame with 30 rows (sites) and 11 environmental variables.}
		\item{poi}{is a data frame with 30 rows (sites) and 27 fish species.}
		\item{xy}{is a data frame with 30 rows (sites)  and 2 spatial coordinates.}
	}
}
\source{
 Verneaux, J. (1973)\cr
 Cours d'eau de Franche-Comt (Massif du Jura).\cr
 Recherches cologiques sur le rseau hydrographique du Doubs. Essai de biotypologie.\cr
 Thse d'tat, Besanon. 1--257
}
\examples{
data(doubs)
pca1 <- dudi.pca(doubs$mil, scan = FALSE)
pca2 <- dudi.pca(doubs$poi, scale = FALSE, scan = FALSE)
coiner1 <- coinertia(pca1, pca2, scan = FALSE)
par(mfrow = c(3,3))
s.corcircle(coiner1$aX)
s.value(doubs$xy, coiner1$lX[,1])
s.value(doubs$xy, coiner1$lX[,2])
s.arrow(coiner1$c1)
s.match(coiner1$mX, coiner1$mY)
s.corcircle(coiner1$aY)
s.arrow(coiner1$l1)
s.value(doubs$xy, coiner1$lY[,1])
s.value(doubs$xy, coiner1$lY[,2])
}
\keyword{datasets}
\eof
\name{dudi}
\alias{dudi}
\alias{as.dudi}
\alias{print.dudi}
\alias{t.dudi}
\alias{is.dudi}
\alias{redo.dudi}
\title{Duality Diagram}
\description{
\code{as.dudi} is called by many functions (\code{pca.dudi}, \code{coa.dudi}, \code{acm.dudi}, ...) 
and not directly by the user. It creates duality diagrams.

\code{t.dudi} returns an object of class 'dudi' where the rows are the columns and the columns are the rows
of the initial dudi. 

\code{is.dudi} returns TRUE if the object is of class \code{dudi} 

\code{redo.dudi} computes again an analysis, eventually changing the number of kept axes. Used by other functions.\cr
}
\usage{
as.dudi(df, col.w, row.w, scannf, nf, call, type, tol = 1e-07, 
    full = FALSE) 
print.dudi(x, \dots) 
is.dudi(x) 
redo.dudi(dudi, newnf = 2) 
t.dudi(x) 
}
\arguments{
  \item{df}{a data frame with n rows and p columns}
  \item{col.w}{a numeric vector containing the row weights}
  \item{row.w}{a numeric vector containing the column weights}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  \item{call}{generally \code{match.call()}}
  \item{type}{a string of characters : the returned list will be of class \code{c(type, "dudi")}}
  \item{tol}{a tolerance threshold for null eigenvalues (a value less than tol times the first one is considered as null)}
  \item{full}{a logical value indicating whether all non null eigenvalues should be kept}
  \item{x, dudi}{objects of class \code{dudi}}
  \item{\dots}{further arguments passed to or from other methods}
  \item{newnf}{an integer indicating the number of kept axes}
}
\value{
as.dudi and all the functions that use it return a list with the following components :
\item{tab}{a data frame with n rows et p columns}
\item{cw}{row weights, a vector with n components} 
\item{lw}{column weights, a vector with p components}
\item{eig}{eigenvalues, a vector with min(n,p) components}
\item{nf}{integer, number of kept axes}
\item{c1}{principal axes, data frame with p rows et nf columns}
\item{l1}{principal components, data frame with n rows et nf columns}
\item{co}{column coordinates, data frame with p rows et nf columns}
\item{li}{row coordinates, data frame with n rows et nf columns}
\item{call}{original call}
}
\references{Escoufier, Y. (1987) 
The duality diagram  : a means of better practical applications 
In \emph{Development in numerical ecology}, Legendre, P. & Legendre, L. (Eds.) 
NATO advanced Institute,  Serie G. Springer Verlag, Berlin,  139--156.
}
\examples{
data(deug)
dd1 <- dudi.pca(deug$tab, scannf = FALSE)
dd1
t(dd1)
is.dudi(dd1)
redo.dudi(dd1,3)
}
\keyword{multivariate}
\eof
\name{dudi.acm}
\alias{dudi.acm}
\alias{acm.burt}
\alias{acm.disjonctif}
\alias{boxplot.acm}
\title{Multiple Correspondence Analysis}
\description{
\code{dudi.acm} performs the multiple correspondence analysis of a factor table.\cr
\code{acm.burt} an utility giving the crossed Burt table of two factors table.\cr
\code{acm.disjonctif} an utility giving the complete disjunctive table of a factor table.\cr
\code{boxplot.acm} a graphic utility to interpret axes.\cr
}
\usage{
dudi.acm (df, row.w = rep(1, nrow(df)), scannf = TRUE, nf = 2)
acm.burt (df1, df2, counts = rep(1, nrow(df1))) 
acm.disjonctif (df) 
boxplot.acm (x, xax = 1, \dots) 
}
\arguments{
  \item{df, df1, df2}{data frames containing only factors}
  \item{row.w, counts}{vector of row weights, by default, uniform weighting}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  \item{x}{an object of class \code{acm}}
  \item{xax}{the number of factor to display}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
\code{dudi.acm} returns a list of class \code{acm} and \code{dudi} (see \link{dudi}) containing  
\item{cr}{ a data frame which rows are the variables, columns are the kept scores and the values
are the correlation ratios}
}
\references{
Tenenhaus, M. & Young, F.W. (1985) An analysis and synthesis of multiple correspondence analysis, optimal scaling, dual scaling, homogeneity analysis ans other methods for quantifying categorical multivariate data. Psychometrika, \bold{50}, 1, 91-119.\cr\cr

Lebart, L., A. Morineau, and M. Piron. 1995. Statistique exploratoire multidimensionnelle. Dunod, Paris.
}
\seealso{
	\link{s.chull}, \link{s.class}
}
\examples{
data(banque)
banque.acm <- dudi.acm(banque, scann = FALSE, nf = 3)
scatter.dudi(banque.acm)

apply(banque.acm$cr, 2, mean)
banque.acm$eig[1:banque.acm$nf] # the same thing
boxplot.acm(banque.acm)

scatter(banque.acm)

s.value(banque.acm$li, banque.acm$li[,3])

bb <- acm.burt(banque, banque)
bbcoa <- dudi.coa(bb, scann = FALSE)
plot(banque.acm$c1[,1], bbcoa$c1[,1])
# mca and coa of Burt table. Lebart & coll. section 1.4

bd <- acm.disjonctif(banque)
bdcoa <- dudi.coa(bd, scann = FALSE)
plot(banque.acm$li[,1], bdcoa$li[,1]) 
# mca and coa of disjonctive table. Lebart & coll. section 1.4
plot(banque.acm$co[,1], dudi.coa(bd, scann = FALSE)$co[,1]) 
}
\keyword{multivariate}
\eof
\name{dudi.coa}
\alias{dudi.coa}
\title{Correspondence Analysis}
\description{
performs a correspondence analysis. 
}
\usage{
dudi.coa(df, scannf = TRUE, nf = 2)
}
\arguments{
  \item{df}{a data frame containing positive or null values}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
}
\value{
returns a list of class \code{coa} and \code{dudi} (see \link{dudi}) containing 
  \item{N}{the sum of all the values of the initial table}
}
\references{
Benzcri, J.P. and Coll. (1973) \emph{L'analyse des donnes. II L'analyse des correspondances}, Bordas, Paris. 1--620.\cr

Greenacre, M. J. (1984) \emph{Theory and applications of correspondence analysis}, Academic Press, London.
}
\examples{
data(rpjdl)
chisq.test(rpjdl$fau)$statistic
rpjdl.coa <- dudi.coa(rpjdl$fau, scannf = FALSE, nf = 4)
sum(rpjdl.coa$eig)*rpjdl.coa$N # the same

par(mfrow = c(1,2))
s.label(rpjdl.coa$co, clab = 0.6, lab = rpjdl$frlab)
s.label(rpjdl.coa$li, clab = 0.6)
par(mfrow = c(1,1))

data(bordeaux)
db <- dudi.coa(bordeaux, scan = FALSE)
db
score(db)
}
\keyword{multivariate}
\eof
\name{dudi.dec}
\alias{dudi.dec}
\title{Decentred Correspondence Analysis}
\description{
performs a decentred correspondence analysis. 
}
\usage{
dudi.dec(df, eff, scannf = TRUE, nf = 2)
}
\arguments{
  \item{df}{a data frame containing positive or null values}
  \item{eff}{a vector containing the reference distribution. Its length is equal to the number of rows of df}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
}
\value{
Returns a list of class \code{dec} and \code{dudi} (see \link{dudi}) containing also 
  \item{R}{sum of all the values of the initial table}
}
\references{Doldec, S., Chessel, D. and Olivier J. M. (1995) L'analyse des correspondances dcentre: application aux peuplements ichtyologiques du haut-Rhne. \emph{Bulletin Franais de la Pche et de la Pisciculture}, \bold{336}, 29--40.}
\examples{
data(ichtyo)
dudi1 <- dudi.dec(ichtyo$tab, ichtyo$eff, scan = FALSE)
sum(apply(ichtyo$tab, 2, function(x)
    chisq.test(x, p = ichtyo$eff/sum(ichtyo$eff))$statistic))
sum(dudi1$eig) * sum(ichtyo$eff) # the same

s.class(dudi1$li, ichtyo$dat, wt = ichtyo$eff/sum(ichtyo$eff))
}
\keyword{multivariate}
\eof
\name{dudi.fca}
\alias{dudi.fca}
\alias{prep.fuzzy.var}
\title{Fuzzy Correspondence Analysis}
\description{
 This function analyses a table of fuzzy variables.\cr\cr
 A fuzzy variable takes values of type \eqn{a=(a_1,\dots,a_k)}{a=(a1,\dots,ak)} 
 giving the importance of k categories.\cr\cr
 A missing data is denoted (0,...,0).\cr
 Only the profile a/sum(a) is used, and missing data are replaced by
 the mean profile of the others in the function \code{prep.fuzzy.var}. See ref. for details.
}
\usage{
prep.fuzzy.var (df, col.blocks, row.w = rep(1, nrow(df)))
dudi.fca(df, scannf = TRUE, nf = 2)
}
\arguments{
  \item{df}{a data frame containing positive or null values}
  \item{col.blocks}{a vector containing the number of categories for each fuzzy variable}
  \item{row.w}{a vector of row weights}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
}
\value{
The function \code{prep.fuzzy.var} returns a data frame with the attribute \code{col.blocks}. 
The function \code{dudi.fca} returns a list of class \code{fca} and \code{dudi} (see \link{dudi}) containing also
\item{cr}{a data frame which rows are the blocs, columns are the kept axes, and values are the correlation ratios.}
}
\references{Chevenet, F., Doldec, S. and Chessel, D. (1994) A fuzzy coding approach for the analysis of 
long-term ecological data. \emph{Freshwater Biology}, \bold{31}, 295--309. 
}
\examples{
w1 <- matrix(c(1,0,0,2,1,1,0,2,2,0,1,0,1,1,1,0,1,3,1,0), 4, 5)
w1 <- data.frame(w1)
w2 <- prep.fuzzy.var(w1, c(2,3))
w1
w2
attributes(w2)

data(bsetal97)
w <- prep.fuzzy.var(bsetal97$biol, bsetal97$biol.blo)
scatter(dudi.fca(w, scann = FALSE, nf = 3), csub = 3, clab.moda = 1.5)

 w1 <- prep.fuzzy.var(bsetal97$biol, bsetal97$biol.blo)
w2 <- prep.fuzzy.var(bsetal97$ecol, bsetal97$ecol.blo)
d1 <- dudi.fca(w1, scann = FALSE, nf = 3)
d2 <- dudi.fca(w2, scann = FALSE, nf = 3)
plot(coinertia(d1, d2, scann = FALSE))
}
\keyword{multivariate}
\eof
\name{dudi.mix}
\alias{dudi.mix}
\title{Ordination of Tables mixing quantitative variables and factors}
\description{
performs a multivariate analysis with mixed quantitative variables and factors. 
}
\usage{
dudi.mix(df, add.square = FALSE, scannf = TRUE, nf = 2)
}
\arguments{
  \item{df}{a data frame with mixed type variables (quantitative, factor and ordered)}
  \item{add.square}{a logical value indicating whether the squares of quantitative variables should be added}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
}
\details{
If df contains only quantitative variables, this is equivalent to a normed PCA.\cr
If df contains only factors, this is equivalent to a MCA.\cr
Ordered factors are replaced by \code{poly(x,deg=2)}. \cr

This analysis generalizes the Hill and Smith method.\cr
The principal components of this analysis are centered and normed vectors maximizing the sum of the:\cr
	squared correlation coefficients with quantitative variables\cr
	squared multiple correlation coefficients with polynoms\cr
	correlation ratios with factors. \cr
}
\value{
Returns a list of class \code{mix} and \code{dudi} (see \link{dudi}) containing also 
  \item{index}{a factor giving the type of each variable : f = factor, o = ordered, q = quantitative}
  \item{assign}{a factor indicating the initial variable for each column of the transformed table}
  \item{cr}{a data frame giving for each variable and each score:\cr
	the squared correlation coefficients if it is a quantitative variable\cr
	the correlation ratios if it is a factor\cr
	the squared multiple correlation coefficients if it is ordered}
}
\references{Hill, M. O., and A. J. E. Smith. 1976. Principal component analysis of taxonomic data with multi-state discrete characters. \emph{Taxon}, \bold{25}, 249-255.\cr\cr
De Leeuw, J., J. van Rijckevorsel, and . 1980. HOMALS and PRINCALS - Some generalizations of principal components analysis. Pages 231-242 in E. Diday and Coll., editors. Data Analysis and Informatics II. Elsevier Science Publisher, North Holland, Amsterdam.\cr\cr
Kiers, H. A. L. 1994. Simple structure in component analysis techniques for mixtures of qualitative ans quantitative variables. \emph{Psychometrika}, \bold{56}, 197-212.
}
\examples{
data(dunedata)
dd1 <- dudi.mix(dunedata$envir, scann = FALSE)
scatter.dudi(dd1, clab.r = 1, clab.c = 1.5)

dd2 <- dudi.mix(dunedata$envir, scann = FALSE, add = TRUE)
scatter.dudi(dd2, clab.r = 1, clab.c = 1.5)
}
\keyword{multivariate}
\eof
\name{dudi.nsc}
\alias{dudi.nsc}
\title{Non symmetric correspondence analysis}
\description{
performs a non symmetric correspondence analysis. 
}
\usage{
dudi.nsc(df, scannf = TRUE, nf = 2)
}
\arguments{
  \item{df}{a data frame containing positive or null values}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
}
\value{
Returns a list of class \code{nsc} and \code{dudi} (see \link{dudi}) containing also
  \item{N}{sum of the values of the initial table}
}
\references{Kroonenberg, P. M., and Lombardo  R. (1999) Nonsymmetric correspondence analysis: a tool for analysing contingency tables with a dependence structure. \emph{Multivariate Behavioral Research}, \bold{34}, 367--396.
}
\examples{
data(housetasks)
nsc1 <- dudi.nsc(housetasks, scan = FALSE)
s.label(nsc1$c1, clab = 1.25)
s.arrow(nsc1$li, add.pl = TRUE, clab = 0.75) # see ref p.383
}
\keyword{multivariate}
\eof
\name{dudi.pca}
\alias{dudi.pca}
\title{Principal Component Analysis}
\description{
\code{dudi.pca} performs a principal component analysis of a data frame and
returns the results as objects of class \code{pca} and \code{dudi}. 
}
\usage{
dudi.pca(df, row.w = rep(1, nrow(df))/nrow(df), 
    col.w = rep(1, ncol(df)), center = TRUE, scale = TRUE, 
    scannf = TRUE, nf = 2)
}
\arguments{
  \item{df}{a data frame with n rows (individuals) and p columns (numeric variables)}
  \item{row.w}{an optional row weights (by default, uniform row weights)}
  \item{col.w}{an optional column weights (by default, unit column weights)}
  \item{center}{a logical or numeric value, centring option\cr
	if TRUE, centring by the mean\cr
	if FALSE no centring\cr
	if a numeric vector, its length must be equal to the number of columns of df (p)
	and gives the decentring}
  \item{scale}{a logical value indicating whether the column vectors should be normed for the row.w weighting}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
}
\value{
Returns a list of classes \code{pca} and \code{dudi} (see \link{dudi}) containing also :
\item{cent}{a vector with p components}
\item{norm}{a vector with p components}
if \eqn{x_{ij}}{x[i,j]} is the value of the table df and \eqn{y_{ij}}{y[i,j]} is the value of the table \code{$tab}, we have:
	\deqn{y_{ij}=\frac{x_{ij}-cent_j}{norm_j}}{y[i,j] = (x[i,j] - cent[j]) / norm[j]}
	\deqn{x_{ij}=y_{ij} \ast norm_j + cent_j}{x[i,j] = y[i,j]*norm[j] + cent[j]}
}
\seealso{
    \code{prcomp}, \code{princomp} in the \code{mva} library
}
\examples{
data(deug)
deug.dudi <- dudi.pca(deug$tab, center = deug$cent, 
    scale = FALSE, scan = FALSE)
par(mfrow = c(2,2))
s.class(deug.dudi$li, deug$result, cpoint = 1)
s.arrow(deug.dudi$c1, lab = names(deug$tab))
deug.dudi1 <- dudi.pca(deug$tab, center = TRUE, 
    scale = TRUE, scan = FALSE)
s.class(deug.dudi1$li, deug$result, cpoint = 1)
s.corcircle(deug.dudi1$co, lab = names(deug$tab), 
    full = FALSE, box = TRUE)
par(mfrow = c(1,1))

# for interpretations
par(mfrow = c(3,3))
par(mar = c(2.1,2.1,2.1,1.1))
for(i in 1:9) { 
hist(deug.dudi$tab[,i], xlim = c(-40,40), breaks = seq(-45, 35, by = 5), 
    prob = TRUE, right = FALSE, main = names(deug$tab)[i], xlab = "", 
    ylim = c(0,0.10))
abline(v = 0, lwd = 3)
}
}
\keyword{multivariate}
\eof
\name{dudi.pco}
\alias{dudi.pco}
\alias{scatter.pco}
\title{Principal Coordinates Analysis}
\description{
\code{dudi.pco} performs a principal coordinates analysis of an Euclidean distance matrix
and returns the results as objects of class \code{pco} and \code{dudi}. 
}
\usage{
dudi.pco(d, row.w = "uniform", scannf = TRUE, nf = 2, 
    full = FALSE, tol = 1e-07)
scatter.pco (x, xax = 1, yax = 2, clab.row = 1, posieig = "top", 
    sub = NULL, csub = 2, \dots) 
}
\arguments{
  \item{d}{an object of class 'dist' containing an Euclidean distance matrix.}
  \item{row.w}{an optional distance matrix row weights. 
  If not null, must be a vector of positive numbers with length equal to the size of the distance matrix}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  \item{full}{a logical value indicating whether all the axes should be kept}
  \item{tol}{a tolerance threshold to test whether the distance matrix is Euclidean :
  	an eigenvalue is considered positive if it is larger than 
  \code{-tol*lambda1} where \code{lambda1} is the largest eigenvalue.}\cr\cr
	  
  \item{x}{an object of class \code{pco}}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{clab.row}{a character size for the row labels}
  \item{posieig}{if "top" the eigenvalues bar plot is upside,
  	if "bottom" it is downside, if "none" no plot}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
\code{dudi.pco} returns a list of class 'pco' and 'dudi'. See \link{dudi}
}
\references{Gower, J. C. (1966) Some distance properties of latent root and vector methods used in multivariate analysis. \emph{Biometrika}, \bold{53}, 325--338.
}
\examples{
data(yanomama)
gen <- quasieuclid(as.dist(yanomama$gen))
geo <- quasieuclid(as.dist(yanomama$geo))
ant <- quasieuclid(as.dist(yanomama$ant))
geo1 <- dudi.pco(geo, scann = FALSE, nf = 3)
gen1 <- dudi.pco(gen, scann = FALSE, nf = 3)
ant1 <- dudi.pco(ant, scann = FALSE, nf = 3)
plot(coinertia(ant1, gen1, scann = FALSE))
}
\keyword{array}
\keyword{multivariate}
\eof
\name{dunedata}
\alias{dunedata}
\non_function{}
\title{Dune Meadow Data}
\description{
\code{dunedata} is a data set containing for 30 sites, environmental variables and plant species. 
}
\usage{data(dunedata)}
\format{
	\code{dunedata} is a list with 2 components.
	\enumerate{
		\item{envir}{is a data frame with 30 rows (sites) 5 columns (environnemental variables).}
		\item{veg}{is a data frame with 30 rows (sites) 20 columns (plant species).}
	}
}
\source{
 Jongman, R. H., ter Braak, C. J. F.  and van Tongeren, O. F. R.  (1987)\cr
 \emph{Data analysis in community and landscape ecology}, Pudoc, Wageningen.
}
\examples{
data(dunedata)
summary(dunedata$envir)
is.ordered(dunedata$envir$use)
score(dudi.mix(dunedata$envir, scan = FALSE))
}
\keyword{datasets}
\eof
\name{ecomor}
\alias{ecomor}
\docType{data}
\title{Ecomorphological Convergence}
\description{
This data set gives ecomorphological informations about 129 bird species. 
}
\usage{data(ecomor)}
\format{
	\code{ecomor} is a list of 7 components.
	\enumerate{
		\item{habitat}{is a data frame with 129 species, 16 dummy variables (the habitats). 
		These variables indicate the species presence (1) or the species absence (0) in a given habitat.}
		\item{forsub}{is a data frame with 129 species, 6 variables (the feeding place classes): 
		foliage, ground , twig , bush, trunk and aerial feeders. These dummy variables indicate the use (1) 
		or  no use (0) of a given feeding place by a species. }
		\item{morpho}{is a data frame with 129 species abd 8 morphological variables: wingl (Wing length, mm), 
		taill (Tail length, mm), culml (Culmen length, mm), bilh (Bill height, mm), bilw (Bill width, mm), 
		tarsl (Tarsus length, mm), midtl (Middle toe length, mm) and weig (Weight, g).}
		\item{diet}{is a data frame with 129 species and 8 variables (diet types): Gr (granivorous: seeds), 
		Fr (frugivorous: berries, acorns, drupes), Ne (frugivorous: nectar), Fo (folivorous: leaves), 
		In (invertebrate feeder: insects, spiders, myriapods, isopods, snails, worms), 
		Ca (carnivorous: flesh of small vertebrates), Li (limnivorous: invertebrates in fresh water),
		and Ch (carrion feeder). These dummy variables indicate the use (1) 
		or  no use (0) of a given diet type by a species.}
		\item{codes}{is a data frame with 129 species, 2 factors : 'forsub' summarizing the feeding place and 
		'diet' the diet type. }
		\item{tax}{is a data frame with 129 species and 3 factors: Genus, Family and Order.
		'tax' is a data frame of class \code{taxo}: the variables are factors giving nested classifications.}
		\item{species.names}{is a vector of the names of species.}
	}
}
\source{
Blondel, J., Vuilleumier, F., Marcus, L.F., and Terouanne, E. (1984).\cr
Is there ecomorphological convergence among mediterranean bird communities of Chile, California, and France.\cr
In \emph{Evolutionary Biology} (eds M.K. Hecht, B. Wallace & R.J. MacIntyre),\cr
141--213, Vol. 18. Plenum Press, New York.
}
\examples{
data(ecomor)
ric <- apply(ecomor$habitat, 2, sum)
s.corcircle(dudi.pca(log(ecomor$morpho), scan = FALSE)$co)

forsub <- data.frame(t(apply(ecomor$forsub, 1, function (x) x/sum(x))))
pca1 <- dudi.pca(forsub, scan = FALSE, scale = FALSE)
s.arrow(pca1$c1)
w <- as.matrix(forsub)%*%as.matrix(pca1$c1)
s.label(w, clab = 0, add.p = TRUE, cpoi = 2)

diet <- data.frame(t(apply(ecomor$diet, 1, function (x) x/sum(x))))
pca2 <- dudi.pca(diet, scan = FALSE, scale = FALSE)
s.arrow(pca2$c1)
w <- as.matrix(diet)%*%as.matrix(pca2$c1)
s.label(w, clab = 0, add.p = TRUE, cpoi = 2)

dmorpho <- dist.quant(log(ecomor$morpho), 3)
dhabitat <- dist.binary(ecomor$habitat, 1)

mantel.randtest(dmorpho, dhabitat)
RV.rtest(pcoscaled(dmorpho), pcoscaled(dhabitat), 999)
procuste.randtest(pcoscaled(dmorpho), pcoscaled(dhabitat))
}
\keyword{datasets}
\eof
\name{elec88}
\alias{elec88}
\docType{data}
\title{Electoral Data}
\description{
This data set gives the results of the presidential election in France in 1988 for each department and all the candidates. 
}
\usage{data(elec88)}
\format{
\code{elec88} is a list of 4 components. 
It is a data frame with 94 rows (departments) and 9 variables (candidates).
    \enumerate{
    \item{res}{is the global result of the election all-over the country.}
    \item{lab}{is the vector of the names of the 94 french departments.}
    \item{area}{is the dataframe of 3 variables returning the boundary lines of each department. 
    The first variable is a factor. The levels of this one are the row.names of tab. 
    The second and third variables return the coordinates (x,y) of the points of the boundary line.}
    }
}
\source{
 Public data
}
\examples{
data(elec88)
apply(elec88$tab, 2, mean)
summary(elec88$res)

par(mfrow = c(2,2))
plot(elec88$area[,2:3], type = "n", asp = 1)
lpoly <- split(elec88$area[,2:3], elec88$area[,1])
lapply(lpoly, function(x) {points (x,type = "l");invisible()})
polygon(elec88$area[elec88$area$V1=="D25", 2:3], col = 1)
area.plot(elec88$area, graph = elec88$neig, lwdg = 1)
polygon(elec88$area[elec88$area$V1=="D25", 2:3], col = 1)
pca1 <- dudi.pca(elec88$tab, scal = FALSE, scan = FALSE)
area.plot(elec88$area, val = elec88$xy[,1] + elec88$xy[,2])
area.plot(elec88$area, val = pca1$li[,1], sub = "F1 PCA", 
    csub = 2, cleg = 1.5)
}
\keyword{datasets}
\eof
\name{escopage}
\alias{escopage}
\docType{data}
\title{K-tables of wine-tasting}
\description{
This data set describes 27 characteristics of 21 wines distributed in four fields : 
rest, visual, olfactory and global. 
}
\usage{data(escopage)}
\format{
	\code{escopage} is a list of 3 components.
	\enumerate{
		\item{tab}{is a data frame with 21 observations (wines) and 27 variables. }
		\item{tab.names}{is the vector of the names of sub-tables : "rest" "visual" "olfactory" "global".}
		\item{blo}{is a vector of the numbers of variables for each sub-table.}
	}
}
\source{
Escofier, B. and Pags, J. (1990)\cr
\emph{Analyses factorielles simples et multiples : objectifs, mthodes et interprtation}\cr
Dunod, Paris. 1--267.\cr\cr
Escofier, B. and Pags, J. (1994)\cr
Multiple factor analysis (AFMULT package).\cr
\emph{Computational Statistics and Data Analysis}, \bold{18}, 121--140.
}
\examples{
data(escopage)
w <- data.frame(scale(escopage$tab))
w <- ktab.data.frame(w, escopage$blo)
names(w)[1:4] <- escopage$tab.names
plot(mfa(w, scan = FALSE))
}
\keyword{datasets}
\eof
\name{euro123}
\alias{euro123}
\docType{data}
\title{Triangular Data}
\description{
This data set gives the proportions of employement in the primary, secondary and tertiary 
sectors for 12 European countries in 1978, 1986 and 1997. 
}
\usage{data(euro123)}
\format{
    \code{euro123} is a list of 4 components.
    \enumerate{
    \item{in78}{is a data frame with 12 rows and 3 variables.}
    \item{in86}{: idem in 1986}
    \item{in97}{: idem in 1997}
    \item{plan}{is a data frame with two factors to both organize the 3 tables.}
    }
}
\source{
Encyclopaedia Universalis, Symposium, Les chiffres du Monde. Encyclopaedia Universalis, Paris. 519.\cr\cr
Universit de Barcelone : \url{http://www.ub.es/medame/nutstat1.html}
}
\examples{
data(euro123)
par(mfrow = c(2,2))
triangle.plot(euro123$in78, addaxes = TRUE)
triangle.plot(euro123$in86, addaxes = TRUE)
triangle.plot(euro123$in97, addaxes = TRUE)
triangle.biplot(euro123$in78, euro123$in97)
}
\keyword{datasets}
\eof
\name{foucart}
\alias{foucart}
\alias{plot.foucart}
\alias{print.foucart}
\title{K-tables Correspondence Analysis with the same rows and the same columns}
\description{
  K tables have the same rows and the same columns.\cr
  Each table is transformed by P=X/sum(X). Average of P is computing.\cr
  A correspondence analysis is realized on this average.\cr
  The initial rows and the initial columns are projected in supplementary elements.
}
\usage{
foucart(X, scannf = TRUE, nf = 2)
plot.foucart(x, xax = 1, yax = 2, clab = 1, csub = 2, possub = "bottomright", \dots) 
print.foucart(x, \dots) 
}
\arguments{
  \item{X}{a list of data frame where the row names and the column names are the same for each table}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  \cr

  \item{x}{an object of class 'foucart'}
  \item{xax}{the column number of the x-axis}
  \item{yax}{the column number of the y-axis}
  \item{clab}{if not NULL, a character size for the labels, used with \code{par("cex")*clab}}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft","topright","bottomleft","bottomright")}
  \item{\dots}{further arguments passed to or from other methods}

}
\value{
  \code{foucart} returns a list of the classes 'dudi', 'coa' and 'foucart'
 	\item{call}{origine}
	\item{nf}{axes-components saved}
	\item{rank}{rank}
	\item{blo}{useful vector}
	\item{cw}{vector: column weights}
	\item{lw}{vector: row weights}
	\item{eig}{vector: eigen values}
	\item{tab}{data.frame: modified array}
	\item{li}{data.frame: row coordinates}
	\item{l1}{data.frame: row normed scores}
	\item{co}{data.frame: column coordinates}
	\item{c1}{data.frame: column normed scores}
	\item{Tli}{data.frame: row coordinates (each table)}
	\item{Tco}{data.frame: col coordinates (each table)}
	\item{TL}{data.frame: factors for Tli}
	\item{TC}{data.frame: factors for Tco}
}
\references{Foucart, T. (1984) \emph{Analyse factorielle de tableaux multiples}, Masson, Paris.
}
\author{P. Bady
}
\examples{
data(bf88)
fou1 <- foucart(bf88, scann = FALSE, nf = 3)
fou1
plot(fou1)

data(meaudret)
l1 <- split(meaudret$fau, meaudret$plan$dat)
l1 <- lapply(l1, function(x) 
    {row.names(x) <- paste("Sta",1:5,sep="");x})
fou2 <- foucart(l1, scan = FALSE)
kplot(fou2, clab.r = 2)
}
\keyword{multivariate}
\eof
\name{friday87}
\alias{friday87}
\docType{data}
\title{Faunistic K-tables}
\description{
This data set gives informations about sites, species and environmental variables
}
\usage{data(friday87)}
\format{
    \code{friday87} is a list of 4 components.
    \enumerate{
    \item{fau}{is a data frame containing a faunistic table with 16 sites and 91 species.}
    \item{mil}{is a data frame with 16 sites and 9 environmental variables.}
    \item{fau.blo}{is a vector of the number of species per group.}
    \item{tab.names}{is the name of each group of species.}
    }
}
\source{
Friday, L.E. (1987) The diversity of macroinvertebrate and macrophyte communities in ponds.,\emph{Freshwater Biology}, \bold{18}, 87--104.
}
\examples{
data(friday87)
wfri <- data.frame(scale(friday87$fau, scal = FALSE))
wfri <- ktab.data.frame(wfri, friday87$fau.blo, 
    tabnames = friday87$tab.names)
kplot(sepan(wfri), clab.r = 2, clab.c = 1)
}
\keyword{datasets}
\eof
\name{fruits}
\alias{fruits}
\docType{data}
\title{Pair of Tables}
\description{
    28 batches of fruits -two types- are judged by two different ways.\cr
    They are classified in order of preference, without ex aequo, by 16 individuals.\cr
    15 quantitative variables described the batches of fruits.\cr
}
\usage{data(fruits)}
\format{
    \code{fruits} is a list of 3 components:
    \enumerate{
    \item{typ}{is a vector returning the type of the 28 batches of fruits (peaches or nectarines).}
    \item{jug}{is a data frame of 28 rows et 16 columns (judges).}
    \item{var}{is a data frame of 28 rows et 16 measures (average of 2 judgements).}
    }
}
\details{
    \code{fruits$var} is a data frame of 15 variables:
    \enumerate{
    \item{1{\_}taches}{: quantity of cork blemishes (0=absent - maximum 5)}
    \item{2{\_}stries}{: quantity of stria (1/none - maximum 4)}
    \item{3{\_}ab{\_}muc}{: abundance of mucron (1/absent - 4)}
    \item{4{\_}ir{\_}for}{: shape irregularity (0/none - 3)}
    \item{5{\_}allong}{: length of the fruit (1/round fruit - 4)}
    \item{6{\_}su{\_}rou}{: percentage of the red surface (minimum 40\% - maximum 90\%)}
    \item{7{\_}ho{\_}lot}{: homogeneity of the intra-batch coloring (1/strong - 4)}
    \item{8{\_}ho{\_}fru}{: homogeneity of the intra-fruit coloring (1/strong - 4)}
    \item{9{\_}pubes}{: pubescence (0/none - 4)}
    \item{10{\_}vert}{: intensity of green in red area (1/none - 4)}
    \item{11{\_}fonc}{: intensity of dark area (0/pink - 4)}
    \item{12{\_}col{\_}mu}{: intensity of the mucron color (1=no contrast - 4/dark)}
    \item{13{\_}impres}{: kind of impression (1/watched - 4/pointill)}
    \item{14{\_}col{\_}dom}{: intensity of the predominating color (0/clear - 4)}
    \item{15{\_}calib}{: grade (1/<90g - 5/>200g)}
    }
}
\source{
Kervella, J. (1991) 
Analyse de l'attrait d'un produit : exemple d'une comparaison de lots de pches. 
Agro-Industrie et mthodes statistiques. 
Compte-rendu des secondes journes europennes. Nantes 13-14 juin 1991 . 
Association pour la Statistique et ses Utilisations, Paris,  313--325.
}
\examples{
data(fruits)
par(mfrow = c(2,2))
pcajug <- dudi.pca(fruits$jug, scann = FALSE)
s.corcircle(pcajug$co)
s.class(pcajug$li, fac = fruits$type)

pcavar <- dudi.pca(fruits$var, scann = FALSE)
s.corcircle(pcavar$co)
s.class(pcavar$li, fac = fruits$type)

par(mfrow = c(1,1))
plot(coinertia(pcajug, pcavar, scan = FALSE))
}
\keyword{datasets}
\eof
\name{granulo}
\alias{granulo}
\docType{data}
\title{Granulometric Curves}
\description{
This data set gives the repartition in diameter classes of deposit samples. 
}
\usage{data(granulo)}
\format{
    \code{granulo} is a list of 2 components.
    \enumerate{
        \item{tab}{contains the 49 deposit samples, 9 diameter classes, weight of grains by size class}
        \item{born}{contains the boundaries of the diameter classes}
    }
}
\source{
Gaschignard-Fossati, O. (1986) Rpartition spatiale des macroinvertbrs benthiques d'un bras vif du Rhne.\cr
Rle des crues et dynamique saisonnire.\cr
Thse de doctorat, Universit Lyon 1.
}
\examples{
data(granulo)
w <- t(apply(granulo$tab, 1, function (x) x / sum(x)))
w <- data.frame(w)
wtr <- data.frame(t(w))
wmoy <- data.frame(matrix(apply(wtr, 1, mean), 1))
d1 <- dudi.pca(w, scal = FALSE, scan = FALSE)
wmoy <- suprow.default(d1, wmoy)$lisup
s.arrow(d1$c1, clab = 1.5)
s.distri(d1$c1, wtr, cstar = 0.33, cell = 0, 
    axesell = FALSE, add.p = TRUE, clab = 0.75)
s.label(wmoy, cpoi = 5, clab = 0, add.p = TRUE)
}
\keyword{datasets}
\eof
\name{housetasks}
\alias{housetasks}
\docType{data}
\title{Contingency Table}
\description{
The \code{housetasks} data frame gives 13 housetasks and their repartition in the couple. 
}
\usage{data(housetasks)}
\format{
  This data frame contains four columns : wife, alternating, husband and jointly.
  Each column is a numeric vector. 
}
\source{
Kroonenberg, P. M. and Lombardo, R. (1999)\cr
Nonsymmetric correspondence analysis: a tool for analysing contingency tables with a dependence structure.\cr
\emph{Multivariate Behavioral Research}, \bold{34}, 367--396
}
\examples{
data(housetasks)
nsc1 <- dudi.nsc(housetasks, scan = FALSE)
s.label(nsc1$c1, clab = 1.25)
s.arrow(nsc1$li, add.pl = TRUE, clab = 0.75) 
}
\keyword{datasets}
\eof
\name{ichtyo}
\alias{ichtyo}
\docType{data}
\title{Point sampling of fish community}
\description{
This data set gives informations between a faunistic array, 
the total number of sampling points made at each sampling occasion and 
the year of the sampling occasion. 
}
\usage{data(ichtyo)}
\format{
    \code{ichtyo} is a list of 3 components.
    \enumerate{
    \item{tab}{is a faunistic array with 9 columns and 32 rows.}
    \item{eff}{is a vector of the 32 sampling effort.}
    \item{dat}{is a factor where the levels are the 10 years of the sampling occasion.}
    }
}
\details{
    The value n(i,j) at the ith row and the jth column in \code{tab} corresponds to the number of sampling
    points of the ith sampling occasion (in \code{eff}) that contains the jth species.
}
\source{
Doldec, S., Chessel, D. and Olivier, J. M. (1995)\cr
L'analyse des correspondances dcentre: application aux peuplements ichtyologiques du haut-Rhne.\cr
\emph{Bulletin Franais de la Pche et de la Pisciculture}, \bold{336}, 29--40.
}
\examples{
data(ichtyo)
dudi1 <- dudi.dec(ichtyo$tab, ichtyo$eff, scan = FALSE)
s.class(dudi1$li, ichtyo$dat, wt = ichtyo$eff / sum(ichtyo$eff))
}
\keyword{datasets}
\eof
\name{inertia.dudi}
\alias{inertia.dudi}
\title{Statistics of inertia in a one-table analysis}
\description{
Prints of the statistics of inertia in a one-table analysis
}
\usage{
inertia.dudi(dudi, row.inertia = FALSE, col.inertia = FALSE)
}
\arguments{
  \item{dudi}{a duality diagram, object of class \code{dudi}}
  \item{row.inertia}{if TRUE, returns the statistics of the decomposition of inertia for the rows}
  \item{col.inertia}{if TRUE, returns the statistics of the decomposition of inertia for the columns}
}
\value{
a list containing :
\item{TOT}{repartition of the total inertia between axes}
\item{row.abs}{absolute contributions of the decomposition of inertia for the rows}
\item{row.rel}{relative contributions of the decomposition of inertia for the rows}
\item{row.cum}{cumulative relative contributions of the decomposition of inertia for the rows}
\item{col.abs}{absolute contributions of the decomposition of inertia for the columns}
\item{col.rel}{relative contributions of the decomposition of inertia for the columns}
\item{col.cum}{cumulative relative contributions of the decomposition of inertia for the columns}
}
\references{
Lebart, L., Morineau, A. and Tabart, N. (1977) \emph{Techniques de la description statistique, mthodes et logiciels pour la description des grands tableaux}, Dunod, Paris, 61--62.\cr\cr
Volle, M. (1981) \emph{Analyse des donnes}, Economica, Paris, 89--90 and 118\cr\cr
Lebart, L., Morineau, L. and Warwick, K.M. (1984) \emph{Multivariate descriptive analysis: correspondence and related techniques for large matrices}, John Wiley and Sons, New York.\cr\cr
Greenacre, M. (1984) \emph{Theory and applications of correspondence analysis}, Academic Press, London, 66.\cr\cr
Rouanet, H. and Le Roux, B. (1993) \emph{Analyse des donnes multidimensionnelles},  Dunod, Paris, 143--144.\cr\cr
Tenenhaus, M. (1994) \emph{Mthodes statistiques en gestion},  Dunod, Paris, p. 160, 161, 166, 204.\cr\cr
Lebart, L., Morineau, A. and Piron, M. (1995) \emph{Statistique exploratoire multidimensionnelle}, Dunod, Paris,  p. 56,95-96.\cr
}
\details{Contributions are printed in 1/10000 and the sign is the sign of the coordinate
}
\examples{
data(housetasks)
coa1 <- dudi.coa(housetasks, scann = FALSE)
inertia.dudi(coa1, col = TRUE, row = FALSE)$col.rel
}
\keyword{multivariate}
\eof
\name{irishdata}
\alias{irishdata}
\docType{data}
\title{Geary's Irish Data}
\description{
This data set contains geographic informations about 25 counties of Ireland. 
}
\usage{data(irishdata)}
\format{
    \code{irishdata} is a list of 5 components.
    \enumerate{
    \item{area}{is a data frame with polygons for each of the 25 contiguous counties.}
    \item{county.names}{is a vector with the names of the 25 counties.}
    \item{xy}{is a data frame with the coordinates centers of the 25 counties.}
    \item{tab}{is a data frame with 25 rows (counties) and 12 variables.}
    \item{contour}{is a data frame with the global polygon of all the 25 counties.}
    }
}
\source{
Geary, R.C. (1954) The contiguity ratio and statistical mapping.\cr
\emph{The incorporated Statistician}, \bold{5}, 3, 115--145.\cr\cr
Cliff, A.D. and Ord, J.K. (1973) \emph{Spatial autocorrelation}, Pion, London. 1--178.
}
\examples{
data(irishdata)
par(mfrow = c(2,2))
area.plot(irishdata$area, lab = irishdata$county.names, clab = 0.75)
area.plot(irishdata$area)
apply(irishdata$contour, 1, function(x) segments(x[1],x[2],x[3],x[4], 
    lwd = 3))
s.corcircle(dudi.pca(irishdata$tab, scan = FALSE)$co)
score <- dudi.pca(irishdata$tab, scan = FALSE, nf = 1)$li$Axis1
names(score) <- row.names(irishdata$tab)
area.plot(irishdata$area, score)
}
\keyword{datasets}
\eof
\name{is.euclid}
\alias{is.euclid}
\alias{summary.dist}
\alias{mat2dist}
\alias{dist2mat}
\title{Is a Distance Matrix Euclidean ?}
\description{
Confirmation of the Euclidean nature of a distance matrix by the Gower's theorem.\cr
is.euclid is used in summary.dist.\cr
mat2dist and dist2mat are local copies of as.dist and as.matrix.dist of mva.
}
\usage{
is.euclid(distmat, plot = FALSE, print = FALSE, tol = 1e-07)
summary.dist(object, \dots)
}
\arguments{
  \item{distmat}{an object of class 'dist'}
  \item{plot}{a logical value indicating whether the eigenvalues bar plot of the matrix of the term \eqn{-\frac{1}{2} {d_{ij}^2}}{-1/2 dij} centred by rows and columns should be diplayed}
  \item{print}{a logical value indicating whether the eigenvalues of the matrix of the term \eqn{-\frac{1}{2} {d_{ij}^2}}{-1/2 dij} centred by rows and columns should be printed}
  \item{tol}{a tolerance threshold : an eigenvalue is considered positive if it is larger than \code{-tol*lambda1} where \code{lambda1} is the largest eigenvalue.}
  \item{object}{an object of class 'dist'}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
returns a logical value indicating if all the eigenvalues are positive or equal to zero
}
\references{Gower, J.C. and Legendre, P. (1986) Metric and Euclidean properties of dissimilarity coefficients. \emph{Journal of Classification}, \bold{3}, 5--48.
}
\examples{
w <- matrix(runif(10000), 100, 100)
w <- dist(w)
summary(w)
is.euclid (w) # TRUE
w <- quasieuclid(w) # no correction need in: quasieuclid(w)
w <- lingoes(w) # no correction need in: lingoes(w)
w <- cailliez(w) # no correction need in: cailliez(w)
rm(w)
}
\keyword{array}
\eof
\name{jv73}
\alias{jv73}
\docType{data}
\title{K-tables Multi-Regions}
\description{
This data set gives physical and physico-chemical variables, fish species, spatial coordinates about 92 sites. 
}
\usage{data(jv73)}
\format{
    \code{jv73} is a list of 6 components.
    \enumerate{
    \item{morpho}{is a data frame with 92 sites and 6 physical variables.}
    \item{phychi}{is a data frame with 92 sites and 12 physico-chemical variables.}
    \item{poi}{is a data frame with 92 sites and 19 fish species.}
    \item{xy}{is a data frame with 92 sites and 2 spatial coordinates.}
    \item{contour}{is a data frame for mapping.}
    \item{fac.riv}{is a factor distributing the 92 sites on 12 rivers.}
    }
}
\source{
Verneaux, J. (1973) Cours d'eau de Franche-Comt (Massif du Jura).\cr
Recherches cologiques sur le rseau hydrographique du Doubs.\cr
Essai de biotypologie. Thse d'tat, Besanon.
}
\examples{
data(jv73)
s.label(jv73$xy, contour = jv73$contour, incl = FALSE, 
    clab = 0.75)
s.class(jv73$xy, jv73$fac.riv, add.p = TRUE, cell = 0,
    axese = FALSE, csta = 0, cpoi = 0, clab = 1.25)

w <- split(jv73$morpho, jv73$fac.riv)
w <- lapply(w, function(x) t(dudi.pca(x, scann = FALSE)))
w <- ktab.list.dudi(w)
kplot(sepan(w), perm = TRUE, clab.r = 0, clab.c = 2, show = FALSE)
}
\keyword{datasets}
\eof
\name{kplot}
\alias{kplot}
\title{Generic Function for Multiple Graphs in a K-tables Analysis}
\description{
	Methods for \code{foucart}, \code{mcoa}, \code{mfa}, \code{pta}, \code{sepan}, \code{sepan.coa} and \code{statis}
}
\usage{
kplot(object, ...)
}
\arguments{
  \item{object}{an object used to select a method}
  \item{\dots}{further arguments passed to or from other methods}
}
\examples{
methods(plot)
methods(scatter)
methods(kplot)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{kplot.foucart}
\alias{kplot.foucart}
\title{Multiple Graphs for the Foucart's Correspondence Analysis}
\description{
performs high level plots of a Foucart's Correspondence Analysis, 
using an object of class \code{foucart}.  
}
\usage{
kplot.foucart(object, xax = 1, yax = 2, mfrow = NULL, 
    which.tab = 1:length(fouc$blo), clab.r = 1, clab.c = 1.25, 
    csub = 2, possub = "bottomright", \dots)
}
\arguments{
  \item{object}{an object of class \code{foucart} }
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{mfrow}{a vector of the form 'c(nr,nc)', otherwise computed by as special own function \code{n2mfrow}}
  \item{which.tab}{vector of table numbers for analyzing}
  \item{clab.r}{a character size for the row labels}
  \item{clab.c}{a character size for the column labels}
  \item{csub}{a character size for the sub-titles used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{\dots}{further arguments passed to or from other methods}
}
\examples{
data(bf88)
fou1 <- foucart(bf88, scann = FALSE, nf = 3)
kplot(fou1, clab.r = 0, clab.c = 2, csub = 3)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{kplot.mcoa}
\alias{kplot.mcoa}
\title{Multiple Graphs for a Multiple Co-inertia Analysis}
\description{
performs high level plots of a Multiple Co-inertia Analysis, 
using an object of class \code{mcoa}. 
}
\usage{
kplot.mcoa(object, xax = 1, yax = 2, which.tab = 1:nrow(mcoa$cov2), 
    mfrow = NULL, option = c("points", "axis", "columns"), 
    clab = 1, cpoint = 2, csub = 2, possub = "bottomright",\dots)
}
\arguments{
  \item{object}{an object of class \code{mcoa}}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{which.tab}{a numeric vector containing the numbers of the tables to analyse}
  \item{mfrow}{a vector of the form 'c(nr,nc)', otherwise computed by as special own function \code{n2mfrow}}
  \item{option}{a string of characters for the drawing option
	  \item{"points"}{plot of the projected scattergram onto the co-inertia axes}
	  \item{"axis"}{projections of inertia axes onto the co-inertia axes.}
	  \item{"columns"}{projections of variables onto the synthetic variables planes.}
  }
  \item{clab}{a character size for the labels}
  \item{cpoint}{a character size for plotting the points, used with \code{par("cex")}*cpoint. If zero, no points are drawn.}
  \item{csub}{a character size for the sub-titles, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{\dots}{further arguments passed to or from other methods}
}
\examples{
data(friday87)
w1 <- data.frame(scale(friday87$fau, scal = FALSE))
w2 <- ktab.data.frame(w1, friday87$fau.blo, 
    tabnames = friday87$tab.names)
mcoa1 <- mcoa(w2, "lambda1", scan = FALSE)
kplot(mcoa1, clab = 2, csub = 2, cpoi = 3, opt = "axis")

kplot(mcoa1, mfrow = c(3,4), clab = 2, csub = 3, cpoi = 3)

kplot(mcoa1, clab = 2, csub = 3, cpoi = 3, mfrow = c(3,4), 
    opt = "columns")
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{kplot.mfa}
\alias{kplot.mfa}
\title{Multiple Graphs for a Multiple Factorial Analysis}
\description{
performs high level plots of a Multiple Factorial Analysis, 
using an object of class \code{mfa}. 
}
\usage{
kplot.mfa(object, xax = 1, yax = 2, mfrow = NULL, 
    which.tab = 1:length(afm$blo), row.names = FALSE, col.names = TRUE, 
    traject = FALSE, permute.row.col = FALSE, 
    clab = 1, csub = 2, possub = "bottomright", \dots)
}
\arguments{
  \item{object}{an object of class \code{mfa}}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{mfrow}{a vector of the form 'c(nr,nc'), otherwise computed by a special own function \code{n2mfrow}}
  \item{which.tab}{vector of the numbers of tables used for the analysis}
  \item{row.names}{a logical value indicating whether the row labels should be inserted}
  \item{col.names}{a logical value indicating whether the column labels should be inserted}
  \item{traject}{a logical value indicating whether the trajectories of the rows should be drawn in a natural order}
  \item{permute.row.col}{if TRUE, the rows are represented by vectors and columns by points, otherwise it is the opposite}
  \item{clab}{a character size for the labels}
  \item{csub}{a character size for the sub-titles, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{\dots}{further arguments passed to or from other methods}
}
\examples{
data(friday87)
w1 <- data.frame(scale(friday87$fau, scal = FALSE))
w2 <- ktab.data.frame(w1, friday87$fau.blo, 
    tabnames = friday87$tab.names)
mfa1 <- mfa(w2, scann = FALSE)
kplot(mfa1)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{kplot.pta}
\alias{kplot.pta}
\title{Multiple Graphs for a Partial Triadic Analysis}
\description{
performs high level plots of a Partial Triadic Analysis, 
using an object of class \code{pta}. 
}
\usage{
kplot.pta(object, xax = 1, yax = 2, which.tab = 1:nrow(atp$RV), 
    mfrow = NULL, which.graph = 1:4, clab = 1, cpoint = 2, csub = 2, 
    possub = "bottomright", ask = par("ask"), ...)
}
\arguments{
  \item{object}{an object of class \code{pta}}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{which.tab}{a numeric vector containing the numbers of the tables to analyse}
  \item{mfrow}{parameter of the array of figures to be drawn, otherwise the graphs associated to a table are drawn on the same row}
 \item{which.graph}{an option for drawing, an integer between 1 and 4. For each table of which.tab, are drawn :
	  \item{1}{the projections of the principal axes}
	  \item{2}{the projections of the rows}
	  \item{3}{the projections of the columns}
	  \item{4}{the projections of the principal components onto the planes of the compromise}
  }
  \item{clab}{a character size for the labels}
  \item{cpoint}{a character size for plotting the points, used with \code{par("cex")}*cpoint. If zero, no points are drawn.}
  \item{csub}{a character size for the sub-titles, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{ask}{a logical value indicating if the graphs requires several arrays of figures}
  \item{\dots}{further arguments passed to or from other methods}
}
\examples{
data(meaudret)
wit1 <- within(dudi.pca(meaudret$fau, scan = FALSE, scal = FALSE), 
    meaudret$plan$dat, scan = FALSE)
kta1 <- ktab.within(wit1, colnames = rep(c("S1","S2","S3","S4","S5"), 4))
kta2 <- t(kta1) ; pta1 <- pta(kta2, scann = FALSE)
kplot(pta1, clab = 1.5, csub = 3)
kplot(pta1, clab = 1.5, csub = 3, which.graph = 3, mfrow = c(2,2))
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{kplot.sepan}
\alias{kplot.sepan}
\alias{kplot.sepan.coa}
\title{Multiple Graphs for Separed Analyses in a K-tables}
\description{
performs high level plots for Separed Analyses in a K-tables, 
using an object of class \code{sepan}. 
}
\usage{
kplot.sepan(object, xax = 1, yax = 2, which.tab = 1:length(sep$blo), 
    mfrow = NULL, permute.row.col = FALSE, clab.row = 1, 
    clab.col = 1.25, traject.row = FALSE, csub = 2, 
    possub = "bottomright", show.eigen.value = TRUE,\dots)

kplot.sepan.coa (object, xax = 1, yax = 2, which.tab = 1:length(sep$blo), 
    mfrow = NULL, permute.row.col = FALSE, clab.row = 1, 
    clab.col = 1.25, csub = 2, possub = "bottomright", 
    show.eigen.value = TRUE, poseig = c("bottom", "top"), \dots)
}
\arguments{
  \item{object}{an object of class \code{sepan}}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{which.tab}{a numeric vector containing the numbers of the tables to analyse}
  \item{mfrow}{parameter for the array of figures to be drawn, otherwise use n2mfrow}
  \item{permute.row.col}{if TRUE the rows are represented by arrows and the columns by points, if FALSE it is the opposite}
  \item{clab.row}{a character size for the row labels}
  \item{clab.col}{a character size for the column labels}
  \item{traject.row}{a logical value indicating whether the trajectories between rows should be drawn in a natural order}
  \item{csub}{a character size for the sub-titles, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{show.eigen.value}{a logical value indicating whether the eigenvalues bar plot should be drawn}
  \item{poseig}{if "top" the eigenvalues bar plot is upside, if "bottom", it is downside}
  \item{\dots}{further arguments passed to or from other methods}
}
\details{
\code{kplot.sepan} superimposes the points for the rows and the arrows for the columns using an adapted rescaling such as the scatter.dudi.\cr
\code{kplot.sepan.coa} superimposes the row coordinates and the column coordinates with the same scale.
}
\examples{
data(escopage)
w <- data.frame(scale(escopage$tab))
w <- ktab.data.frame(w, escopage$blo, tabnames = escopage$tab.names)
sep1 <- sepan(w)
kplot(sep1, show = FALSE)

data(friday87)
w <- data.frame(scale(friday87$fau, scal = FALSE))
w <- ktab.data.frame(w, friday87$fau.blo, tabnames = friday87$tab.names)
kplot(sepan(w), clab.r = 1.25, clab.c = 0, csub = 3)

data(microsatt)
w <- dudi.coa(data.frame(t(microsatt$tab)), scann = FALSE)
loci.fac <- factor(rep(microsatt$loci.names, microsatt$loci.eff))
wit <- within(w, loci.fac, scann = FALSE)
microsatt.ktab <- ktab.within(wit)
kplot.sepan.coa(sepan(microsatt.ktab), show = FALSE, clab.c = 0, 
    mfrow = c(3,3), clab.r = 1.5)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{kplot.statis}
\alias{kplot.statis}
\title{Multiple Graphs of a STATIS Analysis}
\description{
performs high level plots for a STATIS analysis, 
using an object of class \code{statis}. 
}
\usage{
kplot.statis(object, xax = 1, yax = 2, mfrow = NULL, 
    which.tab = 1:length(x$tab.names), clab = 1.5, cpoi = 2, 
    traject = FALSE, arrow = TRUE, class = NULL, 
    unique.scale = FALSE, csub = 2, possub = "bottomright",\dots)
}
\arguments{
  \item{object}{an object of class \code{statis}}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{mfrow}{parameter for the array of figures to be drawn}
  \item{which.tab}{a numeric vector containing the numbers of the tables to analyse}
  \item{clab}{a character size for the labels}
  \item{cpoi}{the size of points}
  \item{traject}{a logical value indicating whether the trajectories should be drawn in a natural order}
  \item{arrow}{a logical value indicating whether the column factorial diagrams should be plotted}
  \item{class}{if not NULL, a factor of length equal to the number of the total columns of the K-tables}
  \item{unique.scale}{if TRUE, all the arrays of figures have the same scale}
  \item{csub}{a character size for the labels of the arrays of figures used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{\dots}{further arguments passed to or from other methods}
}
\examples{
data(jv73)
dudi1 <- dudi.pca(jv73$poi, scann = FALSE, scal = FALSE)
wit1 <- within(dudi1, jv73$fac.riv, scann = FALSE)
kta3 <- ktab.within(wit1)
data(jv73)
statis3 <- statis(kta3, scann = FALSE)
kplot(statis3, traj = TRUE, arrow = FALSE, unique = TRUE, 
    clab = 0, csub = 3, cpoi = 3)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{ktab}
\alias{ktab}
\alias{is.ktab}
\alias{c.ktab}
\alias{[.ktab}
\alias{print.ktab}
\alias{t.ktab}
\alias{row.names.ktab}
\alias{row.names<-.ktab}
\alias{col.names}
\alias{col.names.ktab}
\alias{col.names<-}
\alias{col.names<-.ktab}
\alias{tab.names}
\alias{tab.names.ktab}
\alias{tab.names<-}
\alias{tab.names<-.ktab}
\alias{ktab.util.names}
\alias{ktab.util.addfactor<-}
\title{the class of objects 'ktab' (K-tables)}
\description{
an object of class 'ktab' is a list of data frame with the same row.names in common.\cr
a list of class 'ktab' contains moreover :
 \item{blo}{: the vector of the numbers of columns for each table}
 \item{lw}{: the vector of the row weightings in common for all tables}
 \item{cw}{: the vector of the column weightings}
 \item{TL}{: a data frame of two components to manage the parameter positions associated with the rows of tables}
 \item{TC}{: a data frame of two components to manage the parameter positions associated with the columns of tables}
 \item{T4}{: a data frame of two components to manage the parameter positions of 4 components associated to an array}
}
\usage{
c.ktab (...)
object [selection]
is.ktab(x)
t.ktab(x)
row.names.ktab(x)
col.names.ktab(x)
tab.names(x)
col.names(x)
ktab.util.names(x)
}
\arguments{
  \item{x}{an object of the class 'ktab'}
  \item{\dots}{a sequence of objects of the class 'ktab'}
  \item{selection}{an integer vector}
}
\details{
A 'ktab' object can be created with :\cr
	a list of data frame : \code{\link{ktab.list.df}}\cr
	a list of 'dudi' objects : \code{\link{ktab.list.dudi}}\cr
	a data.frame : \code{\link{ktab.data.frame}}\cr
	an object 'within' : \code{\link{ktab.within}}\cr
}
\value{
\code{c.ktab} returns an object 'ktab'. It concatenates K-tables with the same rows in common. \cr
\code{t.ktab} returns an object 'ktab'. It permutes each data frame into a K-tables. All tables have the same column names and the same column weightings (a data cube). \cr
\code{"["} returns an object 'ktab'. It allowes to select some arrays in a K-tables. \cr
\code{is.ktab} returns TRUE if x is a K-tables. \cr
\code{row.names} returns the vector of the row names common with all the tables of a K-tables and allowes to modifie them.\cr
\code{col.names} returns the vector of the column names of a K-tables and allowes to modifie them.\cr
\code{tab.names} returns the vector of the array names of a K-tables and allowes to modifie them.\cr
\code{ktab.util.names} is a useful function.
}
\examples{
data(friday87)
wfri <- data.frame(scale(friday87$fau, scal = FALSE))
wfri <- ktab.data.frame(wfri, friday87$fau.blo)
wfri[2:4]
c(wfri[2:4], wfri[5])

data(meaudret)
wit1 <- within.pca(meaudret$mil, meaudret$plan$dat, scan = FALSE, 
    scal = "partial")
kta1 <- ktab.within(wit1, colnames = rep(c("S1","S2","S3","S4","S5"), 4))
kta2 <- t(kta1)
kplot(sepan(kta2), clab.r = 1.5, clab.c = 0.75)
}
\keyword{multivariate}
\eof
\name{ktab.data.frame}
\alias{ktab.data.frame}
\title{Creation of K-tables from a data frame}
\description{
creates K tables from a data frame. 
}
\usage{
ktab.data.frame(df, blocks, rownames = NULL, colnames = NULL, 
    tabnames = NULL, w.row = rep(1, nrow(df)) / nrow(df), 
    w.col = rep(1, ncol(df)))
}
\arguments{
  \item{df}{a data frame}
  \item{blocks}{an integer vector for which the sum must be the number of variables of df. Its length is the number of arrays of the K-tables}
  \item{rownames}{the row names of the K-tables (otherwise the row names of df)}
  \item{colnames}{the column names of the K-tables (otherwise the column names of df)}
  \item{tabnames}{the names of the arrays of the K-tables (otherwise "Ana1", "Ana2", \dots)}
  \item{w.row}{a vector of the row weightings}
  \item{w.col}{a vector of the column weightings}
}
\value{
returns a list of class 'ktab'. See \code{\link{ktab}}.
}
\examples{
data(escopage)
wescopage <- data.frame(scalewt(escopage$tab))
wescopage <- ktab.data.frame(wescopage, escopage$blo,
		tabnames = escopage$tab.names)
plot(sepan(wescopage))
data(friday87)
w <- data.frame(scale(friday87$fau, scal = FALSE))
w <- ktab.data.frame(w, friday87$fau.blo, tabnames = friday87$tab.names)
kplot(sepan(w))
}
\keyword{multivariate}
\eof
\name{ktab.list.df}
\alias{ktab.list.df}
\title{Creating a K-tables from a list of data frame.
}
\description{
creates a list of class \code{ktab} from a list of data frame 
}
\usage{
ktab.list.df(obj, rownames = NULL, colnames = NULL, tabnames = NULL, 
    w.row = rep(1, nrow(obj[[1]])), w.col = lapply(obj, function(x) 
    rep(1 / ncol(x), ncol(x))))
}
\arguments{
  \item{obj}{a list of data frame}
  \item{rownames}{the names of the K-tables rows (otherwise, the row names of the arrays)}
  \item{colnames}{the names of the K-tables columns (otherwise, the column names of the arrays)}
  \item{tabnames}{the names of the arrays of the K-tables (otherwise, the names of the obj if they exist, or else "Ana1", "Ana2", \dots)}
  \item{w.row}{a vector of the row weightings in common with all the arrays}
  \item{w.col}{a list of the vector of the column weightings for each array}
}
\details{
Each element of the initial list have to possess the same names and row numbers
}
\value{
returns a list of class 'ktab'. See \code{\link{ktab}}
}
\examples{
data(jv73)
l0 <- split(jv73$morpho, jv73$fac.riv)
l0 <- lapply(l0, function(x) data.frame(t(scalewt(x))))
kta <- ktab.list.df(l0)
kplot(sepan(kta[c(2,5,7,10)]), perm = TRUE, clab.r = 1, clab.c = 1.5)
}
\keyword{multivariate}
\eof
\name{ktab.list.dudi}
\alias{ktab.list.dudi}
\title{Creation of a K-tables from a list of duality diagrams}
\description{
creates a list of class \code{ktab} from a list of duality diagrams. 
}
\usage{
ktab.list.dudi(obj, rownames = NULL, colnames = NULL, tabnames = NULL)
}
\arguments{
  \item{obj}{a list of objects of class 'dudi'. Each element of the list must have the same row names for \code{$tab} and even for \code{$lw}}
  \item{rownames}{the row names of the K-tables (otherwise the row names of the \code{$tab})}
  \item{colnames}{the column names of the K-tables (otherwise the column names of the \code{$tab})}
  \item{tabnames}{the names of the arrays of the K-tables (otherwise the names of the \code{obj}  if they exist, or else "Ana1", "Ana2", \dots)}
}
\value{
returns a list of class 'ktab'. See \code{\link{ktab}}
}
\examples{
data(euro123)
pca1 <- dudi.pca(euro123$in78, scale = FALSE, scann = FALSE)
pca2 <- dudi.pca(euro123$in86, scale = FALSE, scann = FALSE)
pca3 <- dudi.pca(euro123$in97, scale = FALSE, scann = FALSE)
ktabeuro <- ktab.list.dudi(list(pca1, pca2, pca3), 
    tabnames = c("1978","1986","1997"))
kplot(sepan(ktabeuro), mfr = c(2,2), clab.c = 1.5)

data(meaudret)
w1 <- split(meaudret$mil,meaudret$plan$dat)
ll <- lapply(w1, dudi.pca, scann = FALSE)
kta <- ktab.list.dudi(ll, rownames <- paste("Station", 1:5, sep=""))
kplot(sepan(kta), clab.r = 1.5, clab.c = 0.75)

data(jv73)
w <- split(jv73$poi, jv73$fac.riv)
wjv73poi <- lapply(w, dudi.pca, scal = FALSE, scan = FALSE)
wjv73poi <- lapply(wjv73poi, t)
wjv73poi <- ktab.list.dudi(wjv73poi)
kplot(sepan(wjv73poi), permut = TRUE, traj = TRUE)
}
\keyword{multivariate}
\eof
\name{ktab.match2ktabs}
\alias{ktab.match2ktabs}
\title{STATIS and Co-Inertia : Analysis of a series of paired ecological tables}
\description{
Prepares the analysis of a series of paired ecological tables. Partial Triadic
Analysis (see \code{\link{pta}}) can be used thereafter to perform the analysis of this k-table.
}
\usage{
ktab.match2ktabs(KTX, KTY)
}
\arguments{
  \item{KTX}{an objet of class 'ktab'}
  \item{KTY}{an objet of class 'ktab'}
}
\value{
a list of class 'ktab', subclass 'kcoinertia'. See \code{\link{ktab}}
}
\references{
Thioulouse J., Simier M. and Chessel D. (2003). Simultaneous analysis of a sequence of paired ecological tables.  \emph{Ecology} (in press). \cr\cr
Simier, M., Blanc L., Pellegrin F., and Nandris D. (1999). Approche simultane de K couples de tableaux : Application a l'tude des relations pathologie vgtale - environnement. \emph{Revue de Statistique Applique}, \bold{47}, 31-46.
}
\section{WARNING }{
IMPORTANT : \code{KTX} and \code{KTY} must have the same k-tables structure, the same number
of columns, and the same column weights.
}
\examples{
data(meau)
wit1 <- within.pca(meau$mil, meau$plan$dat, scan = FALSE, scal = "total")
pcafau <- dudi.pca(meau$fau, scale = FALSE, scan = FALSE, nf = 2)
wit2 <- within(pcafau, meau$plan$dat, scan = FALSE, nf = 2)
kta1 <- ktab.within(wit1, colnames = rep(c("S1","S2","S3","S4","S5","S6"), 4))
kta2 <- ktab.within(wit2, colnames = rep(c("S1","S2","S3","S4","S5","S6"), 4))
kcoi <- ktab.match2ktabs(kta1, kta2)
ptacoi <- pta(kcoi, scan = FALSE, nf = 2)
plot(ptacoi)
kplot(ptacoi)
}
\keyword{multivariate}
\eof
\name{ktab.within}
\alias{ktab.within}
\title{Process to go from a Within Analysis to a K-tables}
\description{
performs the process to go from a Within Analysis to a K-tables. 
}
\usage{
ktab.within(dudiwit, rownames = NULL, colnames = NULL, tabnames = NULL)
}
\arguments{
  \item{dudiwit}{an objet of class 'within'}
  \item{rownames}{the row names of the K-tables (otherwise the row names of \code{dudiwit$tab})}
  \item{colnames}{the column names of the K-tables (otherwise the column names of \code{dudiwit$tab})}
  \item{tabnames}{the names of the arrays of the K-tables (otherwise the levels of the factor which defines the within-classes)}
}
\value{
a list of class 'ktab'. See \code{\link{ktab}}
}
\examples{
data(bacteria)
w1 <- data.frame(t(bacteria$espcodon))
dudi1 <- dudi.coa(w1, scann = FALSE, nf = 4)
wit1 <- within(dudi1, bacteria$code, scannf = FALSE)
kta1 <- ktab.within(wit1)
plot(statis(kta1, scann = FALSE))

kta2 <- kta1[kta1$blo>3]
kplot(mfa(kta2, scann = FALSE))
}
\keyword{multivariate}
\eof
\name{lascaux}
\alias{lascaux}
\docType{data}
\title{Genetic/Environment and types of variables}
\description{
This data set gives meristic, genetic and morphological data frame 
for 306 trouts.  
}
\usage{data(lascaux)}
\format{
	\code{lascaux} is a list of 9 components.
	\enumerate{
		\item{riv}{is a factor returning the river where 306 trouts are captured}
		\item{code}{vector of characters : code of the 306 trouts}
		\item{sex}{factor sex of the 306 trouts}
		\item{meris}{data frame 306 trouts - 5 meristic variables}
		\item{tap}{data frame of the total number of red and black points}
		\item{gen}{factor of the genetic code of the 306 trouts}
		\item{morpho}{data frame 306 trouts 37 morphological variables}
		\item{colo}{data frame 306 trouts 15 variables of coloring}
		\item{ornem}{data frame 306 trouts 15 factors (ornementation)}
	}
}
\source{
Lascaux, J.M. (1996)\cr
Analyse de la variabilit morphologique de la truite commune (Salmo trutta L.) dans les cours d'eau du bassin pyrnen mditerranen.\cr
Thse de doctorat en sciences agronomiques, INP Toulouse.
}
\examples{
data(lascaux)
par(mfrow = c(2,2))
barplot(dudi.pca(lascaux$meris, scan = FALSE)$eig)
title(main = "Meristic")
barplot(dudi.pca(lascaux$colo, scan = FALSE)$eig)
title(main = "Coloration")
barplot(dudi.pca(na.omit(lascaux$morpho), scan = FALSE)$eig)
title(main = "Morphometric")
barplot(dudi.acm(na.omit(lascaux$orne), scan = FALSE)$eig)
title(main = "Ornemental")
}
\keyword{datasets}
\eof
\name{lingoes}
\alias{lingoes}
\title{Transformation of a Distance Matrix for becoming Euclidean}
\description{
transforms a distance matrix in an Euclidean one. 
}
\usage{
lingoes(distmat, print = FALSE)
}
\arguments{
  \item{distmat}{an object of class 'dist'}
  \item{print}{if TRUE, prints the eigenvalues of the matrix}
}
\value{
returns an object of class 'dist' with an Euclidean distance
}
\references{Lingoes, J.C. (1971) Some boundary conditions for a monotone analysis of symmetric matrices. 
\emph{Psychometrika}, \bold{36}, 195--203. 
}
\details{
 The function uses the smaller positive constant k which transforms the matrix of \eqn{\sqrt{d_{ij}^2 + 2 \ast k}}{sqrt(dij + 2*k)} in an Euclidean one
}
\examples{
data(capitales)
d0 <- as.dist(capitales$df)
is.euclid(d0) # FALSE
d1 <- lingoes(d0, TRUE)
# Lingoes constant = 2120982
is.euclid(d1) # TRUE
plot(d0, d1)
x0 <- sort(unclass(d0))
lines(x0, sqrt(x0^2 + 2 * 2120982), lwd = 3)
 
is.euclid(sqrt(d0^2 + 2 * 2120981), tol = 1e-10) # FALSE
is.euclid(sqrt(d0^2 + 2 * 2120982), tol = 1e-10) # FALSE
is.euclid(sqrt(d0^2 + 2 * 2120983), tol = 1e-10) 
    # TRUE the smaller constant
}
\keyword{array}
\keyword{multivariate}
\eof
\name{macaca}
\alias{macaca}
\docType{data}
\title{Landmarks}
\description{
This data set gives the landmarks of a macaca at the ages of 0.9 and 5.77 years. 
}
\usage{data(macaca)}
\format{
    \code{macaca} is a list of 2 components.
    \enumerate{
    \item{xy1}{is a data frame with 72 points and 2 coordinates.}
    \item{xy2}{is a data frame with 72 points and 2 coordinates.}
    }
}
\source{
Olshan, A.F., Siegel, A.F. and Swindler, D.R. (1982)\cr
Robust and least-squares orthogonal mapping: Methods for the study of cephalofacial form and growth.\cr
\emph{American Journal of Physical Anthropology}, \bold{59}, 131--137.
}
\examples{
data(macaca)
par(mfrow = c(2,2))
s.match(macaca$xy1, macaca$xy2, clab = 0)
pro1 <- procuste(macaca$xy1, macaca$xy2, scal = FALSE)
s.match(pro1$tab1, pro1$rot2, clab = 0.7)
s.match(pro1$tab2, pro1$rot1, clab = 0.7)
pro2 <- procuste(macaca$xy1, macaca$xy2)
s.match(pro2$tab2, pro2$rot1, clab = 0.7)
}
\keyword{datasets}
\eof
\name{macon}
\alias{macon}
\docType{data}
\title{Wine Tasting}
\usage{data(macon)}
\description{
The \code{macon} data frame has 8 rows-wines and 25 columns-tasters.
Each column is a classification of 8 wines (Beaujolais, France).
}
\source{
Foire Nationale des Vins de France, Mcon, 1985
}
\examples{
data(macon)
s.corcircle(dudi.pca(macon, scan = FALSE)$co)
}
\keyword{datasets}
\eof
\name{mafragh}
\alias{mafragh}
\docType{data}
\title{Phyto-Ecological Survey}
\description{
This data set gives environmental and spatial informations about species and sites. 
}
\usage{data(mafragh)}
\format{
	\code{mafragh} is a list of 6 components.
	\enumerate{
		\item{xy}{are the coordinates of 97 sites.}
		\item{flo}{is a data frame with 97 sites and 56 species.}
		\item{espnames}{is a vector of the names of species.}
		\item{neig}{is the neighbourhood graph of the 97 sites (an object of class 'neig').}
		\item{mil}{is a data frame with 97 sites and 11 environmental variables.}
		\item{partition}{is a factor classifying the 97 sites in 5 classes.}
	}
}
\source{
Belair, G.d. and Bencheikh-Lehocine, M. (1987)\cr
Composition et dterminisme de la vgtation d'une plaine cti"re marcageuse : La Mafragh (Annaba, Algrie).\cr
\emph{Bulletin d'Ecologie}, \bold{18}, 393--407.
}
\examples{
data(mafragh)
par(mfrow = c(3,2))
s.label(mafragh$xy, inc = FALSE, neig = mafragh$neig, 
    sub = "Samples & Neighbourhood graph")
coa1 <- dudi.coa(mafragh$flo, scan = FALSE)
s.value(mafragh$xy, coa1$li[,1], sub = "Axis 1 - COA")
pca1 <- dudi.pca(mafragh$xy, scan = FALSE)
s.value(mafragh$xy, pca1$li[,1], sub = "Axis 1 - PCA")
s.class(pca1$li, mafragh$partition, sub = "Plane 1-2 - PCA")
s.class(coa1$li, mafragh$partition, sub = "Plane 1-2 - COA")
s.chull(mafragh$xy, mafragh$partition, optchull = 1)
}
\keyword{datasets}
\eof
\name{mantel.randtest}
\alias{mantel.randtest}
\title{Mantel test (correlation between two distance matrices (in C).)
}
\description{
Performs a Mantel test between two distance matrices.
}
\usage{
mantel.randtest(m1, m2, nrepet = 999)
}
\arguments{
  \item{m1}{an object of class 'dist'}
  \item{m2}{an object of class 'dist'}
  \item{nrepet}{the number of permutations}
}
\value{
an object of class 'randtest' (randomization tests)
}
\references{Mantel, N. (1967) The detection of disease clustering and a generalized regression approach. \emph{Cancer Research}, \bold{27}, 209--220.
}
\examples{
data(yanomama)
gen <- quasieuclid(as.dist(yanomama$gen))
geo <- quasieuclid(as.dist(yanomama$geo))
plot(r1 <- mantel.randtest(geo,gen), main = "Mantel's test")
r1
}
\keyword{array}
\keyword{nonparametric}
\eof
\name{mantel.rtest}
\alias{mantel.rtest}
\title{Mantel test (correlation between two distance matrices (in R).)
}
\description{
Performs a Mantel test between two distance matrices.
}
\usage{
mantel.rtest(m1, m2, nrepet = 99)
}
\arguments{
  \item{m1}{an object of class 'dist'}
  \item{m2}{an object of class 'dist'}
  \item{nrepet}{the number of permutations}
}
\value{
an object of class 'rtest' (randomization tests)
}
\references{Mantel, N. (1967) The detection of disease clustering and a generalized regression approach. \emph{Cancer Research}, \bold{27}, 209--220.
}
\examples{
if (require(mva, quietly=TRUE)) {
	data(yanomama)
	gen <- quasieuclid(as.dist(yanomama$gen))
	geo <- quasieuclid(as.dist(yanomama$geo))
	plot(r1 <- mantel.rtest(geo,gen), main = "Mantel's test")
	r1
}
}
\keyword{array}
\keyword{nonparametric}
\eof
\name{mariages}
\alias{mariages}
\docType{data}
\title{Correspondence Analysis Table}
\description{
This array contains the socio-professionnal repartitions of 5850 couples.
}
\usage{data(mariages)}
\format{
The \code{mariages} data frame has 9 rows and 9 columns.
The rows represent the wife's socio-professionnal category and the columns the husband's socio-professionnal category (1982).\cr
Codes for rows and columns are identical.\cr
    \describe{
    \item{agri}{: Farmers}
    \item{ouva}{: Farm workers}
    \item{pat}{: Company directors (commerce and industry)}
    \item{sup}{: Liberal profession, executives and higher intellectual professions}
    \item{moy}{: Intermediate professions}
    \item{emp}{: Other white-collar workers}
    \item{ouv}{: Manual workers}
    \item{serv}{: Domestic staff}
    \item{aut}{: other workers}
  }
}
\source{
Vallet, L.A. (1986)\cr
Activit professionnelle de la femme marie et dtermination de la position sociale de la famille.\cr
Un test empirique : la France entre 1962 et 1982.\cr
\emph{Revue Franaise de Sociologie}, \bold{27}, 656--696.
}
\examples{
data(mariages)
par(mfrow = c(2,2))
w <- dudi.coa(mariages, scan = FALSE, nf = 3)
scatter(w, met = 1, posi = "bottom")
scatter(w, met = 2, posi = "bottom")
scatter(w, met = 3, posi = "bottom")
score(w, 3)
}
\keyword{datasets}
\eof
\name{mcoa}
\alias{mcoa}
\alias{print.mcoa}
\alias{summary.mcoa}
\alias{plot.mcoa}
\title{Multiple CO-inertia Analysis}
\description{
performs a multiple CO-inertia analysis, 
using an object of class \code{ktab}. 
}
\usage{
mcoa(X, option = c("inertia", "lambda1", "uniform", "internal"), 
    scannf = TRUE, nf = 3, tol = 1e-07)
print.mcoa (x, \dots)
summary.mcoa (object, \dots)
plot.mcoa (x, xax = 1, yax = 2, eig.bottom = TRUE, \dots)
}
\arguments{
  \item{X}{an object of class \code{ktab}}
  \item{option}{a string of characters for the weightings of the arrays options :
  	 \item{"inertia"}{weighting of group k by the inverse of the total inertia of the array k}
  	 \item{"lambda1"}{weighting of group k by the inverse of the first eigenvalue of the k analysis}
  	 \item{"uniform"}{uniform weighting of groups}
  	 \item{"internal"}{weighting included in \code{X$tabw}}
  }
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  \item{tol}{a tolerance threshold, an eigenvalue is considered positive if it is larger than \code{-tol*lambda1} where \code{lambda1} is the largest eigenvalue.}
  \item{x, object}{an object of class 'mcoa'}
  \item{\dots}{further arguments passed to or from other methods}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{eig.bottom}{a logical value indicating whether the eigenvalues bar plot should be added}
}
\value{
mcoa returns a list of  class 'mcoa' containing :
  \item{pseudoeig}{a numeric vector with the all pseudo eigenvalues}
  \item{call}{the call-up order}
  \item{nf}{a numeric value indicating the number of kept axes}
  \item{SynVar}{a data frame with the synthetic scores}
  \item{axis}{a data frame with the co-inertia axes}
  \item{Tli}{a data frame with the co-inertia coordinates}
  \item{Tl1}{a data frame with the co-inertia normed scores}
  \item{Tax}{a data frame with the inertia axes onto co-inertia axis}
  \item{Tco}{a data frame with the column coordinates onto synthetic scores}
  \item{TL}{a data frame with the factors for Tli Tl1}
  \item{TC}{a data frame with the factors for Tco}
  \item{T4}{a data frame with the factors for Tax}
  \item{lambda}{a data frame with the all eigenvalues (computed on the separate analyses)}
  \item{cov2}{a numeric vector with the all pseudo eigenvalues (synthetic analysis)}
}
\references{
Chessel, D. and Hanafi, M. (1996) Analyses de la co-inertie de K nuages de points, \emph{Revue de Statistique Applique}, \bold{44}, 35--60.
}
\examples{
data(friday87)
w1 <- data.frame(scale(friday87$fau, scal = FALSE))
w2 <- ktab.data.frame(w1, friday87$fau.blo, tabnames = friday87$tab.names)
mcoa1 <- mcoa(w2, "lambda1", scan = FALSE)
mcoa1
summary(mcoa1)
plot(mcoa1)
}
\keyword{multivariate}
\eof
\name{meau}
\alias{meau}
\docType{data}
\title{Ecological Data : sites-variables, sites-species, where and when}
\description{
This data set contains informations about sites, environmental variables
and species (Trichopters). 
}
\usage{data(meau)}
\format{
	\code{meau} is a list of 3 components.
	\enumerate{
		\item{mil}{is a data frame with 24 sites and 10 variables.}
		\item{fau}{is a data frame with 24 sites and 13 species (Trichopters).}
		\item{plan}{is a data frame with 24 sites and 2 factors.
			\enumerate{
				\item{dat}{is a factor with 4 levels.}
				\item{sta}{is a factor with 6 levels.}
			}
		}
	}
}
\source{
Pegaz-Maucet, D. (1980)\cr
Impact d'une perturbation d'origine organique sur la drive des macro-invertbrs benthiques d'un cours d'eau.\cr
Comparaison avec le benthos.\cr
Thse de troisime cycle, Universit Lyon 1, 130 p.
}
\examples{
data(meau)
par(mfrow = c(2,2))
pca1 <- dudi.pca(meau$mil, scan = FALSE, nf = 4)
s.class(pca1$li, meau$plan$dat, 
    sub = "Principal Component Analysis")
pca2 <- between(pca1, meau$plan$dat, scan = FALSE, nf = 2)
s.class(pca2$ls, meau$plan$dat, sub = "Between dates Principal Component Analysis")
s.corcircle(pca1$co)
s.corcircle(pca2$as)
}
\keyword{datasets}
\eof
\name{meaudret}
\alias{meaudret}
\docType{data}
\title{Ecological Data : sites-variables, sites-species, where and when}
\description{
This data set contains informations about sites, environmental variables
and species (Trichopters). 
}
\usage{data(meaudret)}
\format{
	\code{meaudret} is a list of 3 components.
	\enumerate{
		\item{mil}{is a data frame with 24 sites and 9 variables.}
		\item{fau}{is a data frame with 24 sites and 13 species (Trichopters).}
		\item{plan}{is a data frame with 24 sites and 2 factors.
			\enumerate{
				\item{dat}{is a factor with 4 levels.}
				\item{sta}{is a factor with 5 levels.}
			}
		}
	}
}
\source{
Pegaz-Maucet, D. (1980)\cr
Impact d'une perturbation d'origine organique sur la drive des macro-invertbrs benthiques d'un cours d'eau.\cr
Comparaison avec le benthos.\cr
Thse de troisime cycle, Universit Lyon 1, 130 p.
}
\examples{
data(meaudret)
par(mfrow = c(2,2))
pca1 <- dudi.pca(meaudret$mil, scan = FALSE, nf = 4)
s.class(pca1$li, meaudret$plan$dat, 
    sub = "Principal Component Analysis")
pca2 <- between(pca1, meaudret$plan$dat, scan = FALSE, nf = 2)
s.class(pca2$ls, meaudret$plan$dat, sub = "Between dates Principal Component Analysis")
s.corcircle(pca1$co)
s.corcircle(pca2$as)
}
\keyword{datasets}
\eof
\name{mfa}
\alias{mfa}
\alias{print.mfa}
\alias{plot.mfa}
\alias{summary.mfa}
\title{Multiple Factorial Analysis}
\description{
performs a multiple factorial analysis, 
using an object of class \code{ktab}. 
}
\usage{
mfa(X, option = c("lambda1", "inertia", "uniform", "internal"), 
    scannf = TRUE, nf = 3)
plot.mfa (x, xax = 1, yax = 2, option.plot = 1:4, \dots) 
print.mfa (x, \dots) 
summary.mfa (object, \dots) 
}
\arguments{
  \item{X}{K-tables, an object of class \code{ktab}}
  \item{option}{a string of characters for the weighting of arrays options :
    \item{\code{lambda1}}{weighting of group k by the inverse of the first eigenvalue of the k analysis}
    \item{\code{inertia}}{weighting of group k by the inverse of the total inertia of the array k}
    \item{\code{uniform}}{uniform weighting of groups}
    \item{\code{internal}}{weighting included in \code{X$tabw}}
  }
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  \item{x, object}{an object of class 'mfa'}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{option.plot}{an integer between 1 and 4, otherwise the 4 components of the plot are displayed}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
  Returns a list including :
  \item{tab}{a data frame with the modified array}
  \item{rank}{a vector of ranks for the analyses}
  \item{eig}{a numeric vector with the all eigenvalues}
  \item{li}{a data frame with the coordinates of rows}
  \item{TL}{a data frame with the factors associated to the rows (indicators of table)}
  \item{co}{a data frame with the coordinates of columns}
  \item{TC}{a data frame with the factors associated to the columns (indicators of table)}
  \item{blo}{a vector indicating the number of variables for each table}
  \item{lisup}{a data frame with the projections of normalized scores of rows for each table}
  \item{cg}{a data frame with the gravity center for the lisup}
  \item{link}{a data frame containing the projected inertia and the links between the arrays and the reference array}
  \item{corli}{a data frame giving the correlations between the \$lisup and the \$li}
}
\references{Escofier, B. and Pags, J. (1994) Multiple factor analysis (AFMULT package), \emph{Computational Statistics and Data Analysis}, \bold{18}, 121--140.
}
\examples{
data(friday87)
w1 <- data.frame(scale(friday87$fau, scal = FALSE))
w2 <- ktab.data.frame(w1, friday87$fau.blo, 
    tabnames = friday87$tab.names)
mfa1 <- mfa(w2, scann = FALSE)
mfa1
plot(mfa1)

data(escopage)
w <- data.frame(scale(escopage$tab))
w <- ktab.data.frame(w, escopage$blo, tabnames = escopage$tab.names)
plot(mfa(w, scann = FALSE))
}
\keyword{multivariate}
\eof
\name{microsatt}
\alias{microsatt}
\docType{data}
\title{Genetic Relationships between cattle breeds with microsatellites}
\description{
This data set gives genetic relationships between cattle breeds with microsatellites. 
}
\usage{data(microsatt)}
\format{
	\code{microsatt} is a list of 4 components. 
	\enumerate{
		\item{tab}{contains the allelic frequencies for 18 cattle breeds (taurine or zebu,french or african) and 9 microsatellites.}
		\item{loci.names}{is a vector of the names of loci.}
		\item{loci.eff}{is a vector of the number of alleles per locus.}
		\item{alleles.names}{is a vector of the names of alleles.}
	}
}
\source{
Extract of data prepared by D. Laloe \email{ugendla@dga2.jouy.inra.fr} from data used in:\cr\cr

Moazami-Goudarzi, K., D. Laloe, J. P. Furet, and F. Grosclaude. 1997.\cr
Analysis of genetic relationships between 10 cattle breeds with 17 microsatellites.\cr
\emph{Animal Genetics}, \bold{28}, 338--345.\cr\cr

Souvenir Zafindrajaona, P.,Zeuh V. ,Moazami-Goudarzi K., Laloe D., Bourzat D., Idriss A., and Grosclaude F. (1999)\cr
Etude du statut phylogntique du bovin Kouri du lac Tchad  l'aide de marqueurs molculaires.\cr
\emph{Revue d'Elevage et de Mdecine Vtrinaire des pays Tropicaux}, \bold{55}, 155--162.\cr\cr

Moazami-Goudarzi, K., Belemsaga D. M. A., Ceriotti G., Laloe D. , Fagbohoun F., Kouagou N. T., Sidib I., Codjia V., Crimella M. C., Grosclaude F. and Tour S. M. (2001)\cr
Caractrisation de la race bovine Somba  l'aide de marqueurs molculaires.\cr
\emph{Revue d'Elevage et de Mdecine Vtrinaire des pays Tropicaux}, \bold{54}, 1--10
}
\examples{
data(microsatt)
fac <- factor(rep(microsatt$loci.names, microsatt$loci.eff))
w <- dudi.coa(data.frame(t(microsatt$tab)), scann = FALSE)
wit <- within(w, fac, scann = FALSE)
microsatt.ktab <- ktab.within(wit)

plot(sepan(microsatt.ktab)) # 9 separated correspondence analyses
plot(mcoa(microsatt.ktab, scan = FALSE))
plot(mfa(microsatt.ktab, scan = FALSE))
plot(statis(microsatt.ktab, scan = FALSE))
}
\keyword{datasets}
\eof
\name{mollusc}
\alias{mollusc}
\docType{data}
\title{Faunistic Communities and Sampling Experiment}
\description{
This data set gives the abundance of 32 mollusk species in 163 samples. 
For each sample, 4 informations are known : the sampling sites, the seasons, 
the sampler types and the time of exposure. 
}
\usage{data(mollusc)}
\format{
    \code{mollusc} is a list of 2 components.
    \enumerate{
    \item{fau}{is a data frame with 163 samples and 32 mollusk species(abundance).}
    \item{plan}{contains the 163 samples and 4 variables.}
    }
}
\source{
 Richardot-Coulet, M., Chessel D. and Bournaud M. (1986)\cr
 Typological value of the benthos of old beds of a large river. Methodological approach.\cr
 \emph{Archiv fr Hydrobiologie}, \bold{107}, 363--383.
}
\examples{
data(mollusc)
coa1 <- dudi.coa(log(mollusc$fau + 1), scannf = FALSE, nf = 3)
par(mfrow = c(2,2))
s.chull(coa1$li, mollusc$plan$site, 2, 3, opt = 1, cpoi = 1)
s.chull(coa1$li, mollusc$plan$season, 2, 3, opt = 1, cpoi = 1)
s.chull(coa1$li, mollusc$plan$method, 2, 3, opt = 1, cpoi = 1)
s.chull(coa1$li, mollusc$plan$duration, 2, 3, opt = 1, cpoi = 1)
}
\keyword{datasets}
\eof
\name{monde84}
\alias{monde84}
\docType{data}
\title{Global State of the World in 1984}
\usage{data(monde84)}
\description{
The \code{monde84} data frame gives five demographic variables 
for 48 countries in the world. 
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{pib}{: Gross Domestic Product}
    \item{croipop}{: Growth of the population}
    \item{morta}{: Infant Mortality}
    \item{anal}{: Literacy Rate}
    \item{scol}{: Percentage of children in full-time education}
  }
}
\source{
Geze, F. and Coll., eds. (1984)\cr
L'tat du Monde 1984 : annuaire conomique et gopolitique mondial. La Dcouverte, Paris.
}
\examples{
data(monde84)
X <- cbind.data.frame(lpib = log(monde84$pib), monde84$croipop)
Y <- cbind.data.frame(lmorta = log(monde84$morta), 
    lanal = log(monde84$anal + 1), rscol = sqrt(100 - monde84$scol))
pcaY <- dudi.pca(Y, scan = FALSE)
pcaiv1 <- pcaiv(pcaY, X0 <- scale(X), scan = FALSE)
sum(cor(pcaiv1$l1[,1], Y0 <- scale(Y))^2)
pcaiv1$eig[1] #the same
}
\keyword{datasets}
\eof
\name{morphosport}
\alias{morphosport}
\docType{data}
\title{Athletes' Morphology}
\description{
This data set gives a morphological description of 153 athletes split in five different sports. 
 }
\usage{data(morphosport)}
\format{
\code{morphosport} is a list of 2 components.
    \enumerate{
    \item{tab}{is a data frame with 153 athletes and 5 variables.}
    \item{sport}{is a factor with 6 items}
    }

    Variables of \code{morphosport$tab} are the following ones.
    \enumerate{
    \item{dbi}{: biacromial diameter (cm)}
    \item{tde}{: height (cm)}
    \item{tas}{: distance from the buttocks to the top of the head (cm)}
    \item{lms}{: length of the upper limbs (cm)}
    \item{poids}{: weigth (kg)}
    }

    The levels of \code{morphosport$sport} are:
    \enumerate{
    \item{athl}{: athletics}
    \item{foot}{: football}
    \item{hand}{: handball}
    \item{judo}{: judo}
    \item{nata}{: swimming}
    \item{voll}{: volleyball}
    }
}
\source{
Mimouni , N. (1996)\cr
Contribution de mthodes biomtriques  l'analyse de la morphotypologie des sportifs.\cr
Thse de doctorat. Universit Lyon 1.
}
\examples{
data(morphosport)
plot(discrimin(dudi.pca(morphosport$tab, scan = FALSE), morphosport$sport, scan = FALSE))
}
\keyword{datasets}
\eof
\name{neig}
\alias{neig}
\alias{neig.util.GtoL}
\alias{neig.util.LtoG}
\alias{print.neig}
\alias{summary.neig}
\alias{scores.neig}
\alias{nb2neig}
\alias{neig2nb}
\alias{neig2mat}
\title{Neighbourhood Graphs}
\description{
\code{neig} creates objects of class 'neig' with : \cr
    a list of edges\cr
    a binary square matrix\cr
    a list of vectors of neighbours\cr
    an integer (linear and circular graphs)\cr
    a data frame of polygons (area)\cr

scores.neig returns the eigenvectors of neighbouring,\cr
orthonormalized scores (null average, unit variance 1/n and null covariances) of maximal autocorrelation.\cr

nb2neig returns an object of class 'neig' using an object of class 'nb' in the library 'spdep'

neig2nb returns an object of class 'nb' using an object of class 'neig'

neig2mat returns the incidence matrix between edges (1= neighbour ; 0= no neighbour)}

neig.util.GtoL and neig.util.LtoG are utilities.
}
\usage{
neig(list = NULL, mat01 = NULL, edges = NULL,
    n.line = NULL, n.circle = NULL, area = NULL)

scores.neig  (obj) 
print.neig  (x, \dots) 
summary.neig  (object, \dots)
nb2neig (nb)
neig2nb (neig)
neig2mat (neig)
}
\arguments{
\item{list}{a list which each component gives the number of neighbours}
\item{mat01}{a symmetric square matrix of 0-1 values}
\item{edges}{a matrix of 2 columns with integer values giving a list of edges}
\item{n.line}{the number of points for a linear plot}
\item{n.circle}{the number of points for a circular plot}
\item{area}{a data frame containing a polygon set (see \link{area.plot})}
\item{nb}{an object of class 'nb'}
\item{neig, x, obj, object}{an object of class 'neig'}
\item{\dots}{further arguments passed to or from other methods}
}
\references{
Thioulouse, J., D. Chessel, and S. Champely. 1995.\cr
Multivariate analysis of spatial patterns: a unified approach to local and global structures.\cr
Environmental and Ecological Statistics, \bold{2}, 1--14.
}
\examples{
data(mafragh)
if (require(tripack, quietly=TRUE)) {
    par(mfrow = c(2,1))
    provi <- neighbours(tri.mesh(mafragh$xy))
    provi.neig <- neig(list = provi)
    
    s.label(mafragh$xy, neig = provi.neig, inc = FALSE, 
        addax = FALSE, clab = 0, cnei = 2)
    dist <- apply(provi.neig, 1, function(x) 
        sqrt(sum((mafragh$xy[x[1],] - mafragh$xy[x[2],])^2)))
    #hist(dist, nclass = 50)
    mafragh.neig <- neig(edges = provi.neig[dist<50,])
    s.label(mafragh$xy, neig = mafragh.neig, inc = FALSE, 
        addax = FALSE, clab = 0, cnei = 2)
    par(mfrow = c(1,1))
    
    data(irishdata)
    irish.neig <- neig(area = irishdata$area)
      summary(irish.neig)
      print(irish.neig)
    s.label(irishdata$xy, neig = irish.neig, cneig = 3,
        area = irishdata$area, clab = 0.8, inc = FALSE)
    
    irish.scores <- scores.neig(irish.neig)
    par(mfrow = c(2,3))
    for (i in 1:6) s.value(irishdata$xy, irish.scores[,i],
        inc = FALSE, grid = FALSE, addax = FALSE,
        neig = irish.neig,
        csi = 2, cleg = 0, sub = paste("Eigenvector n",i), csub = 2)
    par(mfrow = c(1,1))
    
    a.neig <- neig(n.circle = 16)
    a.scores <- scores.neig(a.neig)
    xy <- cbind.data.frame(cos((1:16) * pi / 8), sin((1:16) * pi / 8))
    par(mfrow = c(4,4))
    for (i in 1:15) s.value(xy, a.scores[,i], neig = a.neig, 
        csi = 3, cleg = 0)
    par(mfrow = c(1,1))
    
    a.neig <- neig(n.line = 28)
    a.scores <- scores.neig(a.neig)
    par(mfrow = c(7,4))
    par(mar = c(1.1,2.1,0.1,0.1))
    for (i in 1:27) barplot(a.scores[,i], col = grey(0.8))
}
par(mfrow = c(1,1))

}
\keyword{utilities}
\eof
\name{niche}
\alias{niche}
\alias{plot.niche}
\alias{print.niche}
\title{Method to Analyse a pair of tables : Environmental and Faunistic Data}
\description{
performs a special multivariate analysis for ecological data. 
}
\usage{
niche(dudiX, Y, scannf = TRUE, nf = 2)
print.niche (x, \dots) 
plot.niche (x, xax = 1, yax = 2, \dots)
}
\arguments{
  \item{dudiX}{a duality diagram providing from a function dudi.coa, dudi.pca, ... using an array sites-variables}
  \item{Y}{a data frame sites-species according to \code{dudiX$tab} with no columns of zero}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  \item{x}{an object of class 'niche'}
  \item{\dots}{further arguments passed to or from other methods}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
}
\value{
Returns a list of the class 'niche' (sub-class of 'dudi') containing :
 \item{rank}{an integer indicating the rank of the studied matrix}
 \item{nf}{an integer indicating the number of kept axes}
 \item{RV}{a numeric value indicating the RV coefficient}
 \item{eig}{a numeric vector with the all eigenvalues}
 \item{lw}{a data frame with the row weigths (crossed array)}
 \item{tab}{a data frame with the crossed array (averaging species/sites)}
 \item{li}{a data frame with the species coordinates}
 \item{l1}{a data frame with the species normed scores}
 \item{co}{a data frame with the variable coordinates}
 \item{c1}{a data frame with the variable normed scores}
 \item{ls}{a data frame with the site coordinates}
 \item{as}{a data frame with the axis upon niche axis} 
}
\references{
Doldec, S., Chessel, D. and Gimaret, C. (2000) Niche separation in community analysis: a new method. \emph{Ecology}, \bold{81}, 2914--1927.
}
\examples{
data(doubs)
dudi1 <- dudi.pca(doubs$mil, scale = TRUE, scan = FALSE, nf = 3)
nic1 <- niche(dudi1, doubs$poi, scann = FALSE)

par(mfrow = c(2,2))
s.traject(dudi1$li, clab = 0)
s.traject(nic1$ls, clab = 0)
s.corcircle(nic1$as)
s.arrow(nic1$c1)

par(mfrow = c(5,6))
for (i in 1:27) s.distri(nic1$ls, as.data.frame(doubs$poi[,i]),
    csub = 2, sub = names(doubs$poi)[i])

par(mfrow = c(1,1))
s.arrow(nic1$li, clab = 0.7)

par(mfrow = c(1,1))
data(trichometeo)
pca1 <- dudi.pca(trichometeo$meteo, scan = FALSE)
nic1 <- niche(pca1, log(trichometeo$fau + 1), scan = FALSE)
plot(nic1)

data(rpjdl)
plot(niche(dudi.pca(rpjdl$mil, scan = FALSE), rpjdl$fau, scan = FALSE))
}
\keyword{multivariate}
\eof
\name{olympic}
\alias{olympic}
\docType{data}
\title{Olympic Decathlon}
\description{
This data set gives the performances of 33 men's decathlon in the 1988 Olympics
}
\usage{data(olympic)}
\format{
    \code{olympic} is a list of 2 components.
    \enumerate{
    \item{tab}{is a data frame with 33 rows and 10 columns events of the decathlon.}
    \item{scores}{is a vector of the final points scores of the competition.}
    }
}
\source{
Example 357 in: \cr
Hand, D.J., Daly, F., Lunn, A.D., McConway, K.J. and Ostrowski, E. (1994)\cr
\emph{A handbook of small data sets}, Chapman & Hall, London. 458 p.\cr\cr

Lunn, A. D. and McNeil, D.R. (1991) \emph{Computer-Interactive Data Analysis}, Wiley, New York
}
\examples{
data(olympic)
pca1 <- dudi.pca(olympic$tab, scan = FALSE)
par(mfrow = c(2,2))
barplot(pca1$eig)
s.corcircle(pca1$co)
plot(olympic$score, pca1$l1[,1])
abline(lm(pca1$l1[,1]~olympic$score))
s.label(pca1$l1, clab = 0.5)
s.arrow(2 * pca1$co, add.p = TRUE)
}
\keyword{datasets}
\eof
\name{ours}
\alias{ours}
\docType{data}
\title{A table of Qualitative Variables}
\usage{data(ours)}
\description{
The \code{ours} (bears) data frame has 38 rows, areas of the "Inventaire National Forestier", and 10 columns.
}
\format{
  This data frame contains the following columns:
   \describe{
    \item{altit}{importance of the altitudinal area inhabited by bears, a factor with levels: 
	\code{1} less than 50\% of the area between 800 and 2000 meters 
    	\code{2} between 50 and 70\% 
    	\code{3} more than 70\%} 
		
    \item{deniv}{importance of the average variation in level by square of 50 km2, a factor with levels: 
    	\code{1} less than 700m
    	\code{2} between 700 and 900 m 
    	\code{3} more than 900 m }
		
    \item{cloiso}{partitioning of the massif, a factor with levels: 
    	\code{1} a great valley or a ridge isolates at least a quarter of the massif 
    	\code{2} less than a quarter of the massif is isolated 
    	\code{3} the massif has no split}
		
    \item{domain}{importance of the national forests on contact with the massif, a factor with levels: 
    	\code{1} less than 400  km2 
    	\code{2} between 400 and 1000  km2 
    	\code{3} more than 1000  km2 }
		
    \item{boise}{rate of afforestation, a factor with levels: 
    	\code{1} less than 30\% 
    	\code{2} between 30 and 50\% 
	\code{3} more than 50\% }
	
    \item{hetra}{importance of plantations and mixed forests, a factor with levels: 
    	\code{1} less than 5\% 
    	\code{2} between 5 and 10\% 
    	\code{3} more than 10\% of the massif }
		
    \item{favor}{importance of favorable forests, plantations, mixed forests, fir plantations, a factor with levels: 
    	\code{1} less than 5\% 
    	\code{2} between 5 and 10\% 
	\code{3} more than 10\% of the massif }
		
    \item{inexp}{importance of unworked forests, a factor with levels: 
    	\code{1} less than 4\% 
    	\code{2} between 4 and 8\% 
    	\code{3} more than 8\% of the total area }
		
    \item{citat}{presence of the bear before its disappearance, a factor with levels: 
    	\code{1} no quotation since 1840 
    	\code{2} 1 to 3 quotations before 1900 and none after 
    	\code{3} 4 quotations before 1900 and none after 
    	\code{4} at least 4 quotations before 1900 and at least 1 quotation between 1900 and 1940 }
		
    \item{depart}{district, a factor with levels: 
    	\code{AHP} Alpes-de-Haute-Provence 
    	\code{AM} Alpes-Maritimes 
    	\code{D} Drme 
    	\code{HP} Hautes-Alpes 
    	\code{HS} Haute-Savoie 
    	\code{I} Is"re 
    	\code{S} Savoie }
  }
}
\source{
 Erome, G. (1989) L'ours brun dans les Alpes franaises. Historique de sa disparition.\cr
 Centre Ornithologique Rhne-Alpes, Villeurbanne. 120 p.
}
\examples{
data(ours)
boxplot(dudi.acm(ours, scan = FALSE))
}
\keyword{datasets}
\eof
\name{pcaiv}
\alias{pcaiv}
\alias{plot.pcaiv}
\alias{print.pcaiv}
\title{Principal component analysis with respect to instrumental variables}
\description{
performs a principal component analysis with respect to instrumental variables. 
}
\usage{
pcaiv(dudi, df, scannf = TRUE, nf = 2)
plot.pcaiv (x, xax = 1, yax = 2, \dots) 
print.pcaiv (x, \dots) 
}
\arguments{
  \item{dudi}{a duality diagram, object of class 'dudi'}
  \item{df}{a data frame with the same rows}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  \cr
  \item{x}{an object of class 'pcaiv'}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
returns an object of class 'pcaiv', sub-class of class 'dudi'
  \item{rank}{an integer indicating the rank of the studied matrix}
  \item{nf}{an integer indicating the number of kept axes}
  \item{eig}{a vector with the all eigenvalues}
  \item{lw}{a numeric vector with the row weigths (from \code{dudi})}
  \item{cw}{a numeric vector with the column weigths (from \code{dudi})}
  \item{Y}{a data frame with the dependant variables}
  \item{X}{a data frame with the explanatory variables}
  \item{tab}{a data frame with the modified array (projected variables)}
  \item{c1}{a data frame with the Pseudo Principal Axes (PPA)}
  \item{as}{a data frame with the Principal axes of \code{dudi$tab} on PPA}
  \item{ls}{a data frame with the projections of lines of \code{dudi$tab} on PPA}
  \item{li}{a data frame \code{dudi$ls} with the predicted values by X}
  \item{fa}{a data frame with the loadings (Constraint Principal Components as linear combinations of X}
  \item{l1}{data frame with the Constraint Principal Components (CPC)}
  \item{co}{a data frame with the inner products between the CPC and Y}
  \item{cor}{a data frame with the correlations between the CPC and X }
}
\references{
Rao, C. R. (1964) The use and interpretation of principal component analysis in applied research. \emph{Sankhya}, \bold{A 26}, 329--359.\cr\cr
Obadia, J. (1978) L'analyse en composantes explicatives. \emph{Revue de Statistique Applique}, \bold{24}, 5--28.\cr\cr
Lebreton, J. D., Sabatier, R., Banco G. and  Bacou A. M. (1991) Principal component and correspondence analyses with respect to instrumental variables : an overview of their role in studies of structure-activity and species- environment relationships. In J. Devillers and W. Karcher, editors. \emph{Applied Multivariate Analysis in SAR and Environmental Studies}, Kluwer Academic Publishers, 85--114 
}
\examples{
data(rhone)
pca1 <- dudi.pca(rhone$tab, scan = FALSE, nf = 3)
iv1 <- pcaiv(pca1, rhone$disch, scan = FALSE)
iv1
# iner inercum inerC inercumC ratio R2    lambda
# 6.27 6.27    5.52  5.52     0.879 0.671 3.7   
# 4.14 10.4    4.74  10.3     0.984 0.747 3.54  
plot(iv1)
}
\keyword{multivariate}
\eof
\name{pcaivortho}
\alias{pcaivortho}
\title{Principal Component Analysis with respect to orthogonal instrumental variables}
\description{
performs a Principal Component Analysis with respect to orthogonal instrumental variables. 
}
\usage{
pcaivortho(dudi, df, scannf = TRUE, nf = 2)
}
\arguments{
  \item{dudi}{a duality diagram, object of class 'dudi'}
  \item{df}{a data frame with the same rows}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
}
\value{
an object of class 'pcaivortho' sub-class of class 'dudi'
  \item{rank}{an integer indicating the rank of the studied matrix}
  \item{nf}{an integer indicating the number of kept axes}
  \item{eig}{a vector with the all eigenvalues}
  \item{lw}{a numeric vector with the row weigths (from \code{dudi})}
  \item{cw}{a numeric vector with the column weigths (from \code{dudi})}
  \item{Y}{a data frame with the dependant variables}
  \item{X}{a data frame with the explanatory variables}
  \item{tab}{a data frame with the modified array (projected variables)}
  \item{c1}{a data frame with the Pseudo Principal Axes (PPA)}
  \item{as}{a data frame with the Principal axis of \code{dudi$tab} on PAP}
  \item{ls}{a data frame with the projection of lines of \code{dudi$tab} on PPA}
  \item{li}{a data frame \code{dudi$ls} with the predicted values by X}
  \item{l1}{a data frame with the Constraint Principal Components (CPC)}
  \item{co}{a data frame with the inner product between the CPC and Y}
  \item{param}{a data frame containing a summary}
}
\references{
Rao, C. R. (1964) The use and interpretation of principal component analysis in applied research. \emph{Sankhya}, \bold{A 26}, 329--359.\cr\cr
Sabatier, R., Lebreton J. D. and Chessel D. (1989) Principal component analysis with instrumental variables as a tool for modelling composition data. In R. Coppi and S. Bolasco, editors. \emph{Multiway data analysis}, Elsevier Science Publishers B.V., North-Holland, 341--352
}
\examples{
par(mfrow = c(2,2))
data(avimedi)
cla <- avimedi$plan$reg:avimedi$plan$str

# simple ordination
coa1 <- dudi.coa(avimedi$fau, scan = FALSE, nf = 3)
s.class(coa1$li, cla, sub = "Sans contrainte")

# within region
w1 <- within(coa1, avimedi$plan$reg, scan = FALSE)
s.match(w1$li, w1$ls, clab = 0, sub = "Intra Rgion")
s.class(w1$li, cla, add.plot = TRUE)

# no region the same result
pcaivnonA <- pcaivortho(coa1, avimedi$plan$reg, scan = FALSE)
s.match(pcaivnonA$li, pcaivnonA$ls, clab = 0, 
    sub = "Contrainte Non A")
s.class(pcaivnonA$li, cla, add.plot = TRUE)

# region + strate
interAplusB <- pcaiv(coa1, avimedi$plan, scan = FALSE)
s.match(interAplusB$li, interAplusB$ls, clab = 0, 
    sub = "Contrainte A + B")
s.class(interAplusB$li, cla, add.plot = TRUE)
}
\keyword{multivariate}
\eof
\name{pcoscaled}
\alias{pcoscaled}
\title{Simplified Analysis in Principal Coordinates}
\description{
performs a simplified analysis in principal coordinates, 
using an object of class \code{dist}. 
}
\usage{
pcoscaled(distmat, tol = 1e-07)
}
\arguments{
  \item{distmat}{an object of class \code{dist}}
  \item{tol}{a tolerance threshold, an eigenvalue is considered as positive if it is larger than \code{-tol*lambda1} where \code{lambda1} is the largest eigenvalue}
}
\value{
returns a data frame containing the Euclidean representation of the distance matrix with a total inertia equal to 1
}
\references{Gower, J. C. (1966) Some distance properties of latent root and vector methods used in multivariate analysis. \emph{Biometrika}, \bold{53}, 325--338.
}
\examples{
if (require(mva, quietly = TRUE)) {
	a <- 1 / sqrt(3) - 0.2
	w <- matrix(c(0,0.8,0.8,a,0.8,0,0.8,a,
		0.8,0.8,,0,a,a,a,a,0),4,4)
	w <- as.dist(w)
	w <- cailliez(w)
	w
	pcoscaled(w)
	dist(pcoscaled(w)) # w
	dist(pcoscaled(2 * w)) # the same
	sum(pcoscaled(w)^2) # unity
}
}
\keyword{array}
\eof
\name{perthi02}
\alias{perthi02}
\docType{data}
\title{Contingency Table with a partition in Molecular Biology}
\description{
This data set gives the amino acids of 904 proteins 
distributed in three classes. 
}
\usage{data(perthi02)}
\format{
    \code{perthi02} is a list of 2 components.
    \enumerate{
    \item{tab}{is a data frame 904 rows (proteins of 201 species) 20 columns (amino acids).}
    \item{cla}{is a factor of 3 classes of protein}
    }
    The levels of \code{perthi02$cla} are \code{cyto} (cytoplasmic proteins) \code{memb} (integral membran proteins) \code{peri} (periplasmic proteins)
}
\source{
Perriere, G. and Thioulouse, J. (2002)\cr
Use of Correspondence Discriminant Analysis to predict the subcellular location of bacterial proteins.\cr
\emph{Computer Methods and Programs in Biomedicine}, \bold{70}, 2, 99--105.
}
\examples{
data(perthi02)
plot(discrimin.coa(perthi02$tab, perthi02$cla, scan = FALSE))
}
\keyword{datasets}
\eof
\name{procuste}
\alias{procuste}
\alias{plot.procuste}
\alias{print.procuste}
\title{Simple Procruste Rotation between two sets of points}
\description{
performs a simple procruste rotation between two sets of points. 
}
\usage{
procuste(df1, df2, scale = TRUE, nf = 4, tol = 1e-07) 
plot.procuste (x, xax = 1, yax = 2, \dots)
print.procuste (x, \dots)
}
\arguments{
  \item{df1, df2}{two data frames with the same rows}
  \item{scale}{a logical value indicating whether a transformation by the Gower's scaling (1971) should be applied}
  \item{nf}{an integer indicating the number of kept axes}
  \item{tol}{a tolerance threshold to test whether the distance matrix is Euclidean : an eigenvalue is considered positive if it is larger than \code{-tol*lambda1} where \code{lambda1} is the largest eigenvalue.}
  \cr
  \item{x}{an objet of class 'procuste'}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
returns a list of 9 components of the class 'procuste'
  \item{d}{a numeric vector of the singular values}
  \item{rank}{an integer indicating the rank of the crossed matrix}
  \item{nfact}{an integer indicating the number of kept axes}
  \item{tab1}{a data frame with the array 1, possibly scaled}
  \item{tab2}{a data frame with the array 2, possibly scaled}
  \item{rot1}{a data frame with the result of the rotation from array 1 to array 2}
  \item{rot2}{a data frame with the result of the rotation from array 2 to array 1}
  \item{load1}{a data frame with the loadings of array 1}
  \item{load2}{a data frame with the loadings of array 2}
  \item{scor1}{a data frame with the scores of array 1}
  \item{scor2}{a data frame with the scores of array 2}
  \item{call}{a call order of the analysis}
}
\references{
Digby, P. G. N. and Kempton, R. A. (1987) Multivariate Analysis of Ecological Communities. \emph{Population and Community Biology Series}, Chapman and Hall, London.\cr\cr
Gower, J.C. (1971) Statistical methods of comparing different multivariate analyses of the same data. In \emph{Mathematics in the archaeological and historical sciences}, Hodson, F.R, Kendall, D.G. & Tautu, P. (Eds.) University Press, Edinburgh,  138--149.\cr\cr
Schnemann, P.H. (1968) On two-sided Procustes problems. \emph{Psychometrika}, \bold{33}, 19--34.\cr\cr
Torre, F. and Chessel, D. (1994) Co-structure de deux tableaux totalement apparis. \emph{Revue de Statistique Applique}, \bold{43}, 109--121.\cr\cr
Dray, S., Chessel, D. and Thioulouse, J.  (2003) Procustean co-inertia analysis for the linking of multivariate datasets. \emph{Ecoscience}, \bold{10}, 1, 110-119.
}
\examples{
data(macaca)
par(mfrow = c(2,2))
pro1 <- procuste(macaca$xy1, macaca$xy2, scal = FALSE)
s.match(pro1$tab1, pro1$rot2, clab = 0.7)
s.match(pro1$tab2, pro1$rot1, clab = 0.7)
pro2 <- procuste(macaca$xy1, macaca$xy2)
s.match(pro2$tab1, pro2$rot2, clab = 0.7)
s.match(pro2$tab2, pro2$rot1, clab = 0.7)

data(doubs)
pca1 <- dudi.pca(doubs$mil, scal = TRUE, scann = FALSE)
pca2 <- dudi.pca(doubs$poi, scal = FALSE, scann = FALSE)
pro3 <- procuste(pca1$tab, pca2$tab, nf = 2)
par(mfrow = c(2,2))
s.traject(pro3$scor1, clab = 0)
s.label(pro3$scor1, clab = 0.8, add.p = TRUE)
s.traject(pro3$scor2, clab = 0)
s.label(pro3$scor2, clab = 0.8, add.p = TRUE)
s.arrow(pro3$load1, clab = 0.75)
s.arrow(pro3$load2, clab = 0.75)
plot(pro3)

data(fruits)
plot(procuste(scalewt(fruits$jug), scalewt(fruits$var)))
}
\keyword{multivariate}
\eof
\name{procuste.randtest}
\alias{procuste.randtest}
\title{
    Monte-Carlo Test on the sum of the singular values of a procustean rotation (in C).
}
\description{
performs a Monte-Carlo Test on the sum of the singular values of a procustean rotation. 
}
\usage{
procuste.randtest(df1, df2, nrepet = 999)
}
\arguments{
  \item{df1}{a data frame}
  \item{df2}{a data frame}
  \item{nrepet}{the number of permutations}
}
\value{
returns a list of class 'randtest'
}
\references{
Jackson, D.A. (1995) PROTEST: a PROcustean randomization TEST of community environment concordance. Ecosciences, \bold{2}, 297--303.
}
\examples{
data(doubs)
pca1 <- dudi.pca(doubs$mil, scal = TRUE, scann = FALSE)
pca2 <- dudi.pca(doubs$poi, scal = FALSE, scann = FALSE)
protest1 <- procuste.randtest(pca1$tab, pca2$tab, 999)
protest1
plot(protest1,main="PROTEST")
}
\keyword{multivariate}
\keyword{nonparametric}
\eof
\name{procuste.rtest}
\alias{procuste.rtest}
\title{
    Monte-Carlo Test on the sum of the singular values of a procustean rotation (in R).
}
\description{
performs a Monte-Carlo Test on the sum of the singular values of a procustean rotation. 
}
\usage{
procuste.rtest(df1, df2, nrepet = 99)
}
\arguments{
  \item{df1}{a data frame}
  \item{df2}{a data frame}
  \item{nrepet}{the number of permutations}
}
\value{
returns a list of class 'rtest'
}
\references{
Jackson, D.A. (1995) PROTEST: a PROcustean randomization TEST of community environment concordance. Ecosciences, \bold{2}, 297--303.
}
\examples{
data(doubs)
pca1 <- dudi.pca(doubs$mil, scal = TRUE, scann = FALSE)
pca2 <- dudi.pca(doubs$poi, scal = FALSE, scann = FALSE)
proc1 <- procuste(pca1$tab, pca2$tab)
protest1 <- procuste.rtest(pca1$tab, pca2$tab, 999)
protest1
plot(protest1)
}
\keyword{multivariate}
\keyword{nonparametric}
\eof
\name{pta}
\alias{pta}
\alias{print.pta}
\alias{plot.pta}
\title{Partial Triadic Analysis of a K-tables}
\description{
performs a partial triadic analysis of a K-tables, 
using an object of class \code{ktab}. 
}
\usage{
pta(X, scannf = TRUE, nf = 2)
plot.pta (x, xax = 1, yax = 2, option = 1:4, \dots)
print.pta (x, \dots)
}
\arguments{
  \item{X}{an object of class \code{ktab} where the arrays have 1) the same dimensions 2) the same names for columns 3) the same column weightings}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  
  \item{x}{an object of class 'pta'}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{option}{an integer between 1 and 4, otherwise the 4 components of the plot are displayed}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
returns a list of class 'pta', sub-class of  'dudi' containing :
  \item{RV}{a matrix with the all RV coefficients}
  \item{RV.eig}{a numeric vector with the all eigenvalues (interstructure)}
  \item{RV.coo}{a data frame with the scores of the arrays}
  \item{tab.names}{a vector of characters with the array names}
  \item{nf}{an integer indicating the number of kept axes}
  \item{rank}{an integer indicating the rank of the studied matrix}
  \item{tabw}{a numeric vector with the array weights}
  \item{cw}{a numeric vector with the column weights}
  \item{lw}{a numeric vector with the row weights}
  \item{eig}{a numeric vector with the all eigenvalues (compromis)}
  \item{cos2}{a numeric vector with the \eqn{\cos^2}{cos} between compromise and arrays} 
  \item{tab}{a data frame with the modified array}
  \item{li}{a data frame with the row coordinates}
  \item{l1}{a data frame with the row normed scores}
  \item{co}{a data frame with the column coordinates}
  \item{c1}{a data frame with the column normed scores}
  \item{Tli}{a data frame with the row coordinates (each table)}
  \item{Tco}{a data frame with the column coordinates (each table)}
  \item{Tcomp}{a data frame with the principal components (each table)}
  \item{Tax}{a data frame with the principal axes (each table)}
  \item{TL}{a data frame with the factors for Tli}
  \item{TC}{a data frame with the factors for Tco}
  \item{T4}{a data frame with the factors for Tax and Tcomp}
}
\references{
Blanc, L., Chessel, D. and Doldec, S. (1998) Etude de la stabilit temporelle des structures spatiales par Analyse d'une srie de tableaux faunistiques totalement apparis. \emph{Bulletin Franais de la Pche et de la Pisciculture}, \bold{348}, 1--21.\cr\cr
Thioulouse, J., and D. Chessel. 1987. Les analyses multi-tableaux en cologie factorielle. I De la typologie d'tat  la typologie de fonctionnement par l'analyse triadique. \emph{Acta Oecologica, Oecologia Generalis}, \bold{8}, 463--480.
}
\author{P. Bady}
\examples{
data(meaudret)
wit1 <- within.pca(meaudret$mil, meaudret$plan$dat, scan = FALSE, 
    scal = "partial")
kta1 <- ktab.within(wit1, colnames = rep(c("S1","S2","S3","S4","S5"), 4))
kta2 <- t(kta1)
pta1 <- pta(kta2, scann = FALSE)
pta1
plot(pta1)
}
\keyword{multivariate}
\eof
\name{quasieuclid}
\alias{quasieuclid}
\title{Transformation of a distance matrice to an Euclidean one}
\description{
transforms a distance matrix in an Euclidean one. 
}
\usage{
quasieuclid(distmat)
}
\arguments{
  \item{distmat}{an object of class 'dist'}
}
\details{
 The function creates a distance matrice with the positive eigenvalues of the Euclidean representation. \cr 
 Only for Euclidean distances which are not Euclidean for numeric approximations (for examples, in papers as the following example).
}
\value{
object of class 'dist' containing an Euclidean distance matrice
}
\examples{
data(yanomama)
geo <- as.dist(yanomama$geo)
is.euclid(geo) # FALSE
geo1 <- quasieuclid(geo)
is.euclid(geo1) # TRUE
par(mfrow = c(2,2))
lapply(yanomama, function(x) plot(as.dist(x), quasieuclid(as.dist(x))))
}
\keyword{array}
\eof
\name{randtest-internal}
\alias{testdiscrimin}
\alias{testertrace}
\alias{testertracenu}
\alias{testertracenubis}
\alias{testinter}
\alias{testprocuste}
\alias{testmantel}
\title{Internal Permutation Tests functions (in C).}
\description{
Internal Permutation Tests functions (in C)
}
\usage{
}
\details{
These are not to be called by the user.
}
\keyword{ internal }
\eof
\name{randtest}
\alias{randtest}
\alias{as.randtest}
\alias{plot.randtest}
\alias{print.randtest}
\title{Class of the Permutation Tests (in C).}
\description{
randtest is a generic function. It proposes methods for the following objects \code{between}, \code{discrimin}, \code{coinertia} \code{\dots}\cr
}
\usage{
    randtest(xtest, \dots)
    plot.randtest(x, nclass = 10, coeff = 1, \dots)
    as.randtest (sim, obs, call = match.call())
    print.randtest (x, \dots)
}
\arguments{
\item{xtest}{an object used to select a method}
\item{x}{an object of class \code{randtest}}
\item{\dots}{\code{\dots} further arguments passed to or from other methods; in \code{plot.randtest} to \code{hist}}
\item{nclass}{a number of intervals for the histogram}
\item{coeff}{to fit the magnitude of the graph}
\item{sim}{a numeric vector of simulated values}
\item{obs}{a numeric vector of an observed value}
\item{call}{a call order}
}
\value{
\code{as.randtest} returns a list of class \code{randtest}\cr
\code{plot.randtest} draws the simulated values histograms and the position of the observed value\cr
}
\seealso{\link{mantel.randtest}, \link{procuste.randtest}, \link{rtest}}
\examples{
par(mfrow = c(2,2))
for (x0 in c(2.4,3.4,5.4,20.4)) {
    l0 <- as.randtest(sim = rnorm(200), obs = x0)
    print(l0)
    plot(l0,main=paste("p.value = ", round(l0$pvalue, dig = 5)))
}
par(mfrow = c(1,1))
}
\keyword{methods}
\eof
\name{randtest.between}
\alias{randtest.between}
\title{Monte-Carlo Test on the between-groups inertia percentage (in C).
}
\description{
Performs a Monte-Carlo test on the between-groups inertia percentage. 
}
\usage{
randtest.between(xtest, nrepet = 999, \dots)
}
\arguments{
  \item{xtest}{an object of class 'between'}
  \item{nrepet}{the number of permutations}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
a list of the class 'randtest'
}
\references{
Romesburg, H. C. (1985) Exploring, confirming and randomization tests. \emph{Computers and Geosciences}, \bold{11}, 19--37.
}
\examples{
data(meaudret)
pca1 <- dudi.pca(meaudret$mil, scan = FALSE, nf = 3)
rand1 <- randtest(between(pca1, meaudret$plan$dat, scan = FALSE), 99)
rand1
plot(rand1, main = "Monte-Carlo test")
}
\keyword{multivariate}
\keyword{nonparametric}
\eof
\name{randtest.coinertia}
\alias{randtest.coinertia}
\title{Monte-Carlo test on a coinertia analysis (in C).}
\description{
Performs a Monte-Carlo test on a coinertia analysis. 
}
\usage{
randtest.coinertia(xtest, nrepet = 999, fixed=0, \dots)
}
\arguments{
  \item{xtest}{an object of class 'coinertia'}
  \item{nrepet}{the number of permutations}
  \item{fixed}{when non uniform row weights are used in the coinertia analysis,
this parameter must be the number of the table that should be kept fixed in the permutations}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
a list of the class 'randtest'
}
\references{
Doledec, S. and Chessel, D. (1994) Co-inertia analysis: an alternative method for
studying species-environment relationships. \emph{Freshwater Biology}, \bold{31}, 277--294.
}
\examples{
data(doubs)
dudi1 <- dudi.pca(doubs$mil, scale = TRUE, scan = FALSE, nf = 3)
dudi2 <- dudi.pca(doubs$poi, scale = FALSE, scan = FALSE, nf = 2)
coin1 <- coinertia(dudi1,dudi2, scan = FALSE, nf = 2)
plot(randtest(coin1))
 }
\keyword{multivariate}
\keyword{nonparametric}
\eof
\name{randtest.discrimin}
\alias{randtest.discrimin}
\title{
Monte-Carlo Test on a Discriminant Analysis (in C).}
\description{
Test of the sum of a discriminant analysis eigenvalues (divided by the rank). Non parametric version of the Pillai's test. It authorizes any weighting.
}
\usage{
randtest.discrimin(xtest, nrepet = 999, \dots)
}
\arguments{
  \item{xtest}{an object of class 'discrimin'}
  \item{nrepet}{the number of permutations}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
returns a list of class 'randtest'
}
\examples{
data(meaudret)
pca1 <- dudi.pca(meaudret$mil, scan = FALSE, nf = 3)
rand1 <- randtest(discrimin(pca1, meaudret$plan$dat, scan = FALSE), 99)
rand1
#Monte-Carlo test
#Observation: 0.3035 
#Call: as.randtest(sim = sim, obs = obs)
#Based on 999 replicates
#Simulated p-value: 0.001 
plot(rand1, main = "Monte-Carlo test")
summary.manova(manova(as.matrix(meaudret$mil)~meaudret$plan$dat), "Pillai")
#                   Df Pillai approx F num Df den Df  Pr(>F)    
# meaudret$plan$dat  3   2.73    11.30     27     30 1.6e-09 ***
# Residuals         16                                          
# ---
# Signif. codes:  0 `***' 0.001 `**' 0.01 `*' 0.05 `.' 0.1 ` ' 1 
# 2.731/9 = 0.3034
}
\keyword{multivariate}
\keyword{nonparametric}
\eof
\name{rankrock}
\alias{rankrock}
\docType{data}
\title{Ordination Table}
\description{
This data set gives the classification in order of preference of 10 music groups by 51 students. 
}
\usage{data(rankrock)}
\format{
A data frame with 10 rows and 51 columns.\cr
Each column contains the rank (1 for the favorite, \dots, 10 for the less appreciated)\cr
attributed to the group by a student.
}
\examples{
data(rankrock)
dudi1 <- dudi.pca(rankrock, scannf = FALSE, nf = 3)
scatter(dudi1, clab.r = 1.5)
}
\keyword{datasets}
\eof
\name{reconst}
\alias{reconst}
\alias{reconst.pca}
\title{Reconstitution of Data from a Duality Diagram}
\description{
Generic Function. Nowadays just \code{reconst.pca}
}
\usage{
reconst (dudi, ...)
reconst.pca (dudi, nf = 1, ...) 
}
\arguments{
  \item{dudi}{an object used to select a method}
  \item{\dots}{\code{\dots} further arguments passed to or from other methods}
  
  \item{nf}{an integer indicating the number of kept axes}
}
\value{
a data frame reconstituting the data
}
\references{Gabriel, K.R. (1978) Least-squares approximation of matrices by additive and multiplicative models. \emph{Journal of the Royal Statistical Society}, B , \bold{40}, 186--196.
}
\examples{
data(rhone)
dd1 <- dudi.pca(rhone$tab, nf = 2, scann = FALSE)
rh1 <- reconst(dd1, 1)
rh2 <- reconst(dd1, 2)
par(mfrow = c(4,4))
par(mar = c(2.6,2.6,1.1,1.1))
for (i in 1:15) {
    plot(rhone$date, rhone$tab[,i])
    lines(rhone$date, rh1[,i], lty = 2)
    lines(rhone$date, rh2[,i], lty = 1)
    scatterutil.sub(names(rhone$tab)[i], 2, "topright")
}
}
\keyword{multivariate}
\eof
\name{rhone}
\alias{rhone}
\docType{data}
\title{Physico-Chemistry Data}
\description{
This data set gives for 39 water samples a physico-chemical description 
with the number of sample date and the flows of three tributaries. 
}
\usage{data(rhone)}
\format{
    \code{rhone} is a list of 3 components.
    \enumerate{
    \item{tab}{is a data frame with 39 water samples and 15 physico-chemical variables.}
    \item{date}{is a vector of the sample date (in days).}
    \item{disch}{is a data frame with 39 water samples and the flows of the three tributaries.}
    }
}
\source{
Carrel, G., Barthelemy, D., Auda, Y. and Chessel, D. (1986)\cr
Approche graphique de l'analyse en composantes principales norme : utilisation en hydrobiologie.\cr
\emph{Acta Oecologica, Oecologia Generalis}, \bold{7}, 189--203.
}
\examples{
data(rhone)
pca1 <- dudi.pca(rhone$tab, nf = 2, scann = FALSE)
rh1 <- reconst(pca1, 1)
rh2 <- reconst(pca1, 2)
par(mfrow = c(4,4))
par(mar = c(2.6,2.6,1.1,1.1))
for (i in 1:15) {
    plot(rhone$date, rhone$tab[,i])
    lines(rhone$date, rh1[,i], lwd = 2)
    lines(rhone$date, rh2[,i])
    scatterutil.sub(names(rhone$tab)[i], 2, "topright")
}
}
\keyword{datasets}
\eof
\name{rpjdl}
\alias{rpjdl}
\docType{data}
\title{Avifauna and Vegetation}
\description{
This data set gives the abundance of 52 species and 8 environmental variables 
in 182 sites. 
}
\usage{data(rpjdl)}
\format{
    \code{rpjdl} is a list of 5 components.
    \enumerate{
    \item{fau}{is the faunistic array of 182 sites (rows) and 52 species (columns).}
    \item{mil}{is the array of environmental variables : 182 sites and 8 variables.}
    \item{frlab}{is a vector of the names of species in French.}
    \item{lalab}{is a vector of the names of species in Latin.}
    \item{lab}{is a vector of the simplified labels of species.}
    }
}
\source{
Prodon, R. and Lebreton, J.D. (1981)\cr
Breeding avifauna of a Mediterranean succession : the holm oak and cork oak series in the eastern Pyrnes.\cr
1 : Analysis and modelling of the structure gradient.\cr
\emph{Okos}, \bold{37}, 21--38.\cr\cr

Lebreton, J. D., Chessel D., Prodon R. and Yoccoz N. (1988)\cr
L'analyse des relations espces-milieu par l'analyse canonique des correspondances.\cr
I. Variables de milieu quantitatives.\cr
\emph{Acta Oecologica, Oecologia Generalis}, \bold{9}, 53--67.
}
\examples{
data(rpjdl)
xy <- dudi.coa(rpjdl$fau, scann = FALSE)$l1
s.distri(xy, rpjdl$fau, 2, 1, cstar = 0.3, cell = 0)

xy1 <- dudi.pca(rpjdl$fau, scal = FALSE, scann = FALSE)$l1
s.distri(xy1, rpjdl$fau, 2, 1, cstar = 0.3, cell = 0)

cca1 <- cca(rpjdl$fau, rpjdl$mil, scan = FALSE)
plot(cca1)

}
\keyword{datasets}
\eof
\name{rtest}
\alias{rtest}
\alias{as.rtest}
\alias{plot.rtest}
\alias{print.rtest}
\title{Class of the Permutation Tests (in R).}
\description{
rtest is a generic function. It proposes methods for the following objects \code{between}, \code{discrimin}, \code{procuste} \code{\dots}\cr
}
\usage{
    rtest(xtest, \dots)
    plot.rtest(x, nclass = 10, coeff = 1, \dots)
    as.rtest (sim, obs, call = match.call())
    print.rtest (x, \dots)
}
\arguments{
\item{xtest}{an object used to select a method}
\item{x}{an object of class 'rtest'}
\item{\dots}{\code{\dots} further arguments passed to or from other methods; in \code{plot.randtest} to \code{hist}}
\item{rtest}{object of class \code{rtest}}
\item{nclass}{a number of intervals for the histogram}
\item{coeff}{to fit the magnitude of the graph}
\item{sim}{a numeric vector of simulated values}
\item{obs}{a numeric vector of an observed value}
\item{call}{a call order}
}
\value{
\code{as.rtest} returns a list of class \code{rtest}\cr
\code{plot.rtest} draws the simulated values histograms and the position of the observed value\cr
}
\seealso{\link{RV.rtest}, \link{mantel.rtest}, \link{procuste.rtest}, \link{randtest}}
\examples{
par(mfrow = c(2,2))
for (x0 in c(2.4,3.4,5.4,20.4)) {
    l0 <- as.rtest(sim = rnorm(200), obs = x0)
    print(l0)
    plot(l0,main=paste("p.value = ", round(l0$pvalue, dig = 5)))
}
}
\keyword{methods}
\eof
\name{rtest.between}
\alias{rtest.between}
\title{Monte-Carlo Test on the between-groups inertia percentage (in R).
}
\description{
Performs a Monte-Carlo test on the between-groups inertia percentage. 
}
\usage{
rtest.between(xtest, nrepet = 999, \dots)
}
\arguments{
  \item{xtest}{an object of class 'between'}
  \item{nrepet}{the number of permutations}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
a list of the class 'rtest'
}
\references{
Romesburg, H. C. (1985) Exploring, confirming and randomization tests. \emph{Computers and Geosciences}, \bold{11}, 19--37.
}
\examples{
data(meaudret)
pca1 <- dudi.pca(meaudret$mil, scan = FALSE, nf = 3)
rand1 <- rtest(between(pca1, meaudret$plan$dat, scan = FALSE), 99)
rand1
plot(rand1, main = "Monte-Carlo test")
}
\keyword{multivariate}
\keyword{nonparametric}
\eof
\name{rtest.discrimin}
\alias{rtest.discrimin}
\title{
Monte-Carlo Test on a Discriminant Analysis (in R).
}
\description{
Test of the sum of a discriminant analysis eigenvalues (divided by the rank). Non parametric version of the Pillai's test. It authorizes any weighting.
}
\usage{
rtest.discrimin(xtest, nrepet = 999, \dots)
}
\arguments{
  \item{xtest}{an object of class 'discrimin'}
  \item{nrepet}{the number of permutations}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
returns a list of class 'rtest'
}
\examples{
data(meaudret)
pca1 <- dudi.pca(meaudret$mil, scan = FALSE, nf = 3)
rand1 <- rtest(discrimin(pca1, meaudret$plan$dat, scan = FALSE), 99)
rand1
#Monte-Carlo test
#Observation: 0.3035 
#Call: as.rtest(sim = sim, obs = obs)
#Based on 999 replicates
#Simulated p-value: 0.001 
plot(rand1, main = "Monte-Carlo test")
summary.manova(manova(as.matrix(meaudret$mil)~meaudret$plan$dat), "Pillai")
#                   Df Pillai approx F num Df den Df  Pr(>F)    
# meaudret$plan$dat  3   2.73    11.30     27     30 1.6e-09 ***
# Residuals         16                                          
# ---
# Signif. codes:  0 `***' 0.001 `**' 0.01 `*' 0.05 `.' 0.1 ` ' 1 
# 2.731/9 = 0.3034
}
\keyword{multivariate}
\keyword{nonparametric}
\eof
\name{s.arrow}
\alias{s.arrow}
\title{Plot of the factorial maps for the projection of a vector basis}
\description{
performs the scatter diagrams of the projection of a vector basis. 
}
\usage{
s.arrow(dfxy, xax = 1, yax = 2, label = row.names(dfxy), 
    clabel = 1, pch = 20, cpoint = 0, edge = TRUE, origin = c(0,0), 
    xlim = NULL, ylim = NULL, grid = TRUE, addaxes = TRUE, cgrid = 1, 
    sub = "", csub = 1.25, possub = "bottomleft", pixmap = NULL, 
    contour = NULL, area = NULL, add.plot = FALSE)
}
\arguments{
  \item{dfxy}{a data frame containing the two columns for the axes}
  \item{xax}{the column number of x in \code{dfxy}}
  \item{yax}{the column number of y in \code{dfxy}}
  \item{label}{a vector of strings of characters for the point labels}
  \item{clabel}{if not NULL, a character size for the labels used with par("cex")*\code{clabel}}
  \item{pch}{if \code{cpoint} > 0, an integer specifying the symbol or the single character to be used in plotting points}
  \item{cpoint}{a character size for plotting the points, used with par("cex")*\code{cpoint}. If zero, no points are drawn.}
  \item{edge}{a logical value indicating whether the arrows should be plotted}
  \item{origin}{the fixed point in the graph space, by default c(0,0) the origin of axes. The arrows begin at \code{cent}.}
  \item{xlim}{the ranges to be encompassed by the x-axis, if NULL they are computed}
  \item{ylim}{the ranges to be encompassed by the y-axis, if NULL they are computed}
  \item{grid}{a logical value indicating whether a grid in the background of the plot should be drawn}
  \item{addaxes}{a logical value indicating whether the axes should be plotted}
  \item{cgrid}{a character size, parameter used with par("cex")*\code{cgrid}, to indicate the mesh of the grid}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the legend position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{pixmap}{an object 'pixmap' displayed in the map background}
  \item{contour}{a data frame with 4 columns to plot the contour of the map : each row gives a line (x1,y1,x2,y2)}
  \item{area}{a data frame of class 'area' to plot a set of surface units in contour}
  \item{add.plot}{if TRUE uses the current graphics window}
}
\examples{
s.arrow(cbind.data.frame(runif(55,-2,3), runif(55,-3,2)))
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{s.chull}
\alias{s.chull}
\title{Plot of the factorial maps with polygons of contour by level of a factor}
\description{
performs the scatter diagrams with polygons of contour by level of a factor. 
}
\usage{
s.chull(dfxy, fac, xax = 1, yax = 2, 
    optchull = c(0.25, 0.5, 0.75, 1), label = levels(fac), clabel = 1, 
    cpoint = 0, xlim = NULL, ylim = NULL, grid = TRUE, addaxes = TRUE, 
    origin = c(0,0), include.origin = TRUE, sub = "", csub = 1, 
    possub = "bottomleft", cgrid = 1, pixmap = NULL, contour = NULL, 
    area = NULL, add.plot = FALSE)
}
\arguments{
  \item{dfxy}{a data frame containing the two columns for the axes}
  \item{fac}{a factor partioning the rows of the data frame in classes}
  \item{xax}{the column number of x in \code{dfxy}}
  \item{yax}{the column number of y in \code{dfxy}}
  \item{optchull}{the number of convex hulls and their interval}
  \item{label}{a vector of strings of characters for the point labels}
  \item{clabel}{if not NULL, a character size for the labels, used with  \code{par("cex")*clabel}}
  \item{cpoint}{a character size for plotting the points, used with \code{par("cex")*cpoint}. If zero, no points are drawn}
  \item{xlim}{the ranges to be encompassed by the x axis, if NULL, they are computed}
  \item{ylim}{the ranges to be encompassed by the y axis, if NULL they are computed}
  \item{grid}{a logical value indicating whether a grid in the background of the plot should be drawn}
  \item{addaxes}{a logical value indicating whether the axes should be plotted}
  \item{origin}{the fixed point in the graph space, for example c(0,0) the origin axes}
  \item{include.origin}{a logical value indicating whether the point "origin" should be belonged to the graph space}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{cgrid}{a character size, parameter used with par("cex")* \code{cgrid} to indicate the mesh of the grid}
  \item{pixmap}{an object 'pixmap' displayed in the map background}
  \item{contour}{a data frame with 4 columns to plot the contour of the map : each row gives a line (x1,y1,x2,y2)}
  \item{area}{a data frame of class 'area' to plot a set of surface units in contour}
  \item{add.plot}{if TRUE uses the current graphics window}
}
\examples{
xy <- cbind.data.frame(x = runif(200,-1,1), y = runif(200,-1,1))
posi <- factor(xy$x > 0) : factor(xy$y > 0)
s.chull(xy, posi, cpoi = 1.5)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{s.class}
\alias{s.class}
\title{Plot of factorial maps with representation of point classes}
\description{
performs the scatter diagrams with representation of point classes. 
}
\usage{
s.class(dfxy, fac, wt = rep(1, length(fac)), xax = 1, 
    yax = 2, cstar = 1, cellipse = 1.5, axesell = TRUE, 
    label = levels(fac), clabel = 1, cpoint = 1, pch = 20, xlim = NULL, 
    ylim = NULL, grid = TRUE, addaxes = TRUE, origin = c(0,0), 
    include.origin = TRUE, sub = "", csub = 1, possub = "bottomleft", 
    cgrid = 1, pixmap = NULL, contour = NULL, area = NULL, add.plot = FALSE)
}
\arguments{
  \item{dfxy}{a data frame containing the two columns for the axes}
  \item{fac}{a factor partitioning the rows of the data frame in classes}
  \item{wt}{a vector of the point weightings of the data frame used for computing the means (star centers) and the ellipses of dispersion}
  \item{xax}{the column number of x in \code{dfxy}}
  \item{yax}{the column number of y in \code{dfxy}}
  \item{cstar}{a number between 0 and 1 which defines the length of the star size}
  \item{cellipse}{a positive coefficient for the inertia ellipse size}
  \item{axesell}{a logical value indicating whether the ellipse axes should be drawn}
  \item{label}{a vector of strings of characters for the point labels}
  \item{clabel}{if not NULL, a character size for the labels, used with \code{par("cex")*clabel}}
  \item{cpoint}{a character size for plotting the points, used with \code{par("cex")*cpoint}. If zero, no points are drawn}
  \item{pch}{if \code{cpoint} > 0, an integer specifying the symbol or the single character to be used in plotting points}
  \item{xlim}{the ranges to be encompassed by the x, if NULL they are computed}
  \item{ylim}{the ranges to be encompassed by the y, if NULL they are computed}
  \item{grid}{a logical value indicating whether a grid in the background of the plot should be drawn}
  \item{addaxes}{a logical value indicating whether the axes should be plotted}
  \item{origin}{the fixed point in the graph space, for example c(0,0) the origin axes}
  \item{include.origin}{a logical value indicating whether the point "origin" should be belonged to the graph space}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{cgrid}{a character size, parameter used with par("cex")* \code{cgrid} to indicate the mesh of the grid}
  \item{pixmap}{an object 'pixmap' displayed in the map background}
  \item{contour}{a data frame with 4 columns to plot the contour of the map : each row gives a line (x1,y1,x2,y2)}
  \item{area}{a data frame of class 'area' to plot a set of surface units in contour}
  \item{add.plot}{if TRUE uses the current graphics window}
}
\examples{
xy <- cbind.data.frame(x = runif(200,-1,1), y = runif(200,-1,1))
posi <- factor(xy$x > 0) : factor(xy$y > 0)
par(mfrow = c(2,2))
s.class(xy, posi, cpoi = 2)
s.class(xy, posi, cell = 0, cstar = 0.5)
s.class(xy, posi, cell = 2, axesell = FALSE, csta = 0)
s.chull(xy, posi, cpoi = 1)

data(banque)
dudi1 <- dudi.acm(banque, scannf = FALSE)
par(mfrow = c(2,2))
s.label(dudi1$li, sub = "Factorial map from ACM", csub = 1.5, 
    possub = "topleft")
s.class(dudi1$li, banque[,20], sub = names(banque)[20], 
    possub = "bottomright", cell = 0, cstar = 0.5, cgrid = 0, csub = 1.5)
s.class(dudi1$li, banque[,20], csta = 0, cell = 2, cgrid = 0, 
    clab = 1.5)
s.class(dudi1$li, banque[,20], sub = names(banque)[20], 
    possub = "topright", cgrid = 0)

par(mfrow = n2mfrow(ncol(banque)))
for (i in 1:(ncol(banque)))
    s.class(dudi1$li, banque[,i], clab = 1.5, sub = names(banque)[i], 
    csub = 2, possub = "topleft", cgrid = 0, csta = 0, cpoi = 0)
s.label(dudi1$li, clab = 0, sub = "Common background")
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{s.corcircle}
\alias{s.corcircle}
\title{Plot of the factorial maps of a correlation circle}
\description{
performs the scatter diagram of a correlation circle. 
}
\usage{
s.corcircle(dfxy, xax = 1, yax = 2, label = row.names(df), 
    clabel = 1, grid = TRUE, sub = "", csub = 1, possub = "bottomleft", 
    cgrid = 1, fullcircle = TRUE, box = FALSE, add.plot = FALSE)
}
\arguments{
  \item{dfxy}{a data frame with two coordinates }
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{label}{a vector of strings of characters for the point labels}
  \item{clabel}{if not NULL, a character size for the labels, used with  \code{par("cex")*clabel}}
  \item{grid}{a logical value indicating whether a grid in the background of the plot should be drawn}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{cgrid}{a character size, parameter used with par("cex")*\code{cgrid} to indicate the mesh of the grid}
  \item{fullcircle}{a logical value indicating whether the complete circle sould be drawn}
  \item{box}{a logical value indcating whether a box should be drawn}
  \item{add.plot}{if TRUE uses the current graphics window}
}
\examples{
data (olympic)
dudi1 <- dudi.pca(olympic$tab, scan = FALSE) # a normed PCA
par(mfrow = c(2,2))
s.corcircle(dudi1$co, lab = names(olympic$tab))
s.corcircle(dudi1$co, cgrid = 0, full = FALSE, clab = 0.8)
s.corcircle(dudi1$co, lab = as.character(1:11), cgrid = 2, 
    full = FALSE, sub = "Correlation circle", csub = 2.5, 
    possub = "bottomleft", box = TRUE)
s.arrow(dudi1$co, clab = 1)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{s.distri}
\alias{s.distri}
\title{Plot of a frequency distribution}
\description{
performs the scatter diagram of a frequency distribution. 
}
\usage{
s.distri(dfxy, dfdistri, xax = 1, yax = 2, cstar = 1, 
    cellipse = 1.5, axesell = TRUE, label = names(dfdistri), 
    clabel = 0, cpoint = 1, pch = 20, xlim = NULL, ylim = NULL, 
    grid = TRUE, addaxes = TRUE, origin = c(0,0), 
    include.origin = TRUE, sub = "", csub = 1, possub = "bottomleft", 
    cgrid = 1, pixmap = NULL, contour = NULL, area = NULL, add.plot = FALSE)
}
\arguments{
  \item{dfxy}{a data frame containing two columns for the axes}
  \item{dfdistri}{a data frame containing the mass distributions in columns}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{cstar}{a number between 0 and 1 which defines the length of the star size}
  \item{cellipse}{a positive coefficient for the inertia ellipse size}
  \item{axesell}{a logical value indicating whether the ellipse axes should be drawn}
  \item{label}{a vector of strings of characters for the distribution centers labels}
  \item{clabel}{if not NULL, a character size for the labels, used with \code{par("cex")*clabel}}
  \item{cpoint}{a character size for plotting the points, used with \code{par("cex")*cpoint}. If zero, no points are drawn}
  \item{pch}{if \code{cpoint} > 0, an integer specifying the symbol or the single character to be used in plotting points}
  \item{xlim}{the ranges to be encompassed by the x, if NULL they are computed}
  \item{ylim}{the ranges to be encompassed by the y, if NULL they are computed}
  \item{grid}{a logical value indicating whether a grid in the background of the plot should be drawn}
  \item{addaxes}{a logical value indicating whether the axes should be plotted}
  \item{origin}{the fixed point in the graph space, for example c(0,0) the origin axes}
  \item{include.origin}{a logical value indicating whether the point "origin" should be belonged to the graph space}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{cgrid}{a character size, parameter used with par("cex")* \code{cgrid} to indicate the mesh of the grid}
  \item{pixmap}{an object 'pixmap' displayed in the map background}
  \item{contour}{a data frame with 4 columns to plot the contour of the map : each row gives a line (x1,y1,x2,y2)}
  \item{area}{a data frame of class 'area' to plot a set of surface units in contour}
  \item{add.plot}{if TRUE uses the current graphics window}
}
\examples{
xy <- cbind.data.frame(x = runif(200,-1,1), y = runif(200,-1,1))
distri <- data.frame(w1 = rpois(200, xy$x * (xy$x > 0)))
s.value(xy, distri$w1, cpoi = 1)
s.distri(xy, distri, add.p = TRUE)

w1 <- as.numeric((xy$x> 0) & (xy$y > 0))
w2 <- ((xy$x > 0) & (xy$y < 0)) * (1 - xy$y) * xy$x
w3 <- ((xy$x < 0) & (xy$y > 0)) * (1 - xy$x) * xy$y
w4 <- ((xy$x < 0) & (xy$y < 0)) * xy$y * xy$x

distri <- data.frame(a = w1 / sum(w1), b = w2 / sum(w2), 
    c = w3 / sum(w3), d = w4 / sum(w4))
s.value(xy, unlist(apply(distri, 1, sum)), cleg = 0, csi = 0.75)
s.distri(xy, distri, clab = 2, add.p = TRUE)

data(rpjdl)
xy <- dudi.coa(rpjdl$fau, scan = FALSE)$li
par(mfrow = c(3,4))
for (i in c(1,5,8,20,21,23,26,33,36,44,47,49)){
s.distri(xy, rpjdl$fau[,i], cell = 1.5, sub = rpjdl$frlab[i], 
    csub = 2, cgrid = 1.5)}
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{s.label}
\alias{s.label}
\title{Scatter Plot}
\description{
performs the scatter diagrams with labels. 
}
\usage{
s.label(dfxy, xax = 1, yax = 2, label = row.names(dfxy), 
    clabel = 1, pch = 20, cpoint = if (clabel == 0) 1 else 0, 
    neig = NULL, cneig = 2, xlim = NULL, ylim = NULL, grid = TRUE, 
    addaxes = TRUE, cgrid = 1, include.origin = TRUE, origin = c(0,0), 
    sub = "", csub = 1.25, possub = "bottomleft", pixmap = NULL, 
    contour = NULL, area = NULL, add.plot = FALSE)
}
\arguments{
  \item{dfxy}{a data frame with at least two coordinates}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{label}{a vector of strings of characters for the point labels}
  \item{clabel}{if not NULL, a character size for the labels, used with \code{par("cex")*clabel}}
  \item{pch}{if \code{cpoint} > 0, an integer specifying the symbol or the single character to be used in plotting points}
  \item{cpoint}{a character size for plotting the points, used with \code{par("cex")*cpoint}. If zero, no points are drawn}
  \item{neig}{a neighbouring graph}
  \item{cneig}{a size for the neighbouring graph lines used with par("lwd")*\code{cneig}}
  \item{xlim}{the ranges to be encompassed by the x axis, if NULL, they are computed}
  \item{ylim}{the ranges to be encompassed by the y axis, if NULL, they are computed}
  \item{grid}{a logical value indicating whether a grid in the background of the plot should be drawn}
  \item{addaxes}{a logical value indicating whether the axes should be plotted}
  \item{cgrid}{a character size, parameter used with par("cex")* \code{cgrid} to indicate the mesh of the grid}
  \item{include.origin}{a logical value indicating whether the point "origin" should be belonged to the graph space}
  \item{origin}{the fixed point in the graph space, for example c(0,0) the origin axes}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{pixmap}{an object 'pixmap' displayed in the map background}
  \item{contour}{a data frame with 4 columns to plot the contour of the map : each row gives a line (x1,y1,x2,y2)}
  \item{area}{a data frame of class 'area' to plot a set of surface units in contour}
  \item{add.plot}{if TRUE uses the current graphics window}
}
\examples{
layout(matrix(c(1,2,3,2), 2, 2))
data(atlas)
s.label(atlas$xy, lab = atlas$names.district, 
    area = atlas$area, inc = FALSE, addax = FALSE)
data(mafragh)
s.label(mafragh$xy, inc = FALSE, neig = mafragh$neig, addax = FALSE)
data(irishdata)
s.label(irishdata$xy, inc = FALSE, contour = irishdata$contour, 
    addax = FALSE)

par(mfrow = c(2,2))
cha <- ls()
s.label(cbind.data.frame(runif(length(cha)), 
    runif(length(cha))), lab = cha)
x <- runif(50,-2,2) ; y <- runif(50,-2,2) ; z <- x^2 + y^2
s.label(data.frame(x,y), lab = as.character(z < 1))
s.label(data.frame(x,y), clab = 0, cpoi = 1, add.plot = TRUE)
symbols(0, 0, circles = 1, add = TRUE, inch = FALSE)
s.label(cbind.data.frame(runif(100,0,10), runif(100,5,12)), 
	incl = FALSE, clab = 0)
s.label(cbind.data.frame(runif(100,-3,12),
	runif(100,2,10)), cl = 0, cp = 2, include = FALSE)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{s.match}
\alias{s.match}
\title{Plot of Paired Coordinates}
\description{
performs the scatter diagram for a paired coordinates. 
}
\usage{
s.match(df1xy, df2xy, xax = 1, yax = 2, pch = 20, cpoint = 1, 
    label = row.names(df1xy), clabel=1, edge = TRUE, xlim = NULL, 
    ylim = NULL, grid = TRUE, addaxes = TRUE, cgrid = 1, 
    include.origin = TRUE, origin = c(0,0), sub = "", csub = 1.25, 
    possub = "bottomleft", pixmap = NULL, contour = NULL, area = NULL, 
    add.plot = FALSE)
}
\arguments{
  \item{df1xy}{a data frame containing two columns from the first system}
  \item{df2xy}{a data frame containing two columns from teh second system}
  \item{xax}{the column number for the x-axis of both the two systems}
  \item{yax}{the column number for the y-axis of both the two systems}
  \item{pch}{if \code{cpoint} > 0, an integer specifying the symbol or the single character to be used in plotting points}
  \item{cpoint}{a character size for plotting the points, used with \code{par("cex")*cpoint}. If zero, no points are drawn }
  \item{label}{a vector of strings of characters for the couple labels}
  \item{clabel}{if not NULL, a character size for the labels, used with \code{par("cex")*clabel} }
  \item{edge}{If TRUE the arrows are plotted, otherwise only the segments are drawn}
  \item{xlim}{the ranges to be encompassed by the x axis, if NULL they are computed}
  \item{ylim}{the ranges to be encompassed by the y axis, if NULL they are computed}
  \item{grid}{a logical value indicating whether a grid in the background of the plot should be drawn}
  \item{addaxes}{a logical value indicating whether the axes should be plotted}
  \item{cgrid}{a character size, parameter used with par("cex")* \code{cgrid} to indicate the mesh of the grid}
  \item{include.origin}{a logical value indicating whether the point "origin" should be belonged to the graph space}
  \item{origin}{the fixed point in the graph space, for example c(0,0) the origin axes}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{pixmap}{aan object 'pixmap' displayed in the map background}
  \item{contour}{a data frame with 4 columns to plot the contour of the map : each row gives a line (x1,y1,x2,y2)}
  \item{area}{a data frame of class 'area' to plot a set of surface units in contour}
  \item{add.plot}{if TRUE uses the current graphics window}
}
\examples{
X <- data.frame(x = runif(50,-1,2), y = runif(50,-1,2))
Y <- X + rnorm(100, sd = 0.3)
par(mfrow = c(2,2))
s.match(X, Y)
s.match(X, Y, edge = FALSE, clab = 0)
s.match(X, Y, edge = FALSE, clab = 0)
s.label(X, clab = 1, add.plot = TRUE)
s.label(Y, clab = 0.75, add.plot = TRUE)
s.match(Y, X, clab = 0)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{s.traject}
\alias{s.traject}
\title{Trajectory Plot}
\description{
performs the scatter diagram with trajectories. 
}
\usage{
s.traject(dfxy, fac = factor(rep(1, nrow(dfxy))), 
    ord = (1:length(fac)),  xax = 1, yax = 2, label = levels(fac), 
    clabel = 1, cpoint = 1, pch = 20, xlim = NULL, ylim = NULL, 
    grid = TRUE, addaxes = TRUE, edge = TRUE, origin = c(0,0), 
    include.origin = TRUE, sub = "", csub = 1, possub = "bottomleft", 
    cgrid = 1, pixmap = NULL, contour = NULL, area = NULL, add.plot = FALSE)
}
\arguments{
  \item{dfxy}{a data frame containing two columns for the axes}
  \item{fac}{a factor partioning the rows of the data frame in classes}
  \item{ord}{a vector of length equal to fac. The trajectory is drawn in an ascending order of the ord values}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{label}{a vector of strings of characters for the point labels}
  \item{clabel}{if not NULL, a character size for the labels, used with \code{par("cex")*clabel}}
  \item{cpoint}{a character size for plotting the points, used with \code{par("cex")*cpoint}. If zero, no points are drawn}
  \item{pch}{if \code{cpoint} > 0, an integer specifying the symbol or the single character to be used in plotting points}
  \item{xlim}{the ranges to be encompassed by the x, if NULL they are computed}
  \item{ylim}{the ranges to be encompassed by the y, if NULL they are computed}
  \item{grid}{a logical value indicating whether a grid in the background of the plot should be drawn}
  \item{addaxes}{a logical value indicating whether the axes should be plotted}
  \item{edge}{if TRUE the arrows are plotted, otherwhise only the segments}
  \item{origin}{the fixed point in the graph space, for example c(0,0) the origin axes}
  \item{include.origin}{a logical value indicating whether the point "origin" should be belonged to the graph space}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{cgrid}{a character size, parameter used with \code{par("cex")*cgrid} to indicate the mesh of the grid}
  \item{pixmap}{aan object 'pixmap' displayed in the map background}
  \item{contour}{a data frame with 4 columns to plot the contour of the map : each row gives a line (x1,y1,x2,y2)}
  \item{area}{a data frame of class 'area' to plot a set of surface units in contour}
  \item{add.plot}{if TRUE uses the current graphics window}
}
\examples{
rw <- function(a){
    x <- 0
    for(i in 1:49) x <- c(x,x[length(x)] + runif(1,-1,1))
    x
}
y <- unlist(lapply(1:5, rw))
x <- unlist(lapply(1:5, rw))
z <- gl(5,50)
s.traject(data.frame(x,y), z, edge = FALSE)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{s.value}
\alias{s.value}
\title{Representation of a value in a graph}
\description{
performs the scatter diagram. 
}
\usage{
s.value(dfxy, z, xax = 1, yax = 2, method = c("squaresize", "greylevel"), 
    csize = 1, cpoint = 0, pch = 20, clegend = 0.75, neig = NULL, 
    cneig = 1, xlim = NULL, ylim = NULL, grid = TRUE, addaxes = TRUE, 
    cgrid = 0.75, include.origin = TRUE, origin = c(0,0), sub = "", 
    csub = 1, possub = "topleft", pixmap = NULL, contour = NULL, 
    area = NULL, add.plot = FALSE)
}
\arguments{
  \item{dfxy}{a data frame with two coordinates}
  \item{z}{a vector of the values corresponding to the rows of \code{dfxy}}
  \item{xax}{column for the x axis}
  \item{yax}{column for the y axis}
  \item{method}{a string of characters \cr
  	"squaresize" gives black squares for positive values and white for negative values with a proportional area equal to the absolute value.  \cr
	"greylevel" gives squares of equal size with a grey level proportional to the value. By default the first choice}
  \item{csize}{a size coefficient for symbols}
  \item{cpoint}{a character size for plotting the points, used with \code{par("cex")*cpoint}. If zero, no points are drawn}
  \item{pch}{if \code{cpoint} > 0, an integer specifying the symbol or the single character to be used in plotting points}
  \item{clegend}{a character size for the legend used by \code{par("cex")*clegend}}
  \item{neig}{a neighbouring graph}
  \item{cneig}{a size for the neighbouring graph lines used with \code{par("lwd")*\code{cneig}}}
  \item{xlim}{the ranges to be encompassed by the x, if NULL they are computed}
  \item{ylim}{the ranges to be encompassed by the y, if NULL they are computed}
  \item{grid}{a logical value indicating whether a grid in the background of the plot should be drawn}
  \item{addaxes}{a logical value indicating whether the axes should be plotted}
  \item{cgrid}{a character size, parameter used with \code{par("cex")*cgrid} to indicate the mesh of the grid}
  \item{include.origin}{a logical value indicating whether the point "origin" should be belonged to the graph space}
  \item{origin}{the fixed point in the graph space, for example c(0,0) the origin axes}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{pixmap}{an object 'pixmap' displayed in the map background}
  \item{contour}{a data frame with 4 columns to plot the contour of the map : each row gives a line (x1,y1,x2,y2)}
  \item{area}{a data frame of class 'area' to plot a set of surface units in contour}
  \item{add.plot}{if TRUE uses the current graphics window}
}
\examples{
xy <- cbind.data.frame(x = runif(500), y = runif(500))
z <- rnorm(500)
s.value(xy, z)

s.value(xy, z, method="greylevel")

data(rpjdl)
fau.coa <- dudi.coa(rpjdl$fau, scan = FALSE, nf = 3)
s.value(fau.coa$li, fau.coa$li[,3], csi = 0.75, cleg = 0.75)

data(irishdata)
par(mfrow = c(3,4))
irq0 <- data.frame(scale(irishdata$tab, scale = TRUE))
for (i in 1:12) {
    z <- irq0[,i] ; nam <- names(irq0)[i]
    s.value(irishdata$xy, irq0[,1], area = irishdata$area, csi = 3,
    csub = 2, sub = nam, cleg = 1.5, cgrid = 0, inc = FALSE,
    xlim = c(16,205), ylim = c(-50,268), adda = FALSE, grid = FALSE)
}
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{santacatalina}
\alias{santacatalina}
\docType{data}
\title{Indirect Ordination}
\description{
This data set gives the densities per hectare of 11 species of trees 
for 10 transects of topographic moisture values (mean of several stations per class)
}
\usage{data(santacatalina)}
format{
a data frame with 11 rows and 10 columns
}
\source{
Gauch, H. G. J., Chase, G. B. and Whittaker R. H. (1974)\cr
Ordination of vegetation samples by Gaussian species distributions.\cr
\emph{Ecology}, \bold{55}, 1382--1390.
}
\examples{
data(santacatalina)
par(mfrow = c(2,2))
table.value(log(santacatalina + 1), grid = TRUE)
table.value(log(santacatalina + 1)[,sample(10)], grid = TRUE)
coa1 <- dudi.coa(log(santacatalina + 1), scan = FALSE) # 2 factors
table.value(log(santacatalina + 1)[order(coa1$li[,1]), 
    order(coa1$co[,1])], grid = TRUE) 
scatter(coa1, posi = "bottom")
}
\keyword{datasets}
\eof
\name{sarcelles}
\alias{sarcelles}
\docType{data}
\title{Array of Recapture of Rings}
\description{
The data frame \code{sarcelles$tab} contains the number of the winter teals (Anas C. Crecca) for which the ring was retrieved in the area i during the month j (n=3049)
}
\usage{data(sarcelles)}
\format{
    \code{sarcelles} is a list of 4 components.
    \enumerate{
    \item{tab}{is a data frame with 14 rows-areas and 12 columns-months.}
    \item{xy}{is a data frame with the 2 spatial coordinates of the 14 region centers.}
    \item{neig}{is the neighbouring graph between areas, object of the class 'neig'.}
    \item{col.names}{is a vector containing the month items}
    }
}
\source{
 Lebreton, J.D. (1973)\cr
 Etude des dplacements saisonniers des Sarcelles d'hiver, Anas c. crecca L., hivernant en Camargue  l'aide de l'analyse factorielle des correspondances.\cr
 \emph{Compte rendu hebdomadaire des sances de l'Acadmie des sciences}, Paris, D, III, \bold{277}, 2417--2420.
}
\examples{
# depends of pixmap
if (require(pixmap, quietly=TRUE)) {
	#bkgnd.pnm <- read.pnm(system.file("pictures/sarcelles.pnm", package = "ade4"))
	data(sarcelles)
	par(mfrow = c(4,3))
	for(i in 1:12) {
    #s.distri(sarcelles$xy, sarcelles$tab[,i], pixmap = bkgnd.pnm, sub = sarcelles$col.names[i], clab = 0, csub = 2)
    s.value(sarcelles$xy, sarcelles$tab[,i], add.plot = TRUE, cleg = 0)
	}
}
}
\keyword{datasets}
\eof
\name{scalewt}
\alias{scalewt}
\title{Centring and Scaling a Matrix of Any Weighting}
\description{
transforms a numeric matrix in a centred and scaled matrix for any weighting. 
}
\usage{
scalewt(X, wt = rep(1, nrow(X)), center = TRUE, scale = TRUE)
}
\arguments{
  \item{X}{a numeric matrix (like object)}
  \item{wt}{a vector of weighting}
  \item{center}{a logical value indicating whether the array should be centred}
  \item{scale}{a logical value indicating whether the array should be scaled}
}
\value{
returns a centred, scaled matrix
}
\note{The norms are calculated with 1/n and the columns of null variance are still equal to zero.
}
\examples{
scalewt(matrix(1:12,4,3))
scale((matrix(1:12,4,3)))
scale(matrix(1,4,3))
scalewt(matrix(1,4,3))
}
\keyword{utilities}
\eof
\name{scatter}
\alias{scatter}
\alias{scatterutil.base}
\alias{add.scatter.eig}
\alias{scatterutil.chull}
\alias{scatterutil.eigen}
\alias{scatterutil.ellipse}
\alias{scatterutil.eti.circ}
\alias{scatterutil.eti}
\alias{scatterutil.grid}
\alias{scatterutil.legend.bw.square}
\alias{scatterutil.legend.square.grey}
\alias{scatterutil.legendgris}
\alias{scatterutil.scaling}
\alias{scatterutil.star}
\alias{scatterutil.sub}
\title{Scatter Plot}
\description{
scatter is a generic function. It has methods for the classes 'coa', 'dudi', 'fca', 'acm' and 'pco'.\cr
The scale of the grid is situated on the right-top of the graph.\cr
The points are in the middle of the labels.\cr
This process plots the graphs of the multivariate analyses.\cr
The two axes have the same scale.\cr
}
\usage{
scatter(x, ...)
}
\arguments{
  \item{x}{an object used to select a method}
  \item{\dots}{\code{\dots} further arguments passed to or from other methods}
}
\details{
  The functions scatter use some utilities functions :\cr
  \item{scatterutil.base}{defines the bottom of the plot for all scatters}
  \item{scatterutil.chull}{plots the polygons of the external contour}
  \item{scatterutil.eigen}{plots the eigenvalues bar plot}
  \item{scatterutil.ellipse}{plots an inertia ellipse for a weighting distribution}
  \item{scatterutil.eti.circ}{puts labels on a correlation circle}
  \item{scatterutil.eti}{puts labels centred on the points}
  \item{scatterutil.grid}{plots a grid and adds a legend}
  \item{scatterutil.legend.bw.square}{puts a legend of values by square size}
  \item{scatterutil.legend.square.grey}{puts a legend by squares and grey levels}
  \item{scatterutil.legendgris}{adds a legend of grey levels for the areas}
  \item{scatterutil.scaling}{to fit a plot on a background bipmap}
  \item{scatterutil.star}{plots a star for a weighting distribution}
  \item{scatterutil.sub}{adds a string of characters in sub-title of a graph}
  \item{add.scatter.eig}{adds a eigenvalues bar plot on a graph}
}
\seealso{\code{\link{s.arrow}},\code{\link{s.chull}},\code{\link{s.class}},
\code{\link{s.corcircle}},\code{\link{s.distri}},\code{\link{s.label}},
\code{\link{s.match}},\code{\link{s.traject}},\code{\link{s.value}}
}
\examples{
par(mfrow = c(3,3))
plot.new()
scatterutil.legendgris(1:20, 4, 1.6) 

plot.new()
scatterutil.sub("lkn5555555555lkn", csub = 2, possub = "bottomleft")
scatterutil.sub("lkn5555555555lkn", csub = 1, possub = "topleft")
scatterutil.sub("jdjjl", csub = 3, possub = "topright")
scatterutil.sub("**", csub = 2, possub = "bottomright")

x <- c(0.5,0.2,-0.5,-0.2) ; y <- c(0.2,0.5,-0.2,-0.5)
eti <- c("toto", "kjbk", "gdgiglgl", "sdfg")
plot(x, y, xlim = c(-1,1), ylim = c(-1,1))
scatterutil.eti.circ(x, y, eti, 2.5)
abline(0, 1, lty = 2) ; abline(0, -1, lty = 2)

x <- c(0.5,0.2,-0.5,-0.2) ; y <- c(0.2,0.5,-0.2,-0.5)
eti <- c("toto", "kjbk", "gdgiglgl", "sdfg")
plot(x, y, xlim = c(-1,1), ylim = c(-1,1))
scatterutil.eti(x, y, eti, 1.5)

plot(runif(10,-3,5), runif(10,-1,1), asp = 1)
scatterutil.grid(2)
abline(h = 0, v = 0, lwd = 3)

x <- runif(10,0,1) ; y <- rnorm(10) ; z <- rep(1,10)
plot(x,y) ; scatterutil.star(x, y, z, 0.5)
plot(x,y) ; scatterutil.star(x, y, z, 1)

x <- c(runif(10,0,0.5), runif(10,0.5,1))
y <- runif(20)
plot(x, y, asp = 1)	# asp=1 is essential to have perpendicular axes
scatterutil.ellipse(x, y, rep(c(1,0), c(10,10)), cell = 1.5, ax = TRUE)
scatterutil.ellipse(x, y, rep(c(0,1), c(10,10)), cell = 1.5, ax = TRUE)

x <- c(runif(100,0,0.75), runif(100,0.25,1))
y <- c(runif(100,0,0.75), runif(100,0.25,1))
z <- factor(rep(c(1,2), c(100,100)))
plot(x, y, pch = rep(c(1,20), c(100,100)))
scatterutil.chull(x, y, z, opt = c(0.25,0.50,0.75,1))
par(mfrow = c(1,1))
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{scatter.acm}
\alias{scatter.acm}
\title{Plot of the factorial maps in multiple correspondence analysis}
\description{
performs the scatter diagrams of a multiple correspondence analysis. 
}
\usage{
scatter.acm(x, xax = 1, yax = 2, csub = 2, possub = "topleft", ...)
}
\arguments{
  \item{x}{an object of class \code{acm}}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the legend position ("topleft", "topright", "bottomleft", "bottomright") in a array of figures}
  \item{\dots}{further arguments passed to or from other methods}
}
\examples{
data(lascaux)
scatter(dudi.acm(lascaux$ornem, sca = FALSE), csub = 3)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{scatter.coa}
\alias{scatter.coa}
\title{Plot of the factorial maps for a correspondence analysis}
\description{
performs the scatter diagrams of a correspondence analysis. 
}
\usage{
scatter.coa(x, xax = 1, yax = 2, method = 1:3, clab.row = 0.75, 
    clab.col = 1.25, posieig = "top", sub = NULL, csub = 2, \dots)
}
\arguments{
  \item{x}{an object of class \code{coa}}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{method}{an integer between 1 and 3 \cr
  	1 Rows and columns with the coordinates of lambda variance\cr
	2 Rows variance 1 and columns by averaging\cr
	3 Columns variance 1 and rows by averaging}
  \item{clab.row}{a character size for the rows}
  \item{clab.col}{a character size for the columns}
  \item{posieig}{if "top" the eigenvalues bar plot is upside,vif "bottom" it is downside, if "none" no plot}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{\dots}{further arguments passed to or from other methods}
}
\references{Oksanen, J. (1987) Problems of joint display of species and site scores in correspondence analysis. \emph{Vegetatio}, \bold{72}, 51--57.
}
\examples{
data(housetasks)
par(mfrow = c(2,2))
w <- dudi.coa(housetasks, scan = FALSE)
scatter.dudi(w, sub = "0 / To be avoided")
scatter.coa(w, method = 1, sub = "1 / Standard", posieig = "none")
scatter.coa(w, method = 2, 
    sub = "2 / Columns -> averaging -> Rows", posieig = "none")
scatter.coa(w, method = 3, 
    sub = "3 / Rows -> averaging -> Columns ", posieig = "none")
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{scatter.dudi}
\alias{scatter.dudi}
\title{Plot of the Factorial Maps}
\description{
performs the scatter diagrams of objects of class \code{dudi}. 
}
\usage{
scatter.dudi(x, xax = 1, yax = 2, clab.row = 0.5, clab.col = 1, 
    permute = FALSE, posieig = "top", sub = NULL, \dots)
}
\arguments{
  \item{x}{an object of class \code{dudi}}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{clab.row}{a character size for the rows}
  \item{clab.col}{a character size for the columns}
  \item{permute}{if FALSE, the rows are plotted by points and the columns by arrows. If TRUE it is the opposite.}
  \item{posieig}{if "top" the eigenvalues bar plot is upside,vif "bottom" it is downside, if "none" no plot}
  \item{sub}{a string of characters to be inserted as legend}
  \item{\dots}{further arguments passed to or from other methods}
}
\details{
\code{scatter.dudi} is a factorial map of individuals and the projection of the vectors of the canonical basis multiplied by a constante of rescaling. In the eigenvalues bar plot,the used axes for the plot are in black, the other kept axes in grey and the other in white.
}
\examples{
data(deug)
scatter(dd1 <- dudi.pca(deug$tab, scannf = FALSE, nf = 4), 
    posieig = "bottom")

data(rhone)
dd1 <- dudi.pca(rhone$tab, nf = 4, scann = FALSE)
scatter(dd1, sub = "Principal component analysis")
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{scatter.fca}
\alias{scatter.fca}
\title{Plot of the factorial maps for a fuzzy correspondence analysis}
\description{
performs the scatter diagrams of a fuzzy correspondence analysis. 
}
\usage{
scatter.fca(x, xax = 1, yax = 2, clab.moda = 1, labels = names(x$tab), 
    sub = NULL, csub = 2, \dots)
}
\arguments{
  \item{x}{an object of class \code{fca}}
  \item{xax}{the column number for the x-axis}
  \item{yax}{the column number for the y-axis}
  \item{clab.moda}{the character size to write the modalities}
  \item{labels}{a vector of strings of characters for the labels of the modalities}
  \item{sub}{a vector of strings of characters to be inserted as legend in each figure}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{\dots}{further arguments passed to or from other methods}
}
\examples{
data(coleo)
coleo.fuzzy <- prep.fuzzy.var(coleo$tab, coleo$col.blocks)
fca1 <- dudi.fca(coleo.fuzzy, sca = FALSE, nf = 3)
scatter(fca1, labels = coleo$moda.names, clab.moda = 1.5,
	sub = names(coleo$col.blocks), csub = 3)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{sco.boxplot}
\alias{sco.boxplot}
\title{Representation of the link between a variable and a set of qualitative variables}
\description{
represents the link between a variable and a set of qualitative variables. 
}
\usage{
sco.boxplot(score, df, labels = names(df), clabel = 1, xlim = NULL, 
    grid = TRUE, cgrid = 0.75, include.origin = TRUE, origin = 0, 
    sub = NULL, csub = 1)
}
\arguments{
  \item{score}{a numeric vector}
  \item{df}{a data frame with only factors}
  \item{labels}{a vector of strings of characters for the labels of variables}
  \item{clabel}{if not NULL, a character size for the labels, used with  \code{par("cex")*clabel}}
  \item{xlim}{the ranges to be encompassed by the x axis, if NULL they are computed}
  \item{grid}{a logical value indicating whether the scale vertical lines should be drawn}
  \item{cgrid}{a character size, parameter used with \code{par("cex")*cgrid} to indicate the mesh of the scale}
  \item{include.origin}{a logical value indicating whether the point "origin" should be belonged to the graph space}
  \item{origin}{the fixed point in the graph space, for example 0 the origin axis}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
}
\examples{
w1 <- rnorm(100,-1)
w2 <- rnorm(100)
w3 <- rnorm(100,1)
f1 <- gl(3,100)
f2 <- gl(30,10)
sco.boxplot(c(w1,w2,w3), data.frame(f1,f2))

data(banque)
banque.acm <- dudi.acm(banque, scan = FALSE, nf = 4)
par(mfrow = c(1,3))
sco.boxplot(banque.acm$l1[,1], banque[,1:7], clab = 1.8)
sco.boxplot(banque.acm$l1[,1], banque[,8:14], clab = 1.8)
sco.boxplot(banque.acm$l1[,1], banque[,15:21], clab = 1.8)
par(mfrow = c(1,1))
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{sco.distri}
\alias{sco.distri}
\title{Representation by mean- standard deviation of a set of weight distributions on a numeric score}
\description{
represents the mean- standard deviation of a set of weight distributions on a numeric score. 
}
\usage{
sco.distri(score, df, y.rank = TRUE, csize = 1, labels = names(df), clabel = 1,
    xlim = NULL, grid = TRUE, cgrid = 0.75,
    include.origin = TRUE, origin = 0, sub = NULL, csub = 1)
}
\arguments{
  \item{score}{a numeric vector}
  \item{df}{a data frame with only positive or null values}
  \item{y.rank}{a logical value indicating whether the means should be classified in ascending order}
  \item{csize}{an integer indicating the size segment}
  \item{labels}{a vector of strings of characters for the labels of the variables}
  \item{clabel}{if not NULL, a character size for the labels, used with  \code{par("cex")*clabel}}
  \item{xlim}{the ranges to be encompassed by the x axis, if NULL they are computed}
  \item{grid}{a logical value indicating whether the scale vertical lines should be drawn}
  \item{cgrid}{a character size, parameter used with \code{par("cex")*cgrid} to indicate the mesh of the scale}
  \item{include.origin}{a logical value indicating whether the point "origin" should be belonged to the graph space}
  \item{origin}{the fixed point in the graph space, for example c(0,0) the origin axes}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
}
\examples{
w <-seq(-1, 1, le = 200)
distri <- data.frame(lapply(1:50, 
    function(x) sample((200:1)) * ((w >= (-x/50)) & (w <= x/50)) ))
names(distri) <- paste("w", 1:50, sep = "")
par(mfrow = c(1,2))
sco.distri(w, distri, csi = 1.5)
sco.distri(w, distri, y.rank = FALSE, csi = 1.5)
par(mfrow = c(1,1))

data(rpjdl)
coa2 <- dudi.coa(rpjdl$fau, FALSE)
sco.distri(coa2$li[,1], rpjdl$fau, lab = rpjdl$frlab, clab = 0.8)

data(doubs)
par(mfrow = c(2,2))
poi.coa <- dudi.coa(doubs$poi, scann = FALSE)
sco.distri(poi.coa$l1[,1], doubs$poi)
poi.nsc <- dudi.nsc(doubs$poi, scann = FALSE)
sco.distri(poi.nsc$l1[,1], doubs$poi)
s.label(poi.coa$l1)
s.label(poi.nsc$l1)

data(rpjdl)
fau.coa <- dudi.coa(rpjdl$fau, scann = FALSE)
sco.distri(fau.coa$l1[,1], rpjdl$fau)
fau.nsc <- dudi.nsc(rpjdl$fau, scann = FALSE)
sco.distri(fau.nsc$l1[,1], rpjdl$fau)
s.label(fau.coa$l1)
s.label(fau.nsc$l1)

par(mfrow = c(1,1))
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{sco.quant}
\alias{sco.quant}
\title{Graph to Analyse the Relation between a Score and Quantitative Variables}
\description{
represents the graphs to analyse the relation between a score and quantitative variables. 
}
\usage{
sco.quant (score, df, fac = NULL, clabel = 1, abline = FALSE, 
    sub = names(df), csub = 2, possub = "topleft") 
}
\arguments{
  \item{score}{a numeric vector}
  \item{df}{a data frame which rows equal to the score length}
  \item{fac}{a factor with the same length than the score}
  \item{clabel}{character size for the class labels (if any) used with \code{par("cex")*clabel}}
  \item{abline}{a logical value indicating whether a regression line should be added}
  \item{sub}{a vector of strings of characters for the labels of variables}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
}
\examples{
w <- runif(100, -5, 10)
fw <- cut (w, 5)
levels(fw) <- LETTERS[1:5]
wX <- data.frame(matrix(w + rnorm(900, sd = (1:900) / 100), 100, 9))
sco.quant(w, wX, fac = fw, abline = TRUE, clab = 2, csub = 3)
}
\keyword{hplot}
\keyword{multivariate}
\eof
\name{score}
\alias{score}
\alias{scoreutil.base}
\title{Graphs for One Dimension}
\description{
 score is a generic function. It proposes methods for the objects 'coa', 'acm', 'mix', 'pca'.}
\usage{
score(x, ...)
scoreutil.base(y, xlim, grid, cgrid, include.origin, origin, sub, csub) 
}
\arguments{
  \item{x}{an object used to select a method}
  \item{\dots}{further arguments passed to or from other methods}
  \item{y}{a numeric vector}
  \item{xlim}{the ranges to be encompassed by the x axis, if NULL they are computed}
  \item{grid}{a logical value indicating whether the scale vertical lines should be drawn}
  \item{cgrid}{a character size, parameter used with \code{par("cex")*cgrid} to indicate the mesh of the scale}
  \item{include.origin}{a logical value indicating whether the point "origin" should be belonged to the graph space}
  \item{origin}{the fixed point in the graph space, for example 0 the origin axis}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
}
\details{
  \code{scoreutil.base} is a utility function - not for the user - to define the bottom of the layout of all \code{score}.
}
\seealso{\code{\link{sco.boxplot}}, \code{\link{sco.distri}}, \code{\link{sco.quant}}
}
\examples{
# par(mar = c(1,1,1,1))
# scoreutil.base (runif(20,3,7), xlim = NULL, grid = TRUE, cgrid = 0.8, include.origin = TRUE, origin = 0, sub = "Uniform", csub = 1)
# returns the value of the user coordinate of the low line.  
# The user window id defined with c(0,1) in ordinate.
# box()
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{score.acm}
\alias{score.acm}
\title{Graphs to study one factor in a Multiple Correspondence Analysis}
\description{
performs the graphs to study one factor in a Multiple Correspondence Analysis. 
}
\usage{
score.acm(x, xax = 1, which.var = NULL, mfrow = NULL, 
    sub = names(oritab), csub = 2, possub = "topleft", \dots)
}
\arguments{
  \item{x}{an object of class \code{acm}}
  \item{xax}{the column number for the used axis}
  \item{which.var}{the numbers of the kept columns for the analysis, otherwise all columns}
  \item{mfrow}{a vector of the form "c(nr,nc)", otherwise computed by a special own function \code{n2mfrow}}
  \item{sub}{a vector of strings of characters to be inserted as sub-titles, otherwise the variable names of the initial array}
  \item{csub}{a character size for the sub-titles}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{\dots}{further arguments passed to or from other methods}
}
\examples{
data(banque)
banque.acm <- dudi.acm(banque, scann = FALSE, nf = 3)
score(banque.acm, which = which(banque.acm$cr[,1] > 0.2), csub = 3)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{score.coa}
\alias{score.coa}
\title{Graphs to analyse a factor in a correspondence analysis}
\description{
represents the graphs to analyse a factor in a correspondence analysis. 
}
\usage{
score.coa (x, xax = 1, dotchart = FALSE, clab.r = 1, clab.c = 1, 
    csub = 1, cpoi = 1.5, cet = 1.5, ...)
}
\arguments{
  \item{x}{an object of class \code{coa}}
  \item{xax}{the column number for the used axis}
  \item{dotchart}{if TRUE the graph gives a "dual scaling", if FALSE a "reciprocal scaling"}
  \item{clab.r}{a character size for row labels}
  \item{clab.c}{a character size for column labels}
  \item{csub}{a character size for the sub-titles, used with \code{par("cex")*csub}}
  \item{cpoi}{a character size for the points}
  \item{cet}{a coefficient for the size of segments in standard deviation}
  \item{\dots}{further arguments passed to or from other methods}
}
\details{
In a "reciprocal scaling", the reference score is a numeric code centred and normalized of the non zero cells of the array which both maximizes the variance of means by row and by column. The bars are drawn with half the length of this standard deviation.
}
\references{Thioulouse, J. and Chessel D. (1992) A method for reciprocal scaling of species tolerance and sample diversity. \emph{Ecology}, \bold{73}, 670--680.
}
\examples{
layout(matrix(c(1,1,2,3), 2, 2), resp = FALSE)
data(aviurba)
dd1 <- dudi.coa(aviurba$fau, scan = FALSE)
score(dd1, clab.r = 0, clab.c = 0.75)
abline(v = 1, lty = 2, lwd = 3)
sco.distri(dd1$l1[,1], aviurba$fau)
sco.distri(dd1$c1[,1], data.frame(t(aviurba$fau)))

# 1 reciprocal scaling correspondence score -> species amplitude + sample diversity
# 2 sample score -> averaging -> species amplitude
# 3 species score -> averaging -> sample diversity

layout(matrix(c(1,1,2,3), 2, 2), resp = FALSE)
data(rpjdl)
rpjdl1 <- dudi.coa(rpjdl$fau, scan = FALSE)
score(rpjdl1, clab.r = 0, clab.c = 0.75)
if (require(mass, quietly = TRUE)) {
	data(caith)
	score(dudi.coa(caith, scan = FALSE), clab.r = 1.5, clab.c = 1.5, cpoi = 3)
	data(housetasks)
	score(dudi.coa(housetasks, scan = FALSE), clab.r = 1.25, clab.c = 1.25, 
		csub = 0, cpoi = 3)
}
par(mfrow = c(1,1))
score(rpjdl1, dotchart = TRUE, clab.r = 0)
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{score.mix}
\alias{score.mix}
\title{Graphs to Analyse a factor in a Mixed Analysis}
\description{
represents the graphs to analyse a factor in a mixed analysis. 
}
\usage{
score.mix (x, xax = 1, csub = 2, mfrow = NULL, which.var = NULL, \dots)
}
\arguments{
  \item{x}{an object of class \code{mix}}
  \item{xax}{the column number for the used axis}
  \item{csub}{a character size for the sub-titles, used with \code{par("cex")*csub}}
  \item{mfrow}{a vector of the form "c(nr,nc)", otherwise computed by a special own function \code{n2mfrow}}
  \item{which.var}{the numbers of the kept columns for the analysis, otherwise all columns }
  \item{\dots}{further arguments passed to or from other methods}
}
\examples{
data(lascaux)
w <- cbind.data.frame(lascaux$colo, lascaux$ornem)
dd <- dudi.mix(w, scan = FALSE, nf = 4, add = TRUE)
score(dd, which = which(dd$cr[,1] > 0.3))
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{score.pca}
\alias{score.pca}
\title{Graphs to Analyse a factor in PCA}
\description{
represents the graphs of a factor in a principal component analysis. 
}
\usage{
score.pca(x, xax = 1, which.var = NULL, mfrow = NULL, csub = 2, 
    sub = names(x$tab), abline = TRUE, \dots)
}
\arguments{
  \item{x}{an object of class \code{pca}}
  \item{xax}{the column number for the used axis}
  \item{which.var}{the numbers of the kept columns for the analysis, otherwise all columns}
  \item{mfrow}{a vector of the form "c(nr,nc)", otherwise computed by a special own function \code{n2mfrow}}
  \item{csub}{a character size for sub-titles, used with \code{par("cex")*csub}}
  \item{sub}{a vector of string of characters to be inserted as sub-titles, otherwise the names of the variables}
  \item{abline}{a logical value indicating whether a regression line should be added}
  \item{\dots}{further arguments passed to or from other methods}
}
\examples{
data(deug)
dd1 <- dudi.pca(deug$tab, scan = FALSE)
score(dd1, csub = 3)
 
# The correlations are :
dd1$co[,1]
# [1] 0.7925 0.6532 0.7410 0.5287 0.5539 0.7416 0.3336 0.2755 0.4172
}
\keyword{multivariate}
\keyword{hplot}
\eof
\name{seconde}
\alias{seconde}
\docType{data}
\title{Students and  Subjects}
\description{
The \code{seconde} data frame gives the marks of 22 students for 8 subjects. 
}
\usage{data(seconde)}
\format{
  This data frame (22,8) contains the following columns:
  \describe{
    \item{HGEO}{for History and Geography}
    \item{FRAN}{for French literature}
    \item{PHYS}{for Physics}
    \item{MATH}{for Mathematics}
    \item{BIOL}{for Biology}
    \item{ECON}{for Economy}
    \item{ANGL}{for English language}
    \item{ESPA}{for Spanish language}
  }
}
\source{
Personal communication
}
\examples{
data(seconde)
scatter(dudi.pca(seconde, scan = FALSE), clab.r = 1, clab.c = 1.5)
}
\keyword{datasets}
\eof
\name{sepan}
\alias{sepan}
\alias{plot.sepan}
\alias{print.sepan}
\alias{summary.sepan}
\title{Separated Analyses in a K-tables}
\description{
performs K separated multivariate analyses of an object of class \code{ktab} 
containing K tables. 
}
\usage{
sepan(X, nf = 2)
plot.sepan (x, mfrow = NULL, csub = 2, \dots)
summary.sepan (object, \dots)
print.sepan (x, \dots)
}
\arguments{
  \item{X}{an object of class 'ktab'}
  \item{nf}{an integer indicating the number of kept axes for each separated analysis}  
  \item{x, object}{an object of class 'sepan'}
  \item{mfrow}{a vector of the form "c(nr,nc)", otherwise computed by a special own function \code{n2mfrow}}
  \item{csub}{a character size for the sub-titles, used with \code{par("cex")*csub}}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
returns a list of class 'sepan' containing :
  \item{call}{a call order}
  \item{tab.names}{a vector of characters with the names of tables}
  \item{blo}{a numeric vector with the numbers of columns for each table}
  \item{rank}{a numeric vector with the rank of the studied matrix for each table}
  \item{Eig}{a numeric vector with all the eigenvalues}
  \item{Li}{a data frame with the row coordinates}
  \item{L1}{a data frame with the row normed scores}
  \item{Co}{a data frame with the column coordinates}
  \item{C1}{a data frame with the column normed coordinates}
  \item{TL}{a data frame with the factors for Li L1}
  \item{TC}{a data frame with the factors for Co C1}
}
\details{
The function plot on a 'sepan' object allows to compare inertias and structures between arrays.
In black, the eigenvalues of kept axes in the object 'sepan'.
}
\examples{
data(escopage)
w <- data.frame(scale(escopage$tab))
w <- ktab.data.frame(w, escopage$blo, tabnames = escopage$tab.names)
sep1 <- sepan(w)
sep1
summary(sep1)
plot(sep1)
}
\keyword{multivariate}
\eof
\name{skulls}
\alias{skulls}
\docType{data}
\title{Morphometric Evolution}
\description{
This data set gives four anthropometric measures of 30 egyptean 
skulls belonging to five different historical periods. 
}
\usage{data(skulls)}
\format{
The \code{skulls} data frame has 150 rows and 4 columns.
The measurements are made on 5 groups and 30 Egyptian skulls. The groups are defined as follows :\cr
1 - the early predynastic period (circa 4000 BC)\cr
2 - the late predynastic period (circa 3300 BC)\cr
3 - the 12th and 13th dynasties (circa 1850 BC)\cr
4 - the Ptolemiac period (circa 200 BC)\cr
5 - the Roman period (circa 150 BC)\cr
}
\source{
Thompson, A. and Randall-Maciver, R. (1905) \emph{Ancient races of the Thebaid}, Oxford University Press.
}
\references{
Manly, B.F. (1994) \emph{Multivariate Statistical Methods.\cr
A primer}, Second edition. Chapman & Hall, London. 1--215.\cr
The example is treated pp. 6, 13, 51, 64, 72, 107, 112 et 117.
}
\examples{
data(skulls)
pca1 <- dudi.pca(skulls, scan = FALSE)
fac <- gl(5, 30)
levels(fac) <- c("-4000", "-3300", "-1850", "-200", "+150")
dis.skulls <- discrimin(pca1, fac, scan = FALSE)
plot(dis.skulls, 1, 1)
}
\keyword{datasets}
\eof
\name{statis}
\alias{statis}
\alias{print.statis}
\alias{plot.statis}
\title{STATIS, a method for analysing K-tables}
\description{
performs a STATIS analysis of K-tables. 
}
\usage{
statis(X, scannf = TRUE, nf = 3, tol = 1e-07)
plot.statis (x, xax = 1, yax = 2, option = 1:4, \dots) 
print.statis (x, \dots) 
}
\arguments{
  \item{X}{an object of class 'ktab'}
  \item{scannf}{a logical value indicating whether the number of kept axes for the compromise should be asked}
  \item{nf}{if \code{scannf} FALSE, an integer indicating the number of kept axes for the compromise}
  \item{tol}{a tolerance threshold to test whether the distance matrix is Euclidean : an eigenvalue is considered positive if it is larger than \code{-tol*lambda1} where \code{lambda1} is the largest eigenvalue}
  \item{statis, x}{an object of class 'statis'}
  \item{xax, yax}{the numbers of the x-axis and the y-axis}
  \item{option}{an integer between 1 and 4, otherwise the 4 components of the plot are dispayed}
  \item{\dots}{further arguments passed to or from other methods}
}
\value{
\code{statis} returns a list of class 'statis' containing :
  \item{$RV}{a matrix with the all RV coefficients}
  \item{RV.eig}{a numeric vector with all the eigenvalues}
  \item{RV.coo}{a data frame with the array scores}
  \item{tab.names}{a vector of characters with the names of the arrays}
  \item{$RV.tabw}{a numeric vector with the array weigths}
  \item{nf}{an integer indicating the number of kept axes}
  \item{rank}{an integer indicating the rank of the studied matrix}
  \item{C.li}{a data frame with the row coordinates}
  \item{C.Co}{a data frame with the column coordinates}
  \item{T4}{a data frame with the principal vectors (for each table)}
  \item{TL}{a data frame with the factors (not used)}
  \item{TC}{a data frame with the factors for Co}
  \item{T4}{a data frame with the factors for T4}
}
\references{
Lavit, C. (1988) \emph{Analyse conjointe de tableaux quantitatifs}, Masson, Paris.\cr\cr
Lavit, C., Escoufier, Y., Sabatier, R. and Traissac, P. (1994) The ACT (Statis method). \emph{Computational Statistics and Data Analysis}, \bold{18}, 97--119.
}
\examples{
data(jv73)
kta1 <- ktab.within(within.pca(jv73$morpho, jv73$fac.riv, scann = FALSE))
statis1 <- statis(kta1, scann = FALSE)
plot(statis1)

dudi1 <- dudi.pca(jv73$poi, scann = FALSE, scal = FALSE)
wit1 <- within(dudi1, jv73$fac.riv, scann = FALSE)
kta3 <- ktab.within(wit1)
data(jv73)
statis3 <- statis(kta3, scann = FALSE)
plot(statis3)

s.arrow(statis3$C.li, cgrid = 0)

kplot(statis3, traj = TRUE, arrow = FALSE, unique = TRUE, 
    clab = 0, csub = 3, cpoi = 3)
statis3
}
\keyword{multivariate}
\eof
\name{steppe}
\alias{steppe}
\non_function{}
\title{Transect in the Vegetation}
\description{
This data set gives the presence-absence of 37 species on 515 sites. 
}
\usage{data(steppe)}
\format{
	\code{steppe} is a list of 2 components.
	\enumerate{
		\item{tab}{is a data frame with 512 rows (sites) and 37 variables (species) in presence-absence.}
		\item{esp.names}{is a vector of the species names.}
	}
}
\source{
Estve, J. (1978) Les mthodes d'ordination : lments pour une discussion.
in J. M. Legay and R. Tomassone, editors. 
\emph{Biomtrie et Ecologie}, Socit Franaise de Biomtrie, Paris, 223--250 
}
\examples{
par(mfrow = c(3,1))
data(steppe)
w1 <- col(as.matrix(steppe$tab[,1:15]))
w1 <- as.numeric(w1[steppe$tab[,1:15] > 0])
w2 <- row(as.matrix(steppe$tab[,1:15]))
w2 <- as.numeric(w2[steppe$tab[,1:15] > 0])
plot(w2, w1, pch = 20)
plot(dudi.pca(steppe$tab, scan = FALSE, scale = FALSE)$li[,1],
    pch = 20, ylab = "PCA", xlab = "", type = "b")
plot(dudi.coa(steppe$tab, scan = FALSE)$li[,1], pch = 20, 
    ylab = "COA", xlab = "", type = "b")
par(mfrow = c(1,1))
}
\keyword{datasets}
\eof
\name{supcol}
\alias{supcol}
\alias{supcol.coa}
\alias{supcol.default}
\title{Projections of Supplementary Columns}
\description{
performs projections of supplementary columns. 
}
\usage{
supcol(x, \dots)
supcol.default (x, Xsup, \dots) 
supcol.coa (x, Xsup, \dots) 
}
\arguments{
  \item{x}{an object used to select a method}
  \item{Xsup}{an array with the supplementary columns (\code{Xsup} and \code{x$tab} have the same row number)}
  \item{\dots}{further arguments passed to or from other methods}
}
\details{
If \code{supcol.default} is used, the column vectors of \code{Xsup} are projected without prior modification onto the principal components of dudi with the scalar product associated to the row weightings of dudi.
}
\value{
returns a list of two components :
\code{$tabsup} {data frame containing the array with the supplementary columns transformed or not}
\code{$cosup} {data frame containing the coordinates of the supplementary projections}
}
\examples{
data(rpjdl)
rpjdl.coa <- dudi.coa(rpjdl$fau, scan = FALSE, nf = 4)
rpjdl.coa$co[1:3,]
supcol (rpjdl.coa,rpjdl$fau[,1:3])$cosup # the same

data(doubs)
dudi1 <- dudi.pca(doubs$poi, scal = FALSE, scan = FALSE)
s.arrow(dudi1$co)
s.arrow(supcol.default(dudi1,data.frame(scalewt(doubs$mil)))$cosup,
    add.p = TRUE, clab = 2)
symbols(0, 0, circles = 1, inches = FALSE, add = TRUE)
}
\keyword{multivariate}
\eof
\name{suprow}
\alias{suprow}
\alias{suprow.coa}
\alias{suprow.pca}
\alias{suprow.default}
\title{Projections of Supplementary Rows}
\description{
performs projections of supplementary rows. 
}
\usage{ 
suprow.coa (x, Xsup, \dots) 
suprow.default (x, Xsup, \dots) 
suprow.pca (x, Xsup, \dots) 
}
\arguments{
  \item{x}{an object of class 'dudi'}
  \item{Xsup}{an array with the supplementary rows (\code{Xsup} and \code{x$tab} have the same column number)}
  \item{\dots}{further arguments passed to or from other methods}
}
\details{
If \code{suprow.default} is used, the column vectors of Xsup are projected without prior modifications onto the principal components of dudi with the scalar product associated to the row weightings of dudi.
}
\value{
returns a data frame containing the coordinates of the supplementary projections
}
\references{
Gower, J. C. (1967) Multivariate analysis and multivariate geometry. \emph{The statistician}, \bold{17}, 13--28.
}
\examples{
data(euro123)
par(mfrow = c(2,2))
w <- euro123[[2]]
dudi1 <- dudi.pca(w, scal = FALSE, scan = FALSE)
s.arrow(dudi1$c1, sub = "Classical", possub = "bottomright", csub = 2.5)
s.label(suprow(dudi1,w), add.plot = TRUE, clab = 0.75)

s.arrow(dudi1$c1,
    sub = "Without centring", possub = "bottomright", csub = 2.5)
s.label(suprow.default(dudi1,w), clab = 0.75, add.plot = TRUE)

triangle.plot(w, clab = 0.75, label = row.names(w), scal = FALSE)
triangle.plot(w, clab = 0.75, label = row.names(w), scal = TRUE)

data(rpjdl)
rpjdl.coa <- dudi.coa(rpjdl$fau, scann = FALSE, nf = 4)
rpjdl.coa$li[1:3,]
suprow(rpjdl.coa,rpjdl$fau[1:3,]) # idem

data(deug)
deug.dudi <- dudi.pca(df = deug$tab, center = deug$cent, 
    scale = FALSE, scannf = FALSE)
suprow(deug.dudi, deug$tab[1:3,]) # the supplementary individuals are centered
deug.dudi$li[1:3,]  # idem
}
\keyword{multivariate}
\eof
\name{syndicats}
\alias{syndicats}
\docType{data}
\title{Two Questions asked on a Sample of 1000 Respondents}
\description{
This data set is extracted from an opinion poll (period 1970-1980) on 1000 respondents. 
}
\usage{data(syndicats)}
\format{
The \code{syndicats} data frame has 5 rows and 4 columns.\cr
"Which politic family are you agreeing about ?" has 5 response items : 
\code{extgauche} (extreme left) \code{left} \code{center} \code{right} and \code{extdroite} (extreme right)\cr
"What do you think of the trade importance ?" has 4 response items :
\code{trop} (too important) \code{adequate} \code{insufficient} \code{nesaispas} (no opinion)
}
\source{
 unknown
}
\examples{
data(syndicats)
par(mfrow = c(1,2))
dudi1 <- dudi.coa(syndicats, scan = FALSE)
score (dudi1, 1, TRUE)
score (dudi1, 1, FALSE)
}
\keyword{datasets}
\eof
\name{table.cont}
\alias{table.cont}
\title{Plot of Contingency Tables}
\description{
presents a graph for viewing contingency tables. 
}
\usage{
table.cont(df, x = 1:ncol(df), y = 1:nrow(df),
    row.labels = row.names(df), col.labels = names(df),
    clabel.row = 1, clabel.col = 1, abmean.x = FALSE, abline.x = FALSE,
    abmean.y = FALSE, abline.y = FALSE, csize = 1, clegend = 0, grid = TRUE)
}
\arguments{
  \item{df}{a data frame with only positive or null values}
  \item{x}{a vector of values to position the columns}
  \item{y}{a vector of values to position the rows}
  \item{row.labels}{a character vector for the row labels}
  \item{col.labels}{a character vetor for the column labels}
  \item{clabel.row}{a character size for the row labels}
  \item{clabel.col}{a character size for the column labels}
  \item{abmean.x}{a logical value indicating whether the column conditional means should be drawn}
  \item{abline.x}{a logical value indicating whether the regression line of y onto x should be plotted}
  \item{abmean.y}{a logical value indicating whether the row conditional means should be drawn}
  \item{abline.y}{a logical value indicating whether the regression line of x onto y should be plotted}
  \item{csize}{a coefficient for the square size of the values}
  \item{clegend}{if not NULL, a character size for the legend used with  \code{par("cex")*clegend}}
  \item{grid}{a logical value indicating whether a grid in the background of the plot should be drawn}
}
\examples{
data(chats)
chatsw <- data.frame(t(chats))
chatscoa <- dudi.coa(chatsw, scann = FALSE)
table.cont(chatsw)

par(mfrow = c(2,2))
table.cont(chatsw, abmean.x = TRUE, csi = 2, abline.x = TRUE, 
    clabel.r = 1.5, clabel.c = 1.5)
table.cont(chatsw, abmean.y = TRUE, csi = 2, abline.y = TRUE, 
    clabel.r = 1.5, clabel.c = 1.5)
table.cont(chatsw, x = chatscoa$c1[,1], y = chatscoa$l1[,1],
    abmean.x = TRUE, csi = 2, abline.x = TRUE, clabel.r = 1.5, clabel.c = 1.5)
table.cont(chatsw, x = chatscoa$c1[,1], y = chatscoa$l1[,1],
    abmean.y = TRUE, csi = 2, abline.y = TRUE, clabel.r = 1.5, clabel.c = 1.5)

data(rpjdl)
w <- data.frame(t(rpjdl$fau))
wcoa <- dudi.coa(w, scann = FALSE)
par(mfrow = c(1,1))
table.cont(w, abmean.y = TRUE, x = wcoa$c1[,1], y = rank(wcoa$l1[,1]),
    csi = 0.2, clabel.c = 0, row.labels = rpjdl$lalab, clabel.r = 0.75)
}
\keyword{hplot}
\eof
\name{table.dist}
\alias{table.dist}
\title{Graph Display for Distance Matrices}
\description{
presents a graph for viewing distance matrices. 
}
\usage{
table.dist(d, x = 1:(attr(d, "Size")), labels = as.character(x), 
    clabel = 1, csize = 1, grid = TRUE)
}
\arguments{
  \item{d}{an object of class \code{'dist'}}
  \item{x}{a vector of the row and column positions}
  \item{labels}{a vector of strings of characters for the labels}
  \item{clabel}{a character size for the labels}
  \item{csize}{a coefficient for the circle size}
  \item{grid}{a logical value indicating whether a grid in the background of the plot should be drawn}
}
\examples{
data(eurodist)
table.dist(eurodist, labels = attr(eurodist, "Labels"))
}
\keyword{hplot}
\eof
\name{table.paint}
\alias{table.paint}
\title{Plot of the arrays by grey levels}
\description{
presents a graph for viewing the numbers of a table by grey levels. 
}
\usage{
table.paint(df, x = 1:ncol(df), y = nrow(df):1, 
    row.labels = row.names(df), col.labels = names(df), 
    clabel.row = 1, clabel.col = 1, csize = 1, clegend = 1)
}
\arguments{
  \item{df}{a data frame}
  \item{x}{a vector of values to position the columns, used only for the ordered values}
  \item{y}{a vector of values to position the rows, used only for the ordered values}
  \item{row.labels}{a character vector for the row labels}
  \item{col.labels}{a character vector for the column labels}
  \item{clabel.row}{a character size for the row labels}
  \item{clabel.col}{a character size for the column labels}
  \item{csize}{if 'clegend' not NULL, a coefficient for the legend size}
  \item{clegend}{a character size for the legend, otherwise no legend}
}
\examples{
data(rpjdl)
X <- data.frame(t(rpjdl$fau))
Y <- data.frame(t(rpjdl$mil))
layout(matrix(c(1,2,2,2,1,2,2,2,1,2,2,2,1,2,2,2), 4, 4))
coa1 <- dudi.coa(X, scan = FALSE)
x <- rank(coa1$co[,1])
y <- rank(coa1$li[,1])
table.paint(Y, x = x, y = 1:8, clabel.c = 0, cleg = 0)
abline(v = 114.9, lwd = 3, col = "red")
abline(v = 66.4, lwd = 3, col = "red")
table.paint(X, x = x, y = y, clabel.c = 0, cleg = 0,
    row.lab = paste("  ", row.names(X), sep = ""))
abline(v = 114.9, lwd = 3, col = "red")
abline(v = 66.4, lwd = 3, col = "red")
}
\keyword{hplot}
\eof
\name{table.value}
\alias{table.value}
\alias{table.prepare}
\title{Plot of the Arrays}
\description{
presents a graph for viewing the numbers of a table by square sizes. 
}
\usage{
table.value(df, x = 1:ncol(df), y = nrow(df):1, 
    row.labels = row.names(df), col.labels = names(df), clabel.row = 1, 
    clabel.col = 1, csize = 1, clegend = 1, grid = TRUE)
}
\arguments{
  \item{df}{a data frame}
  \item{x}{a vector of values to position the columns}
  \item{y}{a vector of values to position the rows}
  \item{row.labels}{a character vector for the row labels}
  \item{col.labels}{a character vector for the column labels}
  \item{clabel.row}{a character size for the row labels}
  \item{clabel.col}{a character size for the column labels}
  \item{csize}{a coefficient for the square size of the values}
  \item{clegend}{a character size for the legend (if 0, no legend)}
  \item{grid}{a logical value indicating whether the grid should be plotted}
}
\examples{
data(olympic)
w <- olympic$tab
w <- data.frame(scale(w))
wpca <- dudi.pca(w, scann = FALSE)
par(mfrow = c(1,3))
table.value(w, csi = 2, clabel.r = 2, clabel.c = 2)
table.value(w, y = rank(wpca$li[,1]), x = rank(wpca$co[,1]), csi = 2,
    clabel.r = 2, clabel.c = 2)
table.value(w, y = wpca$li[,1], x = wpca$co[,1], csi = 2, 
    clabel.r = 2, clabel.c = 2)
par(mfrow = c(1,1))
}
\keyword{hplot}
\eof
\name{tarentaise}
\alias{tarentaise}
\docType{data}
\title{Mountain Avifauna}
\description{
This data set gives informations between sites, species, environmental and biolgoical variables. 
}
\usage{data(tarentaise)}
\format{
	\code{tarentaise} is a list of 5 components.
	\enumerate{
		\item{ecol}{is a data frame with 376 sites and 98 bird species.}
		\item{frnames}{is a vector of the 98 French names of the species.}
		\item{alti}{is a vector giving the altitude of the 376 sites in m.}
		\item{envir}{is a data frame with 14 environmental variables.}
		\item{traits}{is a data frame with 29 biological variables of the 98 species.}
	}
}
\details{
The attribute \code{col.blocks} of the data frame \code{tarentaise$traits} indicates it is composed of 6 units of variables.
}
\source{
Original data from Hubert Tournier, University of Savoie and Philippe Lebreton, University of Lyon 1.
}
\references{
Lebreton, P., Tournier H. and Lebreton J. D. (1976)\cr
Etude de l'avifaune du Parc National de la Vanoise\cr
VI Recherches d'ordre quantitatif sur les Oiseaux forestiers de Vanoise.\cr
\emph{Travaux Scientifiques du parc National de la vanoise}, \bold{7}, 163--243.\cr\cr

Lebreton, Ph. and Martinot, J.P. (1998)\cr
Oiseaux de Vanoise. Guide de l'ornithologue en montagne.\cr
\emph{Libris}, Grenoble. 1--240.\cr\cr

Lebreton, Ph., Lebrun, Ph., Martinot, J.P., Miquet, A. and Tournier, H. (1999)\cr
Approche cologique de l'avifaune de la Vanoise.\cr
\emph{Travaux scientifiques du Parc national de la Vanoise}, \bold{21}, 7--304.
}
\examples{
data(tarentaise)
coa1 <- dudi.coa(tarentaise$ecol, sca = FALSE, nf = 2)
s.class(coa1$li, tarentaise$envir$alti, wt = coa1$lw)

acm1 <- dudi.acm(tarentaise$envir, sca = FALSE, nf = 2)
s.class(acm1$li, tarentaise$envir$alti)
}
\keyword{datasets}
\eof
\name{tortues}
\alias{tortues}
\docType{data}
\title{Morphological Study of the Painted Turtle}
\description{
This data set gives a morphological description (4 characters) of 48 turtles. 
}
\usage{data(tortues)}
\format{
a data frame with 48 rows and 4 columns (length (mm), maximum width(mm), height (mm), gender). 
}
\source{
Jolicur, P. and Mosimann, J. E. (1960)\cr
Size and shape variation in the painted turtle. A principal component analysis.\cr
\emph{Growth}, \bold{24}, 339--354.
}
\examples{
data(tortues)
xyz <- as.matrix(tortues[,1:3])
ref <- -svd(xyz)$u[,1]
pch0 <- c(1,20)[as.numeric(tortues$sex)]
plot(ref, xyz[,1], ylim = c(40,180), pch = pch0)
abline(lm(xyz[,1]~ -1 + ref))
points(ref,xyz[,2], pch = pch0)
abline(lm(xyz[,2]~ -1 + ref))
points(ref,xyz[,3], pch = pch0)
abline(lm(xyz[,3]~ -1 + ref))
}
\keyword{datasets}
\eof
\name{toxicity}
\alias{toxicity}
\docType{data}
\title{Homogeneous Table}
\description{
This data set gives the toxicity of 7 molecules on 16 targets
  expressed in -log(mol/liter)
}
\usage{data(toxicity)}
\format{
	\code{toxicity} is a list of 3 components.
	\enumerate{
		\item{tab}{is a data frame with 7 columns and 16 rows}
		\item{species}{is a vector of the names of the species in the 16 targets}
		\item{chemicals}{is a vector of the names of the 7 molecules}
	}
}
\source{
Devillers, J., Thioulouse, J. and Karcher W. (1993)\cr
Chemometrical Evaluation of Multispecies-Multichemical Data by Means of Graphical Techniques Combined with Multivariate Analyses.\cr
\emph{Ecotoxicology and Environnemental Safety}, \bold{26}, 333--345
}
\examples{
data(toxicity)
table.paint(toxicity$tab, row.lab = toxicity$species, 
    col.lab = toxicity$chemicals)

table.value(toxicity$tab, row.lab = toxicity$species, 
    col.lab = toxicity$chemicals)
}
\keyword{datasets}
\eof
\name{triangle.plot}
\alias{triangle.plot}
\alias{triangle.biplot}
\alias{triangle.param}
\alias{triangle.posipoint}
\alias{add.position.triangle}
\title{Triangular Plotting}
\description{
	Graphs for a dataframe with 3 columns of positive or null values\cr
	\code{triangle.plot} is a scatterplot\cr
	\code{triangle.biplot} is a paired scatterplots\cr
	\code{triangle.posipoint}, \code{triangle.param}, \code{add.position.triangle} are utilitaries functions. 
}
\usage{
triangle.plot(ta, label = as.character(1:nrow(ta)), clabel = 0, 
    cpoint = 1, draw.line = TRUE, addaxes = FALSE, addmean = FALSE, 
    labeltriangle = TRUE, sub = "", csub = 0, possub = "topright", 
    show.position = TRUE, scale = TRUE, min3 = NULL, max3 = NULL)
triangle.biplot (ta1, ta2, label = as.character(1:nrow(ta1)), 
    draw.line = TRUE, show.position = TRUE, scale = TRUE)
}
\arguments{
  \item{ta, ta1, ta2,}{data frame with three columns, will be transformed in \bold{percentages} by rows}
  \item{label}{a vector of strings of characters for the point labels}
  \item{clabel}{if not NULL, a character size for the labels, used with  \code{par("cex")*clabel}}
  \item{cpoint}{a character size for plotting the points, used with \code{par("cex")*cpoint}. If zero, no points are drawn}
  \item{draw.line}{a logical value indicating whether the lines into the triangle should be drawn}
  \item{addaxes}{a logical value indicating whether the principal axes should be drawn}
  \item{addmean}{a logical value indicating whether the mean should be plotted}
  \item{labeltriangle}{a logical value indicating whether the variable names should be wrote}
  \item{sub}{a string of characters to be inserted as legend}
  \item{csub}{a character size for the legend, used with \code{par("cex")*csub}}
  \item{possub}{a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")}
  \item{show.position}{a logical value indicating whether the used triangle should be shown in the complete one}
  \item{scale}{a logical value indicating whether the smaller equilateral triangle containing the plot should be used}
  \item{min3}{If scale is FALSE, a vector of three values for the minima e.g. c(0.1,0.1,0.1) can be used}
  \item{max3}{If scale is FALSE a vector of three values for the maxima e.g. c(0.9,0.9,0.9) can be used}
}
\examples{
data (euro123)
tot <- rbind.data.frame(euro123$in78, euro123$in86, euro123$in97)
row.names(tot) <- paste(row.names(euro123$in78), rep(c(1,2,3), rep(12,3)),
    sep = "")
triangle.plot(tot, label = row.names(tot), clab = 1)

par(mfrow = c(2,2))
triangle.plot(euro123$in78, clab = 0, cpoi = 2, addmean = TRUE, 
    show = FALSE)
triangle.plot(euro123$in86, label = row.names(euro123$in78), clab = 0.8)
triangle.biplot(euro123$in78, euro123$in86)
triangle.plot(rbind.data.frame(euro123$in78, euro123$in86), clab = 1, 
    addaxes = TRUE, sub = "Principal axis", csub = 2, possub = "topright")

triangle.plot(euro123[[1]], min3 = c(0,0.2,0.3), max3 = c(0.5,0.7,0.8),
    clab = 1, label = row.names(euro123[[1]]), addax = TRUE)
triangle.plot(euro123[[2]], min3 = c(0,0.2,0.3), max3 = c(0.5,0.7,0.8), 
    clab = 1, label = row.names(euro123[[1]]), addax = TRUE)
triangle.plot(euro123[[3]], min3 = c(0,0.2,0.3), max3 = c(0.5,0.7,0.8), 
    clab = 1, label = row.names(euro123[[1]]), addax = TRUE)
triangle.plot(rbind.data.frame(euro123[[1]], euro123[[2]], euro123[[3]]))
}
\keyword{hplot}
\eof
\name{trichometeo}
\alias{trichometeo}
\docType{data}
\title{Pair of Ecological Data}
\description{
This data set gives for trappong nights informations about 
species and meteorological variables. 
}
\usage{data(trichometeo)}
\format{
    \code{trichometeo} is a list of 3 components.
    \enumerate{
    \item{fau}{is a data frame with 49 rows (trapping nights) and 17 species.}
    \item{meteo}{is a data frame with 49 rows and 11 meteorological variables.}
    \item{cla}{is a factor of 12 levels for the definition of the consecutive night groups}
    }
}
\source{
	Data from P. Usseglio-Polatera
}
\references{
Usseglio-Polatera, P. and Auda, Y. (1987)\cr
Influence des facteurs mtorologiques sur les rsultats de pigeage lumineux.\cr
\emph{Annales de Limnologie}, \bold{23}, 65--79, code des espces p. 76
}
\examples{
data(trichometeo)
faulog <- log(trichometeo$fau + 1)
pca1 <- dudi.pca(trichometeo$meteo, scan = FALSE)
niche1 <- niche(pca1, faulog, scan = FALSE)
s.label(niche1$ls, clab = 0)
s.distri(niche1$ls, faulog, clab = 0.6, add.p = TRUE, 
    cell = 0, csta = 0.3)
s.arrow(7 * niche1$c1, clab = 1, add.p = TRUE)
}
\keyword{datasets}
\eof
\name{uniquewt.df}
\alias{uniquewt.df}
\title{Elimination of Duplicated Rows in a Array}
\description{
An utility function to eliminate the duplicated rows in a array. 
}
\usage{
uniquewt.df(x)
}
\arguments{
  \item{x}{a data frame which contains duplicated rows}
}
\value{
The function returns a \code{y} which contains once each duplicated row of \code{x}.\cr
\code{y} is an attribut 'factor' which gives the number of the row of \code{y} in which each row of \code{x} is found\cr
\code{y} is an attribut 'length.class' which gives the number of duplicates in \code{x} with an attribut dof each row of \code{y} with an attribut
}
\examples{
data(ecomor)
forsub.r <- uniquewt.df(ecomor$forsub)
attr(forsub.r, "factor")
forsub.r[1,]
ecomor$forsub[126,] #idem

dudi.pca(ecomor$forsub, scale = FALSE, scann = FALSE)$eig
# [1] 0.36845 0.24340 0.15855 0.09052 0.07970 0.04490
w1 <- attr(forsub.r, "len.class") / sum(attr(forsub.r,"len.class"))
dudi.pca(forsub.r, row.w = w1, scale = FALSE, scann = FALSE)$eig
# [1] 0.36845 0.24340 0.15855 0.09052 0.07970 0.04490
}
\keyword{utilities}
\eof
\name{veuvage}
\alias{veuvage}
\docType{data}
\title{Example for Centring in PCA}
\description{
The data come from the INSEE (National Institute of Statistics and Economical Studies). 
It is an array of widower percentages in relation with the age and the socioprofessional category. 
}
\usage{data(veuvage)}
\format{
    \code{veuvage} is a list of 2 components.
    \enumerate{
    \item{tab}{is a data frame with 37 rows (widowers) 6 columns (socio-professional categories)}
    \item{age}{is a vector of the ages of the 37 widowers. }
    }
}
\details{
The columns contain the socioprofessional categories:\cr
1- Farmers, 2- Craftsmen, 3- Executives and higher intellectual professions,\cr
4- Intermediate Professions, 5- Others white-collar workers and 6- Manual workers.\cr
}
\source{
unknown
}
\examples{
data(veuvage)
par(mfrow = c(3,2))
for (j in 1:6) plot(veuvage$age, veuvage$tab[,j],
    xlab = "ge", ylab = "pourcentage de veufs",
    type = "b", main = names(veuvage$tab)[j])
}
\keyword{datasets}
\eof
\name{within}
\alias{within}
\alias{print.within}
\alias{plot.within}
\title{Within Analyses}
\description{
performs within analyses on an object of class \code{dudi}. 
}
\usage{
within(dudi, fac, scannf = TRUE, nf = 2) 
plot.within (x, xax = 1, yax = 2, \dots) 
print.within (x, \dots)
}
\arguments{
 \item{dudi}{an object of class 'dudi'}
 \item{fac}{a factor distributing the rows of \code{dudi$tab} in classes }
 \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
 \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
 \item{xax}{the column number for the x-axis}
 \item{yax}{the column number for the y-axis}
 \item{x}{an object of class 'within'}
 \item{\dots}{further arguments passed to or from other methods}
}
\value{
Returns a list of the sub-class 'within' in the class 'dudi'
  \item{call}{origine}
  \item{nf}{number of axis saved}
  \item{rank}{rank}
  \item{ratio}{percentage of within inertia}
  \item{eig}{numeric eigen values}
  \item{lw}{numeric row weigths}
  \item{cw}{numeric col weigths}
  \item{tabw}{numeric table weigths}
  \item{fac}{factor for grouping}
  \item{tab}{data frame class-variables}
  \item{li}{data frame row coordinates}
  \item{l1}{data frame row normed scores} 
  \item{co}{data frame column coordinates}
  \item{$c1}{data frame column normed scores}
  \item{ls}{data frame supplementary row coordinates}
  \item{as}{data frame inertia axis onto within axis}
}
\references{
Benzcri, J. P. (1983) Analyse de l'inertie intra-classe par l'analyse d'un tableau de correspondances. \emph{Les Cahiers de l'Analyse des donnes}, \bold{8}, 351--358.\cr\cr
Doldec, S. and Chessel, D. (1987) Rythmes saisonniers et composantes stationnelles en milieu aquatique I- Description d'un plan d'observations complet par projection de variables. \emph{Acta Oecologica, Oecologia Generalis}, \bold{8}, 3, 403--426.
}
\examples{
data(meaudret)
par(mfrow = c(2,2))
pca1 <- dudi.pca(meaudret$mil, scan = FALSE, nf = 4)
s.traject(pca1$li, meaudret$plan$sta, 
    sub = "Principal Component Analysis", csub = 1.5)
wit1 <- within(pca1, meaudret$plan$sta, scan = FALSE, nf = 2)
s.traject(wit1$li, meaudret$plan$sta, 
    sub = "Within site Principal Component Analysis", csub = 1.5)
s.corcircle (wit1$as)
par(mfrow = c(1,1))
plot(wit1)
}
\keyword{multivariate}
\eof
\name{within.pca}
\alias{within.pca}
\title{Normed within Principal Component Analysis}
\description{
performs a normed within principal component analysis. 
}
\usage{
within.pca(df, fac, scaling = c("partial", "total"), 
    scannf = TRUE, nf = 2)
}
\arguments{
  \item{df}{a data frame with quantitative variables}
  \item{fac}{a factor distributing the rows of df in classes}
  \item{scaling}{a string of characters as a scaling option : \cr
  	if "partial", for each factor level, the sub-array is centred and normed.\cr
	If "total", for each factor level, the sub-array is centred and the total array is then normed.}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
}
\value{
returns a list of the sub-class 'within' of class 'dudi'. See \code{\link{within}}
}
\references{Bouroche, J. M. (1975) Analyse des donnes ternaires: la double analyse en composantes principales. Thse de 3me cycle, Universit de Paris VI.
}
\examples{
data(meaudret)
wit1 <- within.pca(meaudret$mil, meaudret$plan$dat, 
    scan = FALSE, scal = "partial")
kta1 <- ktab.within(wit1, colnames = rep(c("S1","S2","S3","S4","S5"), 4))
unclass(kta1)
# See pta
plot(wit1)
}
\keyword{multivariate}
\eof
\name{witwit.coa}
\alias{witwit.coa}
\alias{summary.witwit}
\title{Internal Correspondence Analysis}
\description{
performs an Internal Correspondence Analysis. 
}
\usage{
witwit.coa(dudi, row.blocks, col.blocks, scannf = TRUE, nf = 2)
summary.witwit(object, \dots)
}
\arguments{
  \item{dudi}{an object of class 'coa' }
  \item{row.blocks}{a numeric vector indicating the row numbers for each block of rows}
  \item{col.blocks}{a numeric vector indicating the column numbers for each block of columns}
  \item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed}
  \item{nf}{if scannf FALSE, an integer indicating the number of kept axes}
  \cr
  \item{object}{an object of class 'witwit'}
  \item{\dots}{further arguments passed to or from other methods}
}
value{
returns a list of class \code{witwit}, \code{coa} and \code{dudi} (see \link{as.dudi}) containing
  \item{rbvar}{a data frame with the within variances of the rows of the factorial coordinates}
  \item{lbw}{a data frame with the marginal weighting of the row classes}
  \item{cvar}{a data frame with the within variances of the columns of the factorial coordinates}
  \item{cbw}{a data frame with the marginal weighting of the column classes}
}
\references{
Cazes, P., Chessel, D. and Doldec, S. (1988) L'analyse des correspondances internes d'un tableau partitionn :
son usage en hydrobiologie. \emph{Revue de Statistique Applique}, \bold{36}, 39--54. 
}
\examples{
data(ardeche)
coa1 <- dudi.coa(ardeche$tab, scann = FALSE, nf = 4)
ww <- witwit.coa(coa1, ardeche$row.blocks, ardeche$col.blocks, scann = FALSE)
ww
s.class(ww$co, ardeche$sta.fac, clab = 1.5, cell = 0, axesell = FALSE)
s.label(ww$co, add.p = TRUE, clab = 0.75)
summary(ww)
}
\keyword{multivariate}
\eof
\name{worksurv}
\alias{worksurv}
\docType{data}
\title{French Worker Survey (1970)}
\description{
The \code{worksurv} data frame gives 319 response items and 4 questions 
providing from a French Worker Survey. 
}
\usage{data(worksurv)}
\format{
  This data frame contains the following columns:
  \describe{
    \item{pro}{Professional elections. In professional elections in your firm, would you rather vote for a list supported by?
   \code{CGT}
      \code{CFDT}
      \code{FO}
      \code{CFTC}
      \code{Auton} Autonomous
      \code{Abst}
      \code{Nonaffi} Not affiliated
      \code{NR} No response}
    \item{una}{Union affiliation. At the present time, are you affiliated to a Union, and in the affirmative, which one?
      \code{CGT}
      \code{CFDT}
      \code{FO}
      \code{CFTC}
      \code{Auton} Autonomous
      \code{CGC}
      \code{Notaffi} Not affiliated
      \code{NR} No response}
    \item{pre}{Presidential election. On the last presidential election (1969), can you tell me the candidate for whom you have voted?
      \code{Duclos}
      \code{Deferre}
      \code{Krivine}
      \code{Rocard}
      \code{Poher}
      \code{Ducatel}
      \code{Pompidou}
      \code{NRAbs} No response, abstention}
    \item{pol}{political sympathy. Which political party do you feel closest to, as a rule ?
      \code{Communist} (PCF)
      \code{Socialist} (SFIO+PSU+FGDS)
      \code{Left} (Party of workers",\dots)
      \code{Center} MRP+RAD.
      \code{RI}
      \code{Right} INDEP.+CNI
      \code{Gaullist} UNR
      \code{NR} No response}
  }
}
\details{
The data frame \code{worksurv} has the attribute 'counts' giving the number of responses for each item.
}
\source{
Rouanet, H. and Le Roux, B. (1993)\cr
\emph{Analyse des donnes multidimensionnelles}. Dunod, Paris.
}
\references{
Le Roux, B. and Rouanet, H.  (1997)\cr
Interpreting axes in multiple correspondence analysis: method of the contributions of points and deviation.\cr
Pages 197-220 in B. J. and M. Greenacre, editors.\cr
\emph{Visualization of categorical data}, Acamedic Press, London.
}
\examples{
data(worksurv)
acm1 <- dudi.acm(worksurv, row.w = attr(worksurv,"counts"), 
    scan = FALSE)
par(mfrow = c(2,2))
apply(worksurv,2, function(x) s.class(acm1$li, factor(x),
    attr(worksurv, 'counts')))
}
\keyword{datasets}
\eof
\name{yanomama}
\alias{yanomama}
\docType{data}
\title{Distance Matrices}
\description{
This data set gives 3 matrices about geographical, genetic and anthropometric distances. 
}
\usage{data(yanomama)}
\format{
	\code{yanomama} is a list of 3 components:
	\enumerate{
		\item{geo}{is a matrix of 19-19 geographical distances}
		\item{gen}{is a matrix of 19-19 SFA (genetic) distances}
		\item{ant}{is a matrix of 19-19 anthropometric distances}
	}
}
\source{
Spielman, R.S. (1973)\cr
Differences among Yanomama Indian villages: do the patterns of allele frequencies, anthropometrics and map locations correspond?\cr
\emph{American Journal of Physical Anthropology}, \bold{39}, 461--480.
}
\references{
Table 7.2 Distance matrices for 19 villages of Yanomama Indians.\cr
All distances are as given by Spielman (1973), multiplied by 100 for convenience in:\cr
Manly, B.F.J. (1991)\cr
\emph{Randomization and Monte Carlo methods in biology}\cr
Chapman and Hall, London, 1--281.
}
\examples{
if (require(mva, quietly = TRUE)) {
	data(yanomama)
	gen <- quasieuclid(as.dist(yanomama$gen)) # depends of mva
	ant <- quasieuclid(as.dist(yanomama$ant)) # depends of mva
	par(mfrow = c(2,2))
	plot(gen, ant)
	t1 <- mantel.randtest(gen, ant, 99);
	plot(t1, main = "gen-ant-mantel") ; print(t1)
	t1 <- procuste.rtest(pcoscaled(gen), pcoscaled(ant), 99)
	plot(t1, main = "gen-ant-procuste") ; print(t1)
	t1 <- RV.rtest(pcoscaled(gen), pcoscaled(ant), 99)
	plot(t1, main = "gen-ant-RV") ; print(t1)
}
}
\keyword{datasets}
\eof
